/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

jQuery(function($) {
    
   
	// --------------------------------------------------------------------

    /**
     * détecte si le navigateur est IE 6 ou inférieur 
     *
     * @access public
     * @return boolean
     */ 
    function is_ie6(){
        return is_ie_less_than(7);
    }
   
	// --------------------------------------------------------------------

    /**
     * détecte si le navigateur est IE inférieur à la version passée en paramètre
     *
     * @access public
     * @param integer Version du navigateur
     * @return boolean
     */ 
    function is_ie_less_than(max_version)
    {
        var matches = navigator.userAgent.match(/(msie) ([\w.]+)/i);
        
        if( matches && matches[2] < max_version ){
            return true;
        }
        
        return false;
    }   
   
	// --------------------------------------------------------------------
    
    /**
     * Crée une nouvelle fenêtre
     *
     * @access public
     * @return void
     */     
    function popup_window(url, title, width, height)
    {
        var left = (screen.width - width) / 2;
        var top = (screen.height - height) / 4;  // for 50% - devide by 2  |  for 25% - devide by 4  |  for 33% - devide by 3
        
        return window.open(url, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars, resizable, copyhistory=no, width='+ width +', height='+ height +', top='+ top +', left='+ left);
    } 
   
	// --------------------------------------------------------------------
    
    /**
     * Ajoute l'évenement click pour afficher le navigateur de fichier
     *
     * @access public
     * @return void
     */     
    function add_event_click_for_display_file_browser()
    {
        $('a.filebrowser').on('click', function()
        {
       		var width = $(this).data('popup-width') || '850';
            var height = $(this).data('popup-height') || '495';
       		
            win = popup_window(this.href, 'filebrowser', width, height);
            win.focus();

    		//Apparition du fond - .css({'filter' : 'alpha(opacity=50)'}) pour corriger les bogues d'anciennes versions de IE
            $('<div></div>', {
                'id' : 'fade',
                'css' : {
                	'display': 'none', /*--masqué par défaut--*/
                	'background': '#000',
                	'position': 'fixed', 'left': '0', 'top': '0',
                	'width': '100%', 'height': '100%',
                	'opacity': '.50',
                	'z-index': '9999',
                }
            }).appendTo("body").fadeIn();
    		
            // Correction d'un bug pour la gestion de l'opacité pour IE 5-8
            if (is_ie_less_than(9)) {
        		$('#fade').css({ 'filter' : 'alpha(opacity=50)'});
            }                     
 
            if (is_ie6()) {
        		$('#fade').css({ 'position':  'absolute'});
            }                     
            
            return false;
        });
        
    	//Close Popup and Fade Layer
    	$('body').on('click', '#fade', function() { //Au clic sur le body...
            $('#fade').fadeOut(function()
            {
                $('#fade').remove();
                
                if (win) {
                    win.close();
                } 
                            
            }); //...ils disparaissent ensemble
    		
    		return false;
    	});        
    }


    function add_event_click_for_display_datetime_picker()
    {
        $('#admr_doc_date_publication input, #event_date').datetimepicker({
        	inline : false,
            lang : 'fr',
        	timepicker : false,
        	format : 'Y/m/d',
            validateOnBlur : false,
        });

        $('button').css({'min-width': '5px'}); // Correction d'un problème CSS avec skin guppy
        
        
    }
    
    function add_readonly_for_input_image()
    {
        $('#doc_img1,#doc_img2').attr('readonly', 'readonly');    
    }

    function add_readonly_for_input_file_download()
    {
        $('#doc_file1,#doc_file2').attr('readonly', 'readonly');    
    }

    function add_form_validation()
    {        
        // Setup form validation
        $.validate();
    }

    function add_placeholder_for_old_browsers()
    {        
        $('input').placeholder();
    }
    
	// --------------------------------------------------------------------

    /**
     * fonctions à exécuter lors du chargement du script
     *
     * @return void
     */
    function init()
	{
        add_event_click_for_display_file_browser();
        add_event_click_for_display_datetime_picker();
        add_readonly_for_input_image();
        add_readonly_for_input_file_download();
        add_form_validation();
        add_placeholder_for_old_browsers();       
    }
    //
    
    init(); // initialisation  
});