/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

jQuery(function($) {

    /**
     * cache tous les onglets sauf celui qui est sélectionné par son id
     *
     * @param string Id de l'onglet sélectionné
     * return void;
     */
    function hide_all_tab_except(idTab)
    {
        hide_all_tab();
        show_tab_selected(idTab);            
    }

    /**
     * montre l'onglet sélectionné par son id
     *
     * @param string Id de l'onglet sélectionné
     * return void;
     */
    function show_tab_selected(idTab)
    {
        $('#'+ idTab).show();
        $('#'+ idTab).next().show();
        $('#'+ idTab).next().next().show();
        
        return;
    }

    /**
     * Cache tous les onglets
     *
     * return void;
     */
    function hide_all_tab()
    {
        $('fieldset[id^=params_]').hide();
        $('form button').parent().hide();
        $('a[href="#nav_page"]').parent().hide();
        
        return;
    }
    
	// --------------------------------------------------------------------

    /**
     * Ajoute un évènement onclick sur les items du menu des onglets
     *
     * return void;
     */    
    function add_event_click_for_tab()
    {
        // Affichage de l'onglet sélectionné
        $('#nav_page li').on('click', function() {
            var idTab = $(this).children('a').attr('href');        
            idTab = idTab.substr(1); // Suppression de #
            
            $('#nav_page a').removeClass('current');
            $(this).children('a').addClass('current');
            
            hide_all_tab_except(idTab);
        });
        
        // Désactivation des liens
        $('#nav_page a').click(function(event){
            event.preventDefault();
        });
    }
    
	// --------------------------------------------------------------------

    /**
     * Ajoute un système de validation du formulaire
     *
     * return void;
     */
    function add_form_validation()
    {
        // Setup form validation
        $.validate({
            onError : function() {
                $('#nav_page a').removeClass('current');
                $('a[href="#params_logins"]').addClass('current');
                hide_all_tab_except('params_logins');
            }           
        });
        
    }
   
	// --------------------------------------------------------------------

    /**
     * Ajoute une case à cocher qui permet de cocher ou décocher tous les droits en même temps
     *
     * return void;
     */
    function add_checkbox_for_rights()
    {
        $('fieldset.rights legend')
            .append(function() {
                return $(document.createElement('input')).attr({'type' : 'checkbox', 'title' : $(this).data('check-all')});
            })
            .on('click', function() {        
                if ($(this).children('input').is(':checked')) {
                    $(this).parent().children('p').children('input').prop('checked', true);
                    $(this).children('input').attr('title', $(this).data('uncheck-all'));
                } else {
                    $(this).parent().children('p').children('input').prop('checked', false);
                    $(this).children('input').attr('title', $(this).data('check-all'));  
                }            
        });
    }
   
	// --------------------------------------------------------------------

    /**
     * Ajoute une case à cocher qui permet d'autoriser ou de refuser toutes les options en même temps
     *
     * return void;
     */
    function add_checkbox_for_options()
    {
        $('fieldset.options legend')
            .append(function() {
                return $(document.createElement('input')).attr({'type' : 'checkbox', 'title' : $(this).data('check-all')});
            })
            .on('click', function() {        
                if ($(this).children('input').is(':checked')) {
                    $(this).parent().children('p').children('input[value="1"]').prop('checked', true);
                    $(this).children('input').attr('title', $(this).data('uncheck-all'));
                } else {
                    $(this).parent().children('p').children('input[value="0"]').prop('checked', true);
                    $(this).children('input').attr('title', $(this).data('check-all'));  
                }            
        });
    }
    
	// --------------------------------------------------------------------

    /**
     * initialiser
     *
     * @return void
     */
    function init()
	{
        hide_all_tab_except('params_logins');
        $('#nav_page a[href="#params_logins"]').addClass('current');
        add_event_click_for_tab();
        add_form_validation();
        add_checkbox_for_rights();
        add_checkbox_for_options();    
    }
    //
    
    init(); // initialisation  
});