/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

jQuery(function($) {

    /**
     * Vérfie si une url existe ou non 
     *
     * @access public
     * @param string Url à vérifier
     * @return boolean
     */
 /*   function url_exists(url)
    {
        var http = new XMLHttpRequest();
        http.open('HEAD', url, false);
        http.send();
        
        return http.status != 404;
    }*/
   
	// --------------------------------------------------------------------

    /**
     * détecte si le navigateur est IE 6 ou inférieur 
     *
     * @access public
     * @return boolean
     */ 
    function is_ie6(){
        return is_ie_less_than(7);
    }
   
	// --------------------------------------------------------------------

    /**
     * détecte si le navigateur est IE inférieur à la version passée en paramètre
     *
     * @access public
     * @param integer Version du navigateur
     * @return boolean
     */ 
    function is_ie_less_than(max_version)
    {
        var matches = navigator.userAgent.match(/(msie) ([\w.]+)/i);
        
        if( matches && matches[2] < max_version ){
            return true;
        }
        
        return false;
    }
   
	// --------------------------------------------------------------------

    /**
     * Supprime les caractères blancs au début et à la fin de la valeur d'un élément de type input ou textarea
     *
     * @access public
     * @param object Element de formulaire (input ou textarea)
     * @return object Element
     */    
    function trim(form_element)
    {
        var value = $.trim(form_element.val());
        form_element.val( value );
        
        return form_element;
    }
   
	// --------------------------------------------------------------------

    /**
     * Vérifie si un élement existe ou non
     *
     * @access public
     * @param object Element
     * @return boolean
     */    
    function element_exist(element)
    {
        return element.length > 0;
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute comme évènement l'ouverture d'une fenêtre modale lorsqu'on clique sur le lien qui a la class "popup" 
     *
     * @access public
     * @return void
     */
    function add_event_click_for_open_window_modal()
    {
    	var popID = 'popup'; // Identifiant de la pop-up
        
        //Lorsque vous cliquez sur un lien avec la classe popup
        $('#dir_contents').on('click', 'a.popup', function()
        {
            var popWidth = $(this).data('width');   // Largeur de la popup définie avec l'attribut data-with
            var popHeight = $(this).data('height'); // Largeur de la popup définie avec l'attribut data-height

            //Charger le contenu de la pop-up via ajax
            $('#' + popID).load($(this).attr('href') + ' .popup-content', function(data)
            {
                // Validation du formulaire pour renommer un fichier ou un répertoire avant soumission               
                // $('#' + popID + ' form.rename').submit(valid_form_rename);
                add_form_validation();

                // Redimensionnement de la popup si c'est une image
                var popImg = $('#popup-img');
                
                if (popImg.length > 0) {
                    popWidth = popImg.attr('width');   // Largeur de la popup = largeur de l'image
                    popHeight = popImg.attr('height'); // Hauteur de la popup = hauteur de l'image
                }
                //
                
                build_window_modal(popID, popWidth, popHeight);
            }
            , 'html');        

            
    		return false;
    	});
        
        add_event_click_for_close_window_modal(popID);       
    }    
   
	// --------------------------------------------------------------------

    /**
     * Consruit une fenêtre modale (popup)
     *
     * @access public
     * @param string identifiant de la popup
     * @param integer largeur de la popup
     * @param integer hauteur de la popup
     * @return boolean
     */    
    function build_window_modal(popID, popWidth, popHeight)
    {        
        // Redimensionnement de l'iframe
        $('#' + popID + ' iframe#popup-iframe').css({'width': popWidth, 'height': popHeight});
        
        //Faire apparaitre la pop-up et la dimensionner
        $('#' + popID).fadeIn().css({
            'text-align':'center'
        }).prepend('<a href="#" class="popup_close"><img src="'+$('#' + popID).data('img-close-path')+'" class="btn_close" title="'+$('#' + popID).data('img-close-alt')+'" alt="'+$('#' + popID).data('img-close-alt')+'" /></a>');
		
		//Appliquer les marges qui permettront de centrer la fenêtre - on ajuste de 80px en conformité avec le CSS 
		$('#' + popID).css({ 
            'margin-top':  -($('#' + popID).height() + 80) / 2,
            'margin-left': -($('#' + popID).width() + 80) / 2,
		});
		
		//Apparition du fond - .css({'filter' : 'alpha(opacity=50)'}) pour corriger les bogues d'anciennes versions de IE
        $('<div/>', {
            'id' : 'fade',
            'css' : {
                'filter' : 'alpha(opacity=50)' // for IE 5-8
            }
        }).appendTo("body").fadeIn();
		
        // Correction d'un bug pour la gestion de la position fixed pour IE 6
        if (is_ie6()) {
    		$('#fade').css({ 'position':  'absolute'});
            $('#' + popID).css({ 'position':  'absolute'});
        }                     

        return;
    }
   
	// --------------------------------------------------------------------

    /**
     * Ferme la fenêtre modale lorsqu'on clique sur la page ou bien sur le bouton annuler
     *
     * @access private
     * @param string Identifiant de la popup
     * @return void
     */
    function add_event_click_for_close_window_modal(popID)
    {
    	//Close Popups and Fade Layer
    	$('body').on('click', 'a.popup_close, #fade', function() { //Au clic sur le body...
            $('#fade , #' + popID).fadeOut(function()
            {
                $('#fade, a.popup_close').remove();
                $('#' + popID).empty();                              
            }); //...ils disparaissent ensemble
    		
    		return false;
    	});        
    }

    /*************************************************************************************************************/
    
    /**
     * Supprime l'adresse du domaine dans l'url
     * 
     * @param string url absolue
     * @return string url relative
     */
    function delete_host_name(url)
    {
    	var posPathName = window.location.href.indexOf('admin/plugins/adm_redacteurs/', 0);
   	
        if (posPathName === -1) {      
            posPathName = window.location.href.indexOf('plugins/adm_redacteurs/', 0);
        }
   	
    	return (posPathName !== -1) ?  url.substring(posPathName) : url;
    };
        
	// --------------------------------------------------------------------

    /**
     * Vérifie si le gestionnaire de fichier est appelé dans une popup ou non
     *
     * @return boolean
     */
    function is_popup_filemanager()
    {
        if (window.location.pathname.indexOf('filemanager.php') !== -1) {
            return true;
        }
        
        return false;
    }
        
	// --------------------------------------------------------------------

    /**
     * Récupère le chemin du fichier lorsqu'on clique sur le lien
     *
     * @access private
     * @param string Identifiant du champ cible
     * @return void
     */
    function add_event_click_for_capture_file_path(id_target, ckeditor_func_num)
    {        
        $('table').on('click', 'a.filepath', function()
        {
            var url = delete_host_name(this.href);  // Suppression du nom de domaine

            // Target input
            if (window.opener && window.opener.document.getElementById(id_target)) {
                window.opener.document.getElementById(id_target).value = url;
                window.opener.document.getElementById(id_target).focus();
                
                if (window.opener.document.getElementById('fade')) {
                    var el = window.opener.document.getElementById('fade');
                    el.parentNode.removeChild(el);
                }  
            }
            
            // CKEditor
            if (window.opener && ckeditor_func_num) {
              
                window.opener.CKEDITOR.tools.callFunction(ckeditor_func_num, url, function ()
                {
                    var element, dialog = this.getDialog();

                    if (dialog.getName() == 'link') {   // Popup Liens
                        element = dialog.getContentElement( 'info', 'protocol' );
                        if ( element ) {
                            element.setValue('');
                        }
                    }
                    else if (dialog.getName() == 'image') { // Popup Image

                        element = dialog.getContentElement( 'info', 'txtAlt' );

                        if ( element ) {
                            var alt = '';
                            element.setValue(alt);
                        }
                        
                        element = dialog.getContentElement( 'info', 'txtBorder' );
                        if ( element ) {
                            element.setValue("0");
                        } 
                    }
                });
            }
                       
    		window.close();
            
    		return false;
    	});        
    }    

    // --------------------------------------------------------------------
    
    /**
     * Récupère la valeur d'un paramètre passées dans l'url (nécessaire pour CKEditor)
     */
    function get_ckeditor_func_num()
    {
        var func_num = get_url_param('CKEditorFuncNum');
         
        return (func_num) ? parseInt(func_num) : null ;
    };

    // --------------------------------------------------------------------
    
    /**
     * Récupère la valeur d'un paramètre passées dans l'url (nécessaire pour CKEditor)
     */
    function get_url_param(paramName)
    {
      var reParam = new RegExp('(?:[\?&]|&amp;)' + paramName + '=([^&]+)', 'i') ;
      var match = window.location.search.match(reParam) ;
     
      return (match && match.length > 1) ? match[1] : null ;
    };
   
	// --------------------------------------------------------------------

    /**
     * Ajoute un paramètre supplémentaire à l'url des liens et des formulaires (nécessaire pour CKEditor)
     *
     * @access private
     * @param string Nom du paramètre
     * @param string valeur du paramètre
     * @return void
     */
    function add_url_param(paramName, paramValue)
    {       
        if (!paramValue) {
            return false;
        }
        
        /**
         * Elements A
         */
         $('table a, #dir_contents a').each(function(){
            if (this.href.indexOf('filemanager.php') !== -1 && this.href.indexOf(paramName) === -1) {
                var posAnchor = this.href.lastIndexOf('#');
                             
                if (posAnchor !== -1) {
                    var baseUrl = this.href.substr(0, posAnchor);
                    var anchor = this.href.substr(posAnchor);                     
                    this.href = baseUrl + '&'+paramName+'='+paramValue + anchor;   
                } else {
                    this.href += '&'+paramName+'='+paramValue; 
                }
            }
         });
        //
        
        /**
         * Elements FORM
         */
         $('form').each(function(){
            if (this.action.indexOf('filemanager.php') !== -1 && this.action.indexOf(paramName) === -1) {
                var posAnchor = this.action.lastIndexOf('#');
                             
                if (posAnchor !== -1) {
                    var baseUrl = this.action.substr(0, posAnchor);
                    var anchor = this.action.substr(posAnchor);                     
                    this.action = baseUrl + '&'+paramName+'='+paramValue + anchor;   
                } else {
                    this.action += '&'+paramName+'='+paramValue; 
                }
            }
         });
        //
    }
       
	// --------------------------------------------------------------------

    /**
     * Remplace des directives css dans la feuille de style du gestionnaire de fichier
     *
     * @return void
     */
    function replace_file_manager_css()
    {
//        $('#dir_contents table').css('width', '100%');
    }
    
	// --------------------------------------------------------------------

    /**
     * Crée un menu en liste pour afficher l'arborescence des répertoires
     *
     * @access public
     * @param string Identifiant du formulaire contenant la liste des répertoires
     * @param string Identifiant du block div contenant l'arborescence des répertoires
     * @return void
     */
    function replace_form_select_dirs_path_by_menu_dirs_tree()
    {      
        var form_id = "dir_path";
        var tree_id = "dirs_tree";
        
        var select = $('#' + form_id + ' select');
        var base_uri = get_base_uri($('#' + form_id).attr('action'));
        var query_uri = build_query_uri(
            {
                'type' : $('#' + form_id + ' input[name="type"]').val(),
                'target' : $('#' + form_id + ' input[name="target"]').val(),
                'addon' : $('#' + form_id + ' input[name="addon"]').val()   
            },
            'dirs_tree'
        );

        var options = $('option', select);  // get all <option> elements        
        
        $('#' + form_id).wrap('<div id="' + tree_id + '"></div>');
        
        $('#' + tree_id).append('<h4>' + select.attr('data-title') + '</h4><ul></ul>');
       
        var level = 0;
        var target_element = $('#' + tree_id + ' ul');
        
        options.each(function(){
            var current_level = parseInt($(this).attr('class').substr('dir-level-'.length));
            var item_selected = $(this).is(':selected') ? 'selected ' : '';
            var label = $(this).text();
                        
            if (current_level > level) {
                target_element = target_element.children(":last");
                target_element.append('<ul></ul>');
                target_element = target_element.children(":last");    
            }
            else if (current_level < level) {
                while(level != current_level) {
                    target_element = target_element.parent().parent();
                    level--;    
                }    
            }

            if (current_level !== 0) {
                label = $(this).text().substr($(this).text().lastIndexOf('/')+1); // On ne retient que le nom du sous-répertoire courant si niveau > 0
            }
            
            target_element.append('<li title="' + $(this).text() + '" class="' + item_selected + $(this).attr('class') + '"><a href="'+ base_uri + '&amp;dir_path=' + $(this).val() + query_uri + '">' + label + '</a></li>');

            level = current_level;
        });
        
        $('#' + form_id).remove();  // Supprime le formulaire remplacé        
    }           

	// --------------------------------------------------------------------

    /**
     * Retourne la requête avec les paramètres à faire passer dans l'uri
     *
     * @access private
     * @param object paramètres avec les valeurs sous la forme {'name' : value}
     * @param string ancre
     * @return string uri
     */
    function get_base_uri(uri)
    {
        return uri.substring(0, uri.lastIndexOf("#"));
    }

	// --------------------------------------------------------------------

    /**
     * Retourne la requête avec les paramètres à faire passer dans l'uri
     *
     * @access private
     * @param object paramètres avec les valeurs sous la forme {'name' : value}
     * @param string ancre
     * @return string uri
     */
    function build_query_uri(query_params, anchor)
    {
        var query_uri = '';
        
        for(param in query_params) {
            if (query_params[param] != '') {
                query_uri += '&amp;' + param + '=' + query_params[param];
            }    
        }
        
        if (anchor != '') {
            query_uri += '#' + anchor;
        }
        
        return query_uri;
    }

	// --------------------------------------------------------------------

    /**
     * Remplace le formulaire pour uploader un fichier par un lien qui ouvre une popup
     *
     * @return void
     */
    function replace_form_upload_file()
    {
        var form_selector = 'form[name="upload_files"]';
        
        replace_form(form_selector);
    }
       
	// --------------------------------------------------------------------

    /**
     * Remplace le formulaire pour créer un répertoire par un lien qui ouvre une popup
     *
     * @return void
     */
    function replace_form_create_dir()
    {
        var form_selector = 'form[name="create_dir"]';
        
        replace_form(form_selector);
    }
       
	// --------------------------------------------------------------------

    /**
     * Remplace un formulaire par un lien qui ouvre une popup
     *
     * @param string sélecteur du formulaire
     * @return void
     */
    function replace_form(form_selector)
    {
        if ($('#dir_contents>div').length == 0) {
            $('#dir_contents').append('<div></div>');    
        }       
        
        if ($(form_selector).length > 0) {
            var href = $(form_selector).attr('action') + '&dir_path=' + $(form_selector + ' input[name="dir_path"]').val();
                href += ($(form_selector + ' input[name="type"]').val() !== '') ? '&type=' + $(form_selector + ' input[name="type"]').val() : '';
                href += ($(form_selector + ' input[name="target"]').val() !== '') ? '&target=' + $(form_selector + ' input[name="target"]').val() : '';
                href += ($(form_selector + ' input[name="addon"]').val() !== '') ? '&addon=' + $(form_selector + ' input[name="addon"]').val() : '';
            
            var width = $(form_selector).data('width') || 500;
            var height = $(form_selector).data('height') || 110;
            
            $('#dir_contents>div').append('<span><a class="popup ' + $(form_selector).attr('name') + '" data-width="' + width + '" data-height="' + height + '" href="' + href  + '#dir_contents">' + $(form_selector + ' legend').html() + '</a></span>');

            $(form_selector).remove();
            
            return true;
        }
        
        return false;
    }
   
	// --------------------------------------------------------------------
    
    /**
     * Crée une nouvelle fenêtre
     *
     * @access public
     * @return void
     */     
    function popup_window(url, title, width, height)
    {
        var left = (screen.width - width) / 2;
        var top = (screen.height - height) / 4;  // for 50% - divide by 2  |  for 25% - divide by 4  |  for 33% - divide by 3
        
        return window.open(url, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars, resizable, copyhistory=no, width='+ width +', height='+ height +', top='+ top +', left='+ left);
    } 
   
	// --------------------------------------------------------------------
    
    /**
     * Ajoute un évènement (onclick) sur les liens qui possèdent la classe "filebrowser"
     * pour afficher le gestionnaire de fichier
     *
     * @access public
     * @return void
     */
    function add_event_click_for_display_file_browser()
    {
        $('a.filebrowser').on('click', function()
        {
       		var width = $(this).data('popup-width') || '500';
            var height = $(this).data('popup-height') || '500';
       		
            win = popup_window(this.href, 'filebrowser', width, height);
            win.focus();

    		//Apparition du fond - .css({'filter' : 'alpha(opacity=50)'}) pour corriger les bogues d'anciennes versions de IE
            $('<div></div>', {
                'id' : 'fade',
                'css' : {
                	'display': 'none', /*--masqué par défaut--*/
                	'background': '#000',
                	'position': 'fixed', 'left': '0', 'top': '0',
                	'width': '100%', 'height': '100%',
                	'opacity': '.50',
                	'z-index': '9999',
                }
            }).appendTo("body").fadeIn();
    		
            // Correction d'un bug pour la gestion de l'opacité pour IE 5-8
            if (is_ie_less_than(9)) {
        		$('#fade').css({ 'filter' : 'alpha(opacity=50)'});
            }                     
 
            if (is_ie6()) {
        		$('#fade').css({ 'position':  'absolute'});
            }                     
            
            return false;
        });
        
    	//Close Popup and Fade Layer
    	$('body').on('click', '#fade', function() { //Au clic sur le body...
            $('#fade').fadeOut(function()
            {
                $('#fade').remove();
                
                if (win) {
                    win.close();
                } 
                            
            }); //...ils disparaissent ensemble
    		
    		return false;
    	});        
    }
   
	// --------------------------------------------------------------------
    
    /**
     * Ajoute un évènement (onsubmit) sur les formulaires pour vérifier la validité des champs
     *
     * @access public
     * @return void
     */
    function add_form_validation()
    {        
        $.validate();
    }
   
	// --------------------------------------------------------------------
    
    /**
     * Modifie l'apprence du menu général du plugin
     *
     * @access public
     * @return void
     */
    function modify_plugin_menu()
    {        
        $('li.go_dashboard').parent(0).css('text-align', 'left');
    }
   
	// --------------------------------------------------------------------

    /**
     * fonctions à exécuter lors du chargement du script
     *
     * @return void
     */
    function init()
	{
        /**
         * Utilisation du file manager en popup
         */
        if (is_popup_filemanager()) {            
            var ckeditor_func_num = get_ckeditor_func_num();
            add_url_param('CKEditorFuncNum', ckeditor_func_num) // Ajout des paramètres identifiants l'éditeur CKEDITOR
    
            var id_target = get_url_param('target');            
            add_event_click_for_capture_file_path(id_target, ckeditor_func_num); // Ajout de la capture du chemin du fichier lors d'un click de souris sur le nom du fichier (event onclick)
        }   

        // Ajout des fenêtres modales
        add_event_click_for_open_window_modal();
        
        /**
         * Modification de l'apparence du filemanager
         */
        replace_file_manager_css(); // Modifie les css du gestionnaire de fichier
        replace_form_select_dirs_path_by_menu_dirs_tree(); // Affiche l'arborescence des répertoires sous la forme d'un menu en liste à la place d'un menu select
        replace_form_upload_file(); // Modifie l'apparence du formulaire d'upload de fichiers
        replace_form_create_dir(); // Modifie l'apparence du formulaire de création de répertoire
        //

        modify_plugin_menu(); // Modifie les css du menu général du plugin
    }
    //
     
    init(); // initialisation  
});