/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

(function($) {

    /**
     * Validation du choix des dates de publication
     */
    $.formUtils.addValidator({
        name : 'pubdate',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence de la date de début de la publication
             */
            if ($el.attr('id') == 'pubdate_begin' && $.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-date-required');
                return false;                                                            
            }
            
            /**
             *  Test du format de la date de publication
             */
            var dateFormat = /^\d{4}\/\d{2}\/\d{2}$/; // yyyy/mm/dd

            if(!dateFormat.test(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-date-format');
                return false;                                        
                
            }
            //
            
            /**
             * Test de l'existence réelle de la date de publication
             */
            var date_temp = value.split('/');
            date_temp[1] = date_temp[1] - 1; // On rectifie le mois car il commence à 0 en javascript !!!
            
            var date = new Date(parseInt(date_temp[0], 10), parseInt(date_temp[1], 10), parseInt(date_temp[2], 10));

            if (date.getFullYear() != date_temp[0] || date.getMonth() != date_temp[1] || date.getDate() != date_temp[2]) {
                this.errorMessage = $el.attr('data-validation-error-msg-date-not-exist');
                return false;                                                            
            }
            //
            
            /**
             *  Test de la validité de la date de fin de publication par rapport à la date de début
             */
            var dateBegin = document.getElementById('pubdate_begin').value.replace(/\//g, '');
            var dateEnd = value.replace(/\//g, '');

            if (dateBegin > dateEnd) {
                this.errorMessage = $el.attr('data-validation-error-msg-date-end');
                return false;                    
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix de l'heure des dates de publication
     */
    $.formUtils.addValidator({
        name : 'pubhour',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence de l'heure de la date de publication
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-hour-required');
                return false;                                                            
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix des minutes des dates de publication
     */
    $.formUtils.addValidator({
        name : 'pubminutes',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence des minutes de la date de publication
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-minutes-required');
                return false;                                                            
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix des horaires des dates de publication
     */
    $.formUtils.addValidator({
        name : 'pubtime',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             *  Test de la validité de l'horaire de fin de publication par rapport à l'horaire de début
             */
            var dateBegin = document.getElementById('pubdate_begin').value.replace(/\//g, '');
            var dateEnd = document.getElementById('pubdate_end').value.replace(/\//g, '');

            if (dateBegin === dateEnd) { // Même date de début et de fin de publication
                var hourBegin = document.getElementById('pubhour0').value;
                var hourEnd = document.getElementById('pubhour1').value;
                var minutesBegin = document.getElementById('pubminute0').value;
                var minutesEnd = document.getElementById('pubminute1').value;
            
                var dateBegin = new Date(2014, 1, 1, parseInt(hourBegin, 10), parseInt(minutesBegin, 10));
                var dateEnd = new Date(2014, 1, 1, parseInt(hourEnd, 10), parseInt(minutesEnd, 10));
 
                if(dateBegin.getTime() >= dateEnd.getTime()) {
                    this.errorMessage = $el.attr('data-validation-error-msg-time-end');
                    return false;                    
                }
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix de la date de l'évènement
     */
    $.formUtils.addValidator({
        name : 'eventdate',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence de la date de l'évènement
             */
            if ($el.attr('id') == 'event_date' && $.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-date-required');
                return false;                                                            
            }
            
            /**
             *  Test du format de la date de publication
             */
            var dateFormat = /^\d{4}\/\d{2}\/\d{2}$/; // yyyy/mm/dd

            if(!dateFormat.test(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-date-format');
                return false;                                        
                
            }
            //
            
            /**
             * Test de l'existence réelle de la date de publication
             */
            var date_temp = value.split('/');
            date_temp[1] = date_temp[1] - 1; // On rectifie le mois car il commence à 0 en javascript !!!
            
            var date = new Date(parseInt(date_temp[0], 10), parseInt(date_temp[1], 10), parseInt(date_temp[2], 10));

            if (date.getFullYear() != date_temp[0] || date.getMonth() != date_temp[1] || date.getDate() != date_temp[2]) {
                this.errorMessage = $el.attr('data-validation-error-msg-date-not-exist');
                return false;                                                            
            }
            //

            /**
             *  Test de la validité de la date de fin de publication par rapport à la date de début
             */
            var dateBegin = document.getElementById('pubdate_begin').value.replace(/\//g, '');
            var dateEvent = value.replace(/\//g, '');

            if(dateBegin > dateEvent) {
                this.errorMessage = $el.attr('data-validation-error-msg-date-value');
                return false;                    
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix de l'heure de l'évènement
     */
    $.formUtils.addValidator({
        name : 'eventhour',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence de l'heure de l'évènement
             */
            var hour = value;
            var minutes = document.getElementById('evminute' + $el.attr('id').substr(-1,1)).value; 
             
            if ($.trim(hour) === '' && $.trim(minutes) !== '') {
                this.errorMessage = $el.attr('data-validation-error-msg-hour-required');
                return false;                                                            
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix des minutes de l'évènement
     */
    $.formUtils.addValidator({
        name : 'eventminutes',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence des minutes de l'évènement
             */
            var minutes = value;
            var hour = document.getElementById('evhour' + $el.attr('id').substr(-1,1)).value; 
             
            if ($.trim(minutes) === '' && $.trim(hour) !== '') {
                this.errorMessage = $el.attr('data-validation-error-msg-minutes-required');
                return false;                                                            
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix des horaires de l'évènement
     */
    $.formUtils.addValidator({
        name : 'eventtime',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             *  Test de la validité de l'horaire de fin de l'évènement par rapport à l'horaire de début
             */
            var hourBegin = document.getElementById('evhour0').value;
            var hourEnd = document.getElementById('evhour1').value;
            var minutesBegin = document.getElementById('evminute0').value;
            var minutesEnd = document.getElementById('evminute1').value;
            
            if ($.trim(hourBegin) !== '' || $.trim(minutesBegin) !== '' || $.trim(hourEnd) !== '' || $.trim(minutesEnd) !== '') {
                var dateBegin = new Date(2014, 1, 1, parseInt(hourBegin, 10), parseInt(minutesBegin, 10));
                var dateEnd = new Date(2014, 1, 1, parseInt(hourEnd, 10), parseInt(minutesEnd, 10));
 
                if(dateBegin.getTime() > dateEnd.getTime()) {
                    this.errorMessage = $el.attr('data-validation-error-msg-time-end');
                    return false;                    
                }
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
        
	// --------------------------------------------------------------------
        
    /**
     * Validation du choix de l'image
     */
    $.formUtils.addValidator({
        name : 'image',
        validatorFunction : function(value, $el, config, language, $form) {
    
            /**
             * Test de la présence de l'url de l'image
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-image-required');
                return false;                                                            
            }

            /**
             *  Test de la validité de l'extension
             */
            var img_ext_allowed = $el.attr('data-validation-ext-allowed').split(',');
            var img_ext = value.substring(value.lastIndexOf('.'));
            
            if($.inArray(img_ext, img_ext_allowed) === -1) {
                this.errorMessage = $el.attr('data-validation-error-msg-img-ext');
                return false;                    
            }
            //
    
            /**
             * Test de la validité du répertoire de l'icone
             */
            var img_dirs_allowed = $el.attr('data-validation-img-path').split(',');
            var img_dir = value.substring(0, value.indexOf('/'));
    
            if($.inArray(img_dir, img_dirs_allowed) === -1) {
                this.errorMessage = $el.attr('data-validation-error-msg-img-path');
                return false;                    
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation de l'url du site web
     */
    $.formUtils.addValidator({
        name : 'website',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence de l'url
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-url-required');
                return false;                                                            
            }
            
            /**
             *  Test du format de l'url
             */
            if(!$.formUtils.validators.validate_url.validatorFunction(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-url-not-valid');
                return false;                                        
                
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------
    
    /**
     * Validation du choix du fichier
     */
    $.formUtils.addValidator({
        name : 'file',
        validatorFunction : function(value, $el, config, language, $form) {
    
            /**
             * Test de la présence du lien vers le fichier
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-file-required');
                return false;                                                            
            }

            /**
             *  Test de la validité de l'extension du fichier
             */
            var file_ext_allowed = $el.attr('data-validation-ext-allowed').split(',');
            var file_ext = value.substring(value.lastIndexOf('.'));
            
            if($.inArray(file_ext, file_ext_allowed) === -1) {
                this.errorMessage = $el.attr('data-validation-error-msg-file-ext');
                return false;                    
            }
            //
    
            /**
             * Test de la validité du répertoire du fichier
             */
            var file_dirs_allowed = $el.attr('data-validation-file-path').split(',');
            var file_dir = value.substring(0, value.indexOf('/'));
    
            if($.inArray(file_dir, file_dirs_allowed) === -1) {
                this.errorMessage = $el.attr('data-validation-error-msg-file-path');
                return false;                    
            }
            //
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du lien externe de l'item de menu
     */
    $.formUtils.addValidator({
        name : 'external_link',
        validatorFunction : function(value, $el, config, language, $form) {

             if ($('input:checked').val() == 'external') { // Case lien externe cochée
                /**
                 * Test de la présence de l'url
                 */
                if ($.trim(value) === '') {
                    this.errorMessage = $el.attr('data-validation-error-msg-external-link-required');
                    return false;
                }
                
                /**
                 *  Test du format de l'url
                 */
                if(!$.formUtils.validators.validate_url.validatorFunction(value)) {
                    this.errorMessage = $el.attr('data-validation-error-msg-external-link-not-valid');
                    return false;
                }
                //
            }
            
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------
        
})(jQuery);