/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

(function($) {

    /**
     * Vérfie si une url existe ou non 
     *
     * @access public
     * @param string Url à vérifier
     * @return boolean
     */
    function file_exists(url)
    {
        var http = new XMLHttpRequest();
        http.open('HEAD', url, false);
        http.send();
        
        return http.status != 404 ? true : false;
    }
   
	// --------------------------------------------------------------------

    /**
     * Validation de la création d'un nouveau répertoire
     */
    $.formUtils.addValidator({
        name : 'new_dir',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence du nom du répertoire
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-name-required');
                return false;                                                            
            }
            //

            /**
             * Test des caractères du nom du répertoire
             */
            if (/[^-a-z0-9_]/gi.test(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-chars-not-valid');
                return false;                                                            
            }
            //

            /**
             * Test de l'existence du répertoire
             */
            var url = site3 + $('input[name="dir_path"]').val() + '/' + value;
            if(file_exists(url)) {
                this.errorMessage = $el.attr('data-validation-error-msg-name-exists');
                return false;                                          
            }
            //
                                   
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du changement de nom du fichier
     */
    $.formUtils.addValidator({
        name : 'new_filename',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence du nom du fichier
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-name-required');
                return false;                                                            
            }
            //

            /**
             * Test des caractères du nom du fichier
             */
            if (/[^-a-z0-9_]/gi.test(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-chars-not-valid');
                return false;                                                            
            }
            //

            /**
             * Test de l'existence du fichier
             */
            var url = site3 + $('input[name="dir_path"]').val() + '/' + value + $el.attr('data-ext');
            if(file_exists(url)) {
                this.errorMessage = $el.attr('data-validation-error-msg-name-exists');
                return false;                                          
            }
            //
                                   
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------
        
})(jQuery);