/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

jQuery(function($) { 
    
	// --------------------------------------------------------------------

    /**
     * renvoie la valeur d'un paramètre passé dans une url
     *
     * @param string Nom du paramètre
     * @return string
     */
    function get_param_in_url(name) 
    {
        name = name.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
        var regex = new RegExp("[\\?&]" + name + "=([^&#]*)"),
            results = regex.exec(location.search);
        
        return results === null ? "" : decodeURIComponent(results[1].replace(/\+/g, " "));
    }
    
	// --------------------------------------------------------------------
    
    /**
     * construit et renvoie le groupe d'options qui permet de sélectionner un ou des rédacteurs
     *
     * @param string Identifiant du filtre associé au groupe d'options
     * @param string Intitulé du groupe d'options
     * @return object
     */
    function add_optgroup_menu_by_filter_id(filter_id, label)
    {
        var filter = $('#'+filter_id);
        var select = filter.nextAll('select');        
        var options = select.children().clone();

        return $('<optgroup label="'+label+'" data-filter="'+filter.val()+'" data-name="'+select.attr('name')+'"></optgroup>').append(options);
    }
    
	// --------------------------------------------------------------------
    
    /**
     * construit et renvoie l'option qui permet de sélectionner tous les rédacteurs
     *
     * @return object
     */
    function add_option_menu_for_select_all_writers(lang)
    {
        return  '<option value="0">'+lang.all+'</option>';
    }

	// --------------------------------------------------------------------

    /**
     * construit et renvoie le groupe d'options qui permet de sélectionner un ou des rédacteurs
     *
     * @return object
     */
    function add_optgroup_menu_for_select_writers(lang)
    {
        return  add_optgroup_menu_by_filter_id('filter_1', lang.writers);
    }

	// --------------------------------------------------------------------

    /**
     * construit et renvoie le groupe d'options qui permet de sélectionner un ou des rédacteurs appartenant à un groupe
     *
     * @return object
     */
    function add_optgroup_menu_for_select_writers_by_group(lang)
    {
        var optgroup = add_optgroup_menu_by_filter_id('filter_2', lang.groups);
         
        // Ajout du prefix groupe
        optgroup.children().each(function(i, el) {
            $(this).text(lang.group + ' "' + $(this).text() + '"');
        });
        
        return optgroup;
    }
    
	// --------------------------------------------------------------------
    
    /**
     * construit et renvoie le menu qui permet de sélectionner un rédacteur
     *
     * @param object Formulaire de filtrage des données
     * @return object
     */
    function build_menu_for_select_writers(lang)
    {
        return $('<select name="all_records"></select>').append(
            add_option_menu_for_select_all_writers(lang),
            add_optgroup_menu_for_select_writers(lang),
            add_optgroup_menu_for_select_writers_by_group(lang)
        );
    }
    
	// --------------------------------------------------------------------

    /**
     * Ajoute un formulaire qui permet de rechercher des enregistrements dans la table
     *
     * @return void
     */
    function add_form_for_search_records()
    {
        var form = $('form.data_filtering');
        var lang = form.data('lang');
        
        $('<form style="display:inline" action="'+form.attr('action')+'" method="post"></form>').appendTo('#rdesc')
        .append(
            '<input type="hidden" name="filter" value="0" />',
            build_menu_for_select_writers(lang),
            $(form).find('input[name=search]').eq(0).clone()
        )
        .on('submit', function() {            
            var filter =  $(this).find('option:selected').parent().data('filter') || 0;
            var select_name =  $(this).find('option:selected').parent().data('name') || 'all_records';
          
            $(this).find('input[name=filter]').attr('value', filter);
            $(this).find('select').attr('name', select_name);
        });

        // Sélectionne la première option si pas de rédacteur ou de groupe sélectionné
        if (get_param_in_url('writerid') == '' && get_param_in_url('groupid') == '') {
            $('#rdesc form select option:first').attr('selected', 'selected');    
        }  
     }
    
	// --------------------------------------------------------------------

    /**
     * fonctions à exécuter lors du chargement du script
     *
     * @return void
     */
    function init()
	{        
        add_form_for_search_records();
    }
    //
    
    init(); // initialisation  
});