<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Connect_controller extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();         // Données de langue

 	protected $_errors = array();	     // Tableau contenant les messages d'erreur
    protected $_form_validation = FALSE; // Validation du formulaire  
    protected $_params = array();        // Tableau contenant les données du document postées dans le formulaire   

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        parent :: __construct();
        $this -> load_helper('var_helper');
        $this -> load_helper('url_helper');
        $this -> load_helper('security_helper');
        $this -> load_helper('html_helper');
        $this -> load_library('writer_authentification', NULL, 'writer_auth');

        $this -> _params = Var_helper :: import('params', 'post', array(), array('trim')); // Paramètres postés dans le formulaire
        $this -> _errors = $this -> _set_errors($this -> _params);
        $this -> _form_validation = $this -> _is_valid_form($this -> _errors);
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function index()
    {
        $this -> login();
    }
    
	// --------------------------------------------------------------------

    /*
     * Authentifie et ouvre une session
     *
     * @return void
     */
    public function login()
    {
        $params = $this -> _params;

        if ($this -> _form_validation && $this -> writer_auth -> login($params['name'], $params['password']) === TRUE) {
            Url_helper :: redirect($this -> _config['controller_by_default']['public']); // redirection vers le controller par défaut (voir config)     
        }

        $data = array(
            'form_uri' => ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER,            
            'lang' => $this -> _lang,
            'message' => $this -> _lang['errors_msg']['login_failed'],
            'params' => $this -> _params,
            'errors' => $this -> _errors,
        );
        
        $this -> render('login', $data);
    }
    
	// --------------------------------------------------------------------

    /*
     * Se déconnecte et ferme la session
     *
     * @return void
     */
    public function logout()
    {
        $this -> writer_auth -> logout();
                
        Url_helper :: redirect('connect/login');
    }
    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['connect']); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript">$.formUtils.loadModules("module_logins", "'.ADMR_JS_PATH.'/form-validator/my_modules/");</script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/connect.js"></script>'."\n";

        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        
        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
	 * Cherche et renvoie les erreurs lors de la validation du formulaire
     * 
	 * @access public
     * @return array
	 */	
    private function _set_errors($params)
    {  
        // Récupération des règles de validation des paramètres ainsi que les messages d'erreur associés
        $data = $this -> _set_params_rules($params, $this -> _lang, $this -> _config);
        
        foreach ($data as $field => $errors) {
            $this -> _errors[$field] = '';
            
            if (isset($params[$field])) {
                foreach ($errors as $error) {
                    if (!empty($error['rules']) && empty($this -> _errors[$field])) {
                        $this -> _errors[$field] = $this -> _set_error_message($params[$field], $error['rules'], $error['msg']);
                    }
                }
            }
        }
        
        return $this -> _errors;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    private function _set_params_rules($params, $lang, $config)
    {        
        return array(
            'name' => array(       // Nom (ou pseudo) du rédacteur
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => $lang['form_errors_msg']['name_required']
                ),
                array(
                    'rules' => array(array('Var_helper', 'is_valid_writer_name')),
                    'msg' => $lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes']
                )

            ),
            'password' => array(       // Nouveau mot de passe
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => $lang['form_errors_msg']['password_required']
                )
            )
        );
    }
        
	// --------------------------------------------------------------------

    /**
	 * Renvoie un message d'erreur correspondant à la règle de validation non vérifiée
     * 
	 * @access private
     * @param string Valeur de la variable
     * @param array Règles de validitité de la valeur de la variable
     * @param string Contenu du message d'erreur
     * @return string Code html du message d'erreur
	 */	
    private function _set_error_message($var, $rules, $msg_error)
    {        
        if (empty($_POST)) {    // Formulaire non soumis
            return '';
        }

        $error = '';

        if (! Var_helper :: check_value($var, $rules)) {
            $error .= '&nbsp;&nbsp;'.Html_helper :: addEm($msg_error, array('class' => 'form-error'));
        }
        
        return $error;
    }
    
	// --------------------------------------------------------------------

    /**
	 * Vérifie si le formulaire est valide ou non
     * 
	 * @access protected
     * @param array Tableau contenant les messages d'erreurs
     * @return boolean 
	 */	
    protected function _is_valid_form($errors = array())
    {
        if (empty($_POST)) {    // Formulaire non soumis
            return FALSE;
        }
        
        foreach($errors as $error) {
           if (!empty($error)) {
                return FALSE;
           }
        }
        
        return TRUE;
    }    

	// --------------------------------------------------------------------	// --------------------------------------------------------------------

} // End Class