<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/public_controller.php';
 
class Modify_password_controller extends Public_controller
{
    protected $_lang = array();         // Données de langue
    protected $_writer_rights = array(); // Droits du rédacteur

 	protected $_errors = array();	         // Tableau contenant les messages d'erreur
    protected $_form_validation = FALSE; // Validation du formulaire  
    protected $_params = array(); // Tableau contenant les données du document postées dans le formulaire   
    
    function __construct()
    {
        parent :: __construct();
        
        $this -> load_helper('var_helper');
        $this -> load_helper('url_helper');
        $this -> load_helper('html_helper');
        $this -> load_helper('security_helper');
    
        if (empty($this -> _writer_rights['modify_password'])) {
            Url_helper :: redirect('display_error&type=disallowed');
        }    

        $this -> load_model('rights_model', 'writer');
        
        $this -> _params = Var_helper :: import('params', 'post', array(), array('trim')); // Paramètres postés dans le formulaire

        $this -> _errors = $this -> _set_errors($this -> _params);
        $this -> _form_validation = $this -> _is_valid_form($this -> _errors);     
    }

	// --------------------------------------------------------------------

    public function index()
    {
        if ($this -> _form_validation) {    // Formulaire validé
            $this -> _modify_password($this -> _params['old_pass'], $this -> _params['new_pass']);
        }

        $data = array(
            'lang' => $this -> _lang,
            'writer_rights' => $this -> _writer_rights,
            'message' => ($this -> _form_validation) ? $this -> _lang['msg_recording_success'] : $this -> _lang['msg_recording_fail'],
            'params' => $this -> _params,
            'errors' => $this -> _errors,
        );
        
        $this -> render_page('modify_password', $data);
    }
    
	// --------------------------------------------------------------------

    /**
     * Modifie le mot de passe 
     *
     * @param string Ancien mot de passe
     * @param string Ancien mot de passe
     * @return boolean
     */        
    private function _modify_password($old_pass, $new_pass)
    {
        $writer_rights = $this -> _writer_rights;

        if (empty($old_pass) || empty($new_pass) ) {
            return FALSE;
        }
        
        if ($old_pass == $new_pass) {
            return FALSE;
        }
        
        $pass = Security_helper :: encrypt_password($writer_rights['name'].$new_pass);
       
        return $this -> rights_model -> write($writer_rights['id'], array_merge($writer_rights, array('pass' => $pass)));
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['modify_password']); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {
        return $this -> _lang['infos_page_modify_password'];
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript">$.formUtils.loadModules("module_logins", "'.ADMR_JS_PATH.'/form-validator/my_modules/");</script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/modify_password.js"></script>'."\n";

        $css .= '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        
        return $parent_addons.$js.$css;
    }
        
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    protected function _set_menu_plugin_items()
    {
        return array(
            Plugin_menu_helper :: add_item_for_go_dashboard('password', $this -> _lang),
            Plugin_menu_helper :: add_item_for_disconnect('password', $this -> _lang)
        );
    }

	// --------------------------------------------------------------------

    /**
	 * Cherche et renvoie les erreurs lors de la validation du formulaire
     * 
	 * @access public
     * @return array
	 */	
    private function _set_errors($params)
    {  
        // Récupération des règles de validation des paramètres ainsi que les messages d'erreur associés
        $data = $this -> _set_params_rules($params, $this -> _lang, $this -> _config);
        
        foreach ($data as $field => $errors) {
            $this -> _errors[$field] = '';
            
            if (isset($params[$field])) {
                foreach ($errors as $error) {
                    if (!empty($error['rules']) && empty($this -> _errors[$field])) {
                        $this -> _errors[$field] = $this -> _set_error_message($params[$field], $error['rules'], $error['msg']);
                    }
                }
            }
        }
        
        return $this -> _errors;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    private function _set_params_rules($params, $lang, $config)
    {        
        return array(
            'old_pass' => array(       // Ancien mot de passe
                array(
                    'rules' => array(array($this, '_is_valid_length_pass')),
                    'msg' => $lang['form_errors_msg']['password_length_must_greater_than_6_chars']
                ),
                array(
                    'rules' => array(array($this, '_is_valid_pass')),
                    'msg' => $lang['form_errors_msg']['password_is_not_valid']
                )

            ),
            'new_pass' => array(       // Nouveau mot de passe
                array(
                    'rules' => array(array($this, '_is_valid_length_pass')),
                    'msg' => $lang['form_errors_msg']['password_length_must_greater_than_6_chars']
                )
            ),
            'conf_new_pass' => array(  // Confirmation du nouveau mot de passe
                array(
                    'rules' => array(array($this, '_is_valid_conf_pass['.$params['new_pass'].']')),
                    'msg' => $lang['form_errors_msg']['confirmation_password_not_equal_to_password']
                )
            )

        );
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité de la longueur du mot de passe
	 *
	 * @access	public
	 * @param	string mot de passe
	 * @return	bool
	 */
    function _is_valid_length_pass($pass)
    {
        return (boolean) (Var_helper :: is_required($pass) && Var_helper :: has_min_length($pass, 6));         
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité du mot de passe
	 *
	 * @access	public
	 * @param	string mot de passe
	 * @return	bool
	 */
    function _is_valid_pass($pass)
    {
        $writer_rights = $this -> _writer_rights;
//  die(print_r($writer_rights));
                
        return (boolean) ($writer_rights['pass'] === Security_helper :: encrypt_password($writer_rights['name'].$pass));         
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité de la confirmation du mot de passe
	 *
	 * @access	public
	 * @param	string mot de passe de confirmation
     * @param   string mot de passe à confirmer
	 * @return	bool
	 */
    function _is_valid_conf_pass($str, $writerpass = '')
    {
        return (boolean) ($str === $writerpass);
    } 
        
	// --------------------------------------------------------------------

    /**
	 * Renvoie un message d'erreur correspondant à la règle de validation non vérifiée
     * 
	 * @access private
     * @param string Valeur de la variable
     * @param array Règles de validitité de la valeur de la variable
     * @param string Contenu du message d'erreur
     * @return string Code html du message d'erreur
	 */	
    private function _set_error_message($var, $rules, $msg_error)
    {        
        if (empty($_POST)) {    // Formulaire non soumis
            return '';
        }

        $error = '';

        if (! Var_helper :: check_value($var, $rules)) {
            $error .= '&nbsp;&nbsp;'.Html_helper :: addEm($msg_error, array('class' => 'form-error'));
        }
        
        return $error;
    }
    
	// --------------------------------------------------------------------

    /**
	 * Vérifie si le formulaire est valide ou non
     * 
	 * @access protected
     * @param array Tableau contenant les messages d'erreurs
     * @return boolean 
	 */	
    protected function _is_valid_form($errors = array())
    {
        if (empty($_POST)) {    // Formulaire non soumis
            return FALSE;
        }
        
        foreach($errors as $error) {
           if (!empty($error)) {
                return FALSE;
           }
        }
        
        return TRUE;
    }    

	// --------------------------------------------------------------------
    
} // End Class