<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_CORE_PATH.'/admin_controller.php';

abstract class Admin_manage_docs_controller extends Admin_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get   
    protected $_admin_rights = array(); // Droits du rédacteur

    protected $_addon = FALSE; // Addon
    protected $_doc_infos = array('name' => '', 'type' => '');     // Tableau contenant les informations des documents (nom, type) de guppy
         
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    

    /**
     * contructor
     * 
     * @param array Informations concernant le document sous la forme array("name" => , 'type' => '')
     * @param boolean Addon ou non (optionnel avec comme valeur à FALSE par défaut)
     * @return void
     */
    public function __construct($doc_infos, $addon = FALSE)
    {
        parent :: __construct();

        $this -> _doc_infos = $this -> _set_doc_infos($doc_infos);
        $this -> _addon = $addon;        
            
        if (!empty($this -> _addon)) {
            $this -> load_addon_helper($this -> _addon, 'manage_'.$this -> _doc_infos['name'].'_helper', $this -> _admin_rights);
        } else {
            $this -> load_helper('manage_'.$this -> _doc_infos['name'].'_helper', $this -> _admin_rights);
        }        
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */
    public function index()
    {
        $this -> manage();
    }

	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        $this -> {'manage_'.$this -> _doc_infos['name'].'_helper'} -> manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $this -> {'manage_'.$this -> _doc_infos['name'].'_helper'} -> search();
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return $this -> {'manage_'.$this -> _doc_infos['name'].'_helper'} -> set_title_page(); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @access public
     * @return string
	 */	
    public function set_header_addons()
    {
        $header_addons = parent :: set_header_addons();
        $header_addons .= $this -> {'manage_'.$this -> _doc_infos['name'].'_helper'} -> set_header_addons();
         
        return $header_addons;
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {		
        return $this -> {'manage_'.$this -> _doc_infos['name'].'_helper'} -> set_infos_page_content();
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    protected function _set_menu_plugin_items()
    {
        return $this -> {'manage_'.$this -> _doc_infos['name'].'_helper'} -> set_menu_plugin_items();
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si le type du document est autorisé ou non
     *
     * @param integer Identifiant du rédacteur à gérer
     * @return boolean
     */
    protected function _set_doc_infos($doc_infos)
    {
        settype($doc_infos, 'array');
        
        if (empty($doc_infos['type']) || empty($doc_infos['name'])) {     
            die('ERROR : vous devez définir le type et le nom du document dans un tableau sous la forme array("type" => , "name" => )');
        }
        
        return $this -> _doc_infos = $doc_infos;          
    }

	// --------------------------------------------------------------------
	
} //End of Class