<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */
require ADMR_CORE_PATH.'/php_compatibility.php';

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */    
    private static $instance; // Contient l'instance du controller
    
    protected $_vars = array();
    protected $_config = array();
    protected $_lang = array();
    protected $_layout = '';
    protected $_models = array(); // Tableau contenant la liste des modèles chargés
    protected $_libraries = array(); // Tableau contenant la liste des librairies chargées
    protected $_helpers = array(); // Tableau contenant la liste des helpers chargés

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */   
    public function __construct()
    {
        self :: $instance =& $this;

        $this -> set_lang();
        $this -> set_config();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    /**
     * Renvoie l'instance de la class Controller
     *
     * @return object
     */
	public static function &get_instance()
	{
		return self :: $instance;
	}

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie les ajouts à placer dans le <head> de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */    
    public function set_header_addons()
    {
/*        $class_name = strtolower(get_class($this));
        $css = '';
        $js = '';
      
        if (is_file(ADMR_CSS_PATH.'/'.$class_name.'.css')) {
            $css .= '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/'.$class_name.'.css">'."\n";    
        }
        
        if (is_file(ADMR_JS_PATH.'/'.$class_name.'.js')) {
            $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/'.$class_name.'.js"></script>'."\n";    
        }
*/        
        return '';    
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return 'titre de la page';   
    }    

	// --------------------------------------------------------------------

    /**
     * Définit les données à faire passer à la vue
     *
     * @param array Données à faire passer à la vue
     * @return void
     */    
    public function set_vars($data = array())
    {
        $this -> _vars = array_merge($this -> _vars, $data);    
    }

	// --------------------------------------------------------------------

    /**
     * Définit un layout
     *
     * @param array Nom du fichier contenant le layout
     * @return void
     */    
    public function set_layout($filename)
    {
        $this -> _layout = $filename;    
    }

	// --------------------------------------------------------------------

    /**
     * Définit les données de configuration
     *
     * @param array Données à faire passer à la vue
     * @return void
     */    
    public function set_config()
    {
        require ADMR_CONFIGS_PATH.'/config.php'; // Config plugin
        require CONFIGREP.'config.inc'; // Config Guppy
        
        $this -> _config = array_merge($ADMR_config,
            array('lang' => $lang),
            array('user' => $user),
            array('site' => $site),
            array('urlrw' => $urlrw),
            array('page' => $page)
        );
    }

	// --------------------------------------------------------------------

    /**
     * Définit les données de langue
     *
     * @param array Données à faire passer à la vue
     * @return void
     */    
    public function set_lang()
    {
        $ADMR_lang = array();
        $filename = is_file(ADMR_LANGUAGES_PATH.'/'.ADMR_LNG.'.php') ? ADMR_LNG : 'en';

        require ADMR_LANGUAGES_PATH.'/'.$filename.'.php';
     
        $this -> _lang = $ADMR_lang;
    }

	// --------------------------------------------------------------------

    /**
     * charge des données de configuration
     *
     * @param string Nom du fichier de configuration
     * @param string Chemin du répertoire contenant le fichier de configuration
     * @return void
     */    
    public function load_config($filename, $dir_path = ADMR_CONFIGS_PATH)
    {
        $this -> load_helper('array_helper');
                    
        $ADMR_config = array();
        
        if (empty($dir_path) || !is_dir($dir_path)) {
            $dir_path = ADMR_CONFIGS_PATH; 
        }

        if (is_file($dir_path.'/'.$filename.'_config.php')) {
            require $dir_path.'/'.$filename.'_config.php';    
        }

        $this -> _config = Array_helper :: array_merge_recursive($this -> _config, $ADMR_config);    
    }

	// --------------------------------------------------------------------

    /**
     * charge des données de configuration d'un addon
     *
     * @param string Nom du fichier de configuration
     * @return void
     */    
    public function load_addon_config($addon_name)
    {        
        $this -> load_config($addon_name, ADMR_ADDONS_PATH.'/'.$addon_name.'/configs');
    }

	// --------------------------------------------------------------------

    /**
     * Charge des données de langue
     *
     * @param string Nom du fichier de langue
     * @param string Chemin du répertoire contenant le fichier de langue
     * @return void
     */    
    public function load_lang($filename, $dir_path = ADMR_LANGUAGES_PATH)
    {        
        $this -> load_helper('array_helper');
                    
        $ADMR_lang = array();

        if (empty($dir_path) || !is_dir($dir_path)) {
            $dir_path = ADMR_LANGUAGES_PATH; 
        }
        
        $filename = is_file($dir_path.'/'.$filename.'_'.ADMR_LNG.'.php') ? $filename.'_'.ADMR_LNG : $filename.'_en';

        require $dir_path.'/'.$filename.'.php';
        
        $this -> _lang = Array_helper :: array_merge_recursive($this -> _lang, $ADMR_lang);                            
    }

	// --------------------------------------------------------------------

    /**
     * Charge des données de langue d'un addon
     *
     * @param string Nom du fichier de langue
     * @return void
     */    
    public function load_addon_lang($addon_name)
    {        
        $this -> load_lang($addon_name, ADMR_ADDONS_PATH.'/'.$addon_name.'/languages');
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie les données de langue
     *
     * @param string Item de langue
     * @return array Tableau contenant les données de langue
     */    
    public function get_lang($item = '')
    {        
        return isset($this -> _lang[$item]) ? $this -> _lang[$item] : $this -> _lang;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Définit ou écrase un item de configuration
	 *
	 * @access	public
	 * @param	string|array the config item key or array($item => $value)
	 * @param	string	the config item value (not necessary if item is an array)
	 * @return	void
	 */
	public function set_config_item($item, $value = '')
	{
		if (is_array($item)) {
            $this -> load_helper('array_helper');      
            $this -> _config = Array_helper :: array_merge_recursive($this -> _config, $item);  
		} else {
            $this -> _config[$item] = $value; 
		}
	}

	// --------------------------------------------------------------------

    /**
     * Renvoie les données de configuration
     *
     * @param string Item de configuration
     * @return array Tableau contenant les données de configuration
     */    
    public function get_config($item = '')
    {        
        return isset($this -> _config[$item]) ? $this -> _config[$item] : $this -> _config;
    }

	// --------------------------------------------------------------------

    /**
     * Affiche ou renvoie le contenu de la vue
     *
     * @param string Nom du fichier de la vue
     * @param array Données à faire passer à la vue
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    public function render($filename, $data = array(), $return = FALSE)
    {
        unset($_GET);

        if (! is_file(ADMR_VIEWS_PATH.'/'.$filename.'_view.php')) {
            die('ERROR : the file "'.ADMR_VIEWS_PATH.'/'.$filename.'_view.php" doesn\'t exist');    
        }
        
        if (!empty($data) && is_array($data)) {
            $this -> set_vars($data);    
        }
      
        extract($this -> _vars);

        ob_start();
      
        require ADMR_VIEWS_PATH.'/'.$filename.'_view.php';
        
        $content_for_layout = ob_get_clean();

		if ($this -> _layout == FALSE || $return === TRUE) {
            if ($return === TRUE) {
                return $content_for_layout;
            } else {
                echo $content_for_layout;
            }	
		} else {
            require ADMR_VIEWS_PATH.'/'.$this -> _layout.'_view.php';  
		}
    }

	// --------------------------------------------------------------------

    /**
     * charge un model
     *
     * @param string Nom du model
     * @param mixed Paramètres du model
	 * @param string an optional object name
     * @param string Chemin du répertoire contenant le fichier
     * @return object Instance de l'objet créé
     */    
    public function load_model($model, $params = NULL, $object_name = NULL, $dir_path = ADMR_MODELS_PATH)
    {
        if (empty($dir_path) || ! is_file($dir_path.'/'.strtolower($model).'.php')) {
            return FALSE;    
        }
       
        $object_name = empty($object_name) ? $model : $object_name;

//		if ( ! in_array($object_name, $this -> _models, TRUE) && !empty($dir_path) && is_file($dir_path.'/'.strtolower($model).'.php')) {
		if ( ! in_array($object_name, $this -> _models, TRUE)) {
            require_once $dir_path.'/'.strtolower($model).'.php';
            
            $model = ucfirst($model);
           
            $this -> $object_name = empty($params)? new $model : new $model($params);
            $this -> _models[] = $object_name;  // Enregistrement du nom de l'instance du model dans le tableau  
		}
                      
        return $this -> $object_name;
    }

	// --------------------------------------------------------------------

    /**
     * charge un model d'un addon
     *
     * @param string Nom du répertoire de l'addon
     * @param string Nom du model
     * @param mixed Paramètres du model (optionnels)
	 * @param string an optional object name
     * @return object Instance de l'objet créé
     */    
    public function load_addon_model($addon_name, $model, $params = NULL, $object_name = NULL)
    {
        return $this -> load_model($model, $params, $object_name, $dir_path = ADMR_ADDONS_PATH.'/'.$addon_name.'/models');
    }

	// --------------------------------------------------------------------

    /**
     * charge des models
     *
     * @param array Nom des fichiers des models
     * @return void
     */    
    public function load_models($models = array())
    {
		if (is_array($models)) {
			foreach ($models as $model) {
				$this -> load_model($model);
			}
		}
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * charge une librairie
     *
	 * @param	string	the name of the class
	 * @param	mixed	the optional parameters
	 * @param	string	an optional object name
     * @param   string Chemin du répertoire contenant le fichier
	 * @return	void
     */    
    public function load_library($library, $params = NULL, $object_name = NULL, $dir_path = ADMR_LIBRARIES_PATH)
    {        
        if (empty($dir_path) || ! is_file($dir_path.'/'.strtolower($library).'.php')) {
            return FALSE;    
        }

        $object_name = empty($object_name) ? $library : $object_name;
        
//		if ( ! in_array($object_name, $this -> _libraries, TRUE) && !empty($dir_path) && is_file($dir_path.'/'.strtolower($library).'.php')) {
		if ( ! in_array($object_name, $this -> _libraries, TRUE)) {
            require_once $dir_path.'/'.strtolower($library).'.php';
            
            $library = ucfirst($library);
            
            $this -> $object_name = empty($params)? new $library : new $library($params);
            $this -> _libraries[] = $object_name;  // Enregistrement du nom de l'instance du model dans le tableau  
		}
                      
        return $this -> $object_name;
    }

	// --------------------------------------------------------------------

    /**
     * charge une librairie d'un addon
     *
     * @param string Nom du répertoire de l'addon
     * @param string Nom de la class
	 * @param	string	an optional object name
     * @return void
     */    
    public function load_addon_library($addon_name, $library, $params = NULL, $object_name = NULL)
    {
        return $this -> load_library($library, $params, $object_name, $dir_path = ADMR_ADDONS_PATH.'/'.$addon_name.'/libraries');
    }

	// --------------------------------------------------------------------

    /**
     * charge des models
     *
     * @param array Nom des fichiers des libraries
     * @return void
     */    
    public function load_libraries($libraries = array())
    {
		if (is_array($libraries)) {
			foreach ($libraries as $library) {
				$this -> load_library($library);
			}
		}
        
        return;
    }

	// --------------------------------------------------------------------

    /**
     * charge un helper
     *
     * @param string Nom du helper
     * @param mixed  Paramètres passés lors de l'instanciation du helper (optionnel)
	 * @param string an optional object name
     * @param   string Chemin du répertoire contenant le fichier
	 * @return	void
     */    
    public function load_helper($helper, $params = NULL, $object_name = NULL, $dir_path = ADMR_HELPERS_PATH)
    {        
        if (empty($dir_path) || ! is_file($dir_path.'/'.strtolower($helper).'.php')) {
            return FALSE;    
        }

        $object_name = empty($object_name) ? $helper : $object_name;
        
//		if ( ! in_array($object_name, $this -> _libraries, TRUE) && !empty($dir_path) && is_file($dir_path.'/'.strtolower($helper).'.php')) {
		if ( ! in_array($object_name, $this -> _helpers, TRUE)) {
            require_once $dir_path.'/'.strtolower($helper).'.php';
            
            $helper = ucfirst($helper);
            
            $this -> $object_name = empty($params)? new $helper : new $helper($params);
            $this -> _helpers[] = $object_name;  // Enregistrement du nom de l'instance du model dans le tableau  
		}
                    
        return $this -> $object_name;
    }
/*
    public function load_helper($helper, $dir_path = ADMR_HELPERS_PATH)
    {        
        if ( ! in_array($helper, $this -> _helpers, TRUE) && !empty($dir_path) && is_file($dir_path.'/'.strtolower($helper).'.php')) {
            require_once $dir_path.'/'.strtolower($helper).'.php';
            $this -> _helpers[] = $helper;  // Enregistrement du nom de l'helper dans le tableau            
        }
        
        return;
    }
*/
	// --------------------------------------------------------------------

    /**
     * charge un helper dans le répertoire helpers/admin
     *
     * @param string Nom du helper
     * @param mixed  Paramètres passés lors de l'instanciation du helper (optionnel)
	 * @param string an optional object name
     * @return void
     */    
    public function load_admin_helper($helper, $params = NULL, $object_name = NULL)
    {
        return $this -> load_helper($helper, $params, $object_name, $dir_path = ADMR_HELPERS_PATH.'/admin');
    }

	// --------------------------------------------------------------------

    /**
     * charge un helper dans le répertoire helpers/public
     *
     * @param string Nom du helper
     * @param mixed Paramètres passés lors de l'instanciation du helper (optionnel)
	 * @param string an optional object name
     * @return void
     */    
    public function load_public_helper($helper, $params = NULL, $object_name = NULL)
    {
        return $this -> load_helper($helper, $params, $object_name, $dir_path = ADMR_HELPERS_PATH.'/public');
    }

	// --------------------------------------------------------------------

    /**
     * charge un helper d'un addon
     *
     * @param string Nom du répertoire de l'addon
     * @param string Nom de la class
     * @param mixed Paramètres passés lors de l'instanciation du helper (optionnel)
	 * @param string an optional object name
     * @return void
     */    
    public function load_addon_helper($addon_name, $helper, $params = NULL, $object_name = NULL)
    {
        return $this -> load_helper($helper, $params, $object_name, $dir_path = ADMR_ADDONS_PATH.'/'.$addon_name.'/helpers');
    }

	// --------------------------------------------------------------------

    /**
     * charge un helper d'un addon dans le répertoire helpers/admin
     *
     * @param string Nom du répertoire de l'addon
     * @param string Nom de la class
     * @param mixed Paramètres passés lors de l'instanciation du helper (optionnel)
	 * @param string an optional object name
     * @return void
     */   
    public function load_addon_admin_helper($addon_name, $helper, $params = NULL, $object_name = NULL)
    {
        return $this -> load_helper($helper, $params, $object_name, $dir_path = ADMR_ADDONS_PATH.'/'.$addon_name.'/helpers/admin');
    }

	// --------------------------------------------------------------------

    /**
     * charge un helper d'un addon dans le répertoire helpers/public
     *
     * @param string Nom du répertoire de l'addon
     * @param string Nom de la class
     * @param mixed Paramètres passés lors de l'instanciation du helper (optionnel)
	 * @param string an optional object name
     * @return void
     */    
    public function load_addon_public_helper($addon_name, $helper, $params = NULL, $object_name = NULL)
    {
        return $this -> load_helper($helper, $params, $object_name, $dir_path = ADMR_ADDONS_PATH.'/'.$addon_name.'/helpers/public');
    }

/*
    public function load_addon_helper($addon_name, $helper)
    {
        $this -> load_helper($helper, $dir_path = ADMR_ADDONS_PATH.'/'.$addon_name.'/helpers');
        
        return;
    }
*/
	// --------------------------------------------------------------------

    /*
     * charge des helpers
     *
     * @param array the name of the clasess helper
     * @return void
     */    
/*    public function load_helpers($helpers = array(), $dir_path = ADMR_HELPERS_PATH)
    {
		if (is_array($helpers)) {
			foreach ($helpers as $helper) {
				$this -> load_helper($helper, $dir_path);
			}
		}
        
        return;
    }*/

	// --------------------------------------------------------------------

}