<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_HELPERS_PATH.'/date_helper.php';

class Model
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */    
    protected static $_doc_types = array(  // Définitions des types de documents
        TYP_ART     => array('name' => 'articles',    'type' => TYP_ART,     'path' => 'articles.php'),
        TYP_NEWS    => array('name' => 'news',        'type' => TYP_NEWS,    'path' => 'news.php'),
        TYP_DNLOAD  => array('name' => 'downloads',   'type' => TYP_DNLOAD,  'path' => 'download.php'),
        TYP_BANNER  => array('name' => 'banners',     'type' => TYP_BANNER,  'path' => ''),
        TYP_BLOG    => array('name' => 'blog',        'type' => TYP_BLOG,    'path' => 'blog.php'),  
        TYP_LINKS   => array('name' => 'links',       'type' => TYP_LINKS,   'path' => 'links.php'),
        TYP_THINK   => array('name' => 'thinks',      'type' => TYP_THINK,   'path' => ''),
        TYP_FAQ     => array('name' => 'faq',         'type' => TYP_FAQ,     'path' => 'faq.php'),
        TYP_MENUBOX => array('name' => 'boxmenus',    'type' => TYP_MENUBOX, 'path' => ''),
        TYP_FREEBOX => array('name' => 'freeboxes',   'type' => TYP_FREEBOX, 'path' => ''),
        TYP_PHOTO   => array('name' => 'photoramas',  'type' => TYP_PHOTO,   'path' => 'photorama.php'),
        TYP_AGENDA  => array('name' => 'agenda',      'type' => TYP_AGENDA,  'path' => 'agenda.php'),
        TYP_NWL     => array('name' => 'newsletters', 'type' => TYP_NWL,     'path' => 'newsletter.php'),
        TYP_OPTMENU => array('name' => 'menuitems',   'type' => TYP_OPTMENU, 'path' => ''),
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */   
    public function __construct()
    {
        // NOTHING
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * récupére les types de documents
     * 
	 * @access public
     * @param mixed Tableau contenant les types de documents à récupérer
	 * @return array tableau contenant les types de documents enregistrés
     *               sous la forme array('type' => array('type' => '', 'name' => '', 'path' => ''))
	 */
    function get_doc_types($types = array())
    {
        return self :: get_doc_infos_by_type($types);
    }

	// --------------------------------------------------------------------

	/**
	 * ajoute un nouveau type de documents
     * 
	 * @access public
     * @param array Tableau contenant le type de documents à ajouter sous la forme array('type' => array('type' => '', 'name' => '', 'path' => ''))
	 * @return array tableau contenant les types de documents enregistrés
     *               sous la forme array('type' => array('type' => '', 'name' => '', 'path' => ''))
	 */
    public static function add_doc_type($doc_type = array())
    {
        self :: $_doc_types = array_merge(self :: $_doc_types, $doc_type);
    }

	// --------------------------------------------------------------------

    /**
     * Tri les types de documents
     * 
     * @param string Option de tri
     * @return array Données triées
     */
    public function sort_doc_types_by_key($data, $sort_option)
    {       
        if(empty($data)) {
            return $data;
        }

        // Tableau en colonne
        foreach ($data as $key => $row) {
            $type[$key] = $row['type'];
            $name[$key] = $row['name'];
            $path[$key] = $row['path'];
        }
        //
        
        switch ($sort_option) {
			case 'name_asc' :
				array_multisort(array_map('strtolower', $name), SORT_STRING, SORT_ASC, $data);
				break;
			case 'name_desc' :
				array_multisort(array_map('strtolower', $name), SORT_STRING, SORT_DESC, $data);
				break;
			case 'type_asc' :
				array_multisort($type, SORT_STRING, SORT_ASC, $data);
				break;
			case 'type_desc' :
				array_multisort($type, SORT_STRING, SORT_DESC, $data);
				break;
			default :
				array_multisort($type, SORT_STRING, SORT_ASC, $data);
		}	
	
		return $data;
    }

	// --------------------------------------------------------------------

	/**
	 * récupére les informations (type, name, path) des documents pris en charge
     * 
	 * @access public
     * @param mixed Tableau contenant les noms des documents à récupérer (vide par défaut)
	 * @return array tableau contenant les informations des documents enregistrés (tous les documents par défaut)
     *               sous la forme array('name' => array('type' => '', 'name' => '', 'path' => ''))
 	 */
    public static function get_doc_infos_by_name($names = array())
    {
        $doc_infos = array();

        foreach (self :: $_doc_types as $key => $value) {
            $doc_infos[$value['name']] =  self :: $_doc_types[$key];   
        }    

        if (empty($names)) {
            return $doc_infos;    
        }
        else {
            if (is_array($names)) {
                return array_intersect($doc_infos, array_flip($names));               
            }
            else {
                return isset($doc_infos[$names]) ? $doc_infos[$names] : array();
            }           
        }
                
        return array();        
    }

	// --------------------------------------------------------------------

	/**
	 * récupére les informations (type, name, path) des documents pris en charge
     * 
	 * @access public
     * @param mixed Tableau contenant les types des documents à récupérer (vide par défaut)
	 * @return array tableau contenant les informations des documents enregistrés (tous les documents par défaut)
     *               sous la forme array('type' => array('type' => '', 'name' => '', 'path' => ''))
 	 */
    public static function get_doc_infos_by_type($types = array())
    {
        if (empty($types)) {
            $doc_infos = self :: $_doc_types;
        } else {
            if (is_array($types)) {
                $doc_infos = array();
                foreach($types as $type) {
                    if (isset(self :: $_doc_types[$type])) {
                        $doc_infos[$type] = self :: $_doc_types[$type];    
                    }                       
                }
            } else {
                $doc_infos = isset(self :: $_doc_types[$types]) ? self :: $_doc_types[$types] : self :: $_doc_types;    
            }
        }

        return $doc_infos;    
    }

	// --------------------------------------------------------------------

	/**
	 * récupére les informations (type, name, path) de tous les documents pris en charge
     * 
	 * @access public
	 * @return array tableau contenant les informations de tous documents enregistrés (tous les documents par défaut)
     *               sous la forme array('type' => array('type' => '', 'name' => '', 'path' => ''))
 	 */
    public static function get_all_docs_infos()
    {
        return self :: $_doc_types;;    
    }

	// --------------------------------------------------------------------
    
}