<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/public_controller.php';

abstract class Public_add_writers_docs_controller extends Public_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get   
    protected $_writer_rights = array(); // Droits du rédacteur
    protected $_doc_id = 0; // Identifiant du document à gérer
    protected $_writer_managed_id = 0; // Identifiant du rédacteur à gérer

    protected $_addon = FALSE; // Addon
    protected $_doc_infos = array('name' => '', 'type' => '');     // Tableau contenant les informations des documents (nom, type) de guppy
         
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    
    /**
     * contructor
     * 
     * @param array Informations concernant le document sous la forme array("name" => , 'type' => '')
     * @param boolean Addon ou non (optionnel avec comme valeur à FALSE par défaut)
     * @return void
     */
    public function __construct($doc_infos, $addon = FALSE)
    {
        parent :: __construct();

        $this -> load_library('writers_managed', parent :: get_writer_id());
        
        $this -> _doc_infos = $this -> _set_doc_infos($doc_infos);
        $this -> _addon = $addon;        
        $this -> _writer_managed_id = Var_helper :: import('writerid', '', 0, array('trim'), array(array('Var_helper', 'is_digit')));
        $this -> _doc_id = Var_helper :: import('id', 'POST_GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));      
        // Redéfinition des droits pour gérer les documents du rédacteur géré
        $this -> _writer_rights = $this -> writers_managed -> set_rights_for_manage_docs($this -> _writer_managed_id, $this -> _get_writer_docnames()); 
                
        if (empty($this -> _addon)) {
            $this -> load_helper('add_writers_'.$this -> _doc_infos['name'].'_helper', $this -> _writer_rights);    
        } else {
            $this -> load_addon_helper($this -> _addon, 'add_writers_'.$this -> _doc_infos['name'].'_helper', $this -> _writer_rights); 
        }       

        /**
         * Controle de sécurité
         */
        if (!$this -> _is_allowed_access()) {
            Url_helper :: redirect('display_error&type=disallowed');
        }        
        //
    }
    
    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * édite ou ajoute un enregistrement
     * 
     * @access public
	 * @return string code html
	 */	
    public function index()
    {
        return $this -> {'add_writers_'.$this -> _doc_infos['name'].'_helper'} -> index();
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        $addon = $this -> _addon;
        $writer_rights = $this -> _writer_rights;
        $doc_infos = $this -> _doc_infos;
               
        if ($addon === FALSE) {
            $controller = 'manage_writers_docs';
            $title  = 'manage_docs_created_by_writer_%s';          
        } else {
            $controller = 'addons/'.$doc_infos['name'].'/manage_addons_writers_'.$doc_infos['name'];
            $title  = 'manage_'.$doc_infos['name'].'_docs_created_by_writer_%s';
        }
        
        $href = Url_helper :: build_uri(
            $params = array(
                'writerid' => $writer_rights['id'],
                'idpg'     => Var_helper :: import('idpg', '', 1, array('trim'), array(array('Var_helper', 'is_digit'))),
                'doctype'  => trim(Var_helper :: import('doctype', '', NULL, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))), '-'),
                'sort'     => Var_helper :: import('sort', '', $this -> _config['sort_option_by_default'], array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))),
            ),
            $basehref = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.$controller
        );
        
        return '<a href="'.$href.'">'.ucfirst(sprintf($this -> _lang[$title], $writer_rights['name'])).'</a>';
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @access public
     * @return string
	 */	
    public function set_header_addons()
    {
        $header_addons = parent :: set_header_addons();
        $header_addons .= $this -> {'add_writers_'.$this -> _doc_infos['name'].'_helper'} -> set_header_addons();
         
        return $header_addons;
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {		
        return $this -> {'add_writers_'.$this -> _doc_infos['name'].'_helper'} -> set_infos_page_content();
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    protected function _set_menu_plugin_items()
    {
        return array();
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si le type du document est autorisé ou non
     *
     * @param integer Identifiant du rédacteur à gérer
     * @return boolean
     */
    protected function _set_doc_infos($doc_infos)
    {
        settype($doc_infos, 'array');
        
        if (empty($doc_infos['type']) || empty($doc_infos['name'])) {     
            die('ERROR : vous devez définir le type et le nom du document dans un tableau sous la forme array("type" => , "name" => )');
        }
        
        return $this -> _doc_infos = $doc_infos;          
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si l'accès est autorisé ou non
     *
     * @param object Instance de la classe qui gère les rédacteurs gérés par un super rédacteur
     * @param array Droits du rédacteur géré
     * @param integer Id du document à éditer
     * @param array Tableau contenant les infos (type et nom) du document à éditer
     * @return boolean
     */
    protected function _is_allowed_access()
    {
        $doc_id = $this -> _doc_id;
        $writer_rights = $this -> _writer_rights;
        $doc_infos = $this -> _doc_infos;
     
        if (!$this -> _is_allowed_writer($writer_rights['id'])
            || !$this -> _is_allowed_doc_type($doc_infos['type'])
            || (empty($doc_id) && empty($writer_rights[$doc_infos['name'].'_add']))   // Mode ajout
            || (!empty($doc_id) && empty($writer_rights[$doc_infos['name'].'_edit'])) // Mode édition
        )
        {     
            return FALSE;
        }
        
        return TRUE;          
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si le rédacteur à gérer est autorisé ou non
     *
     * @param integer Identifiant du rédacteur à gérer
     * @return boolean
     */
    protected function _is_allowed_writer($writer_id)
    {
        if (!$this -> writers_managed -> is_writer_managed($writer_id)) {     
            return FALSE;
        }
        
        return TRUE;          
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si le type du document est autorisé ou non
     *
     * @param string Type du document à éditer
     * @return boolean
     */
    protected function _is_allowed_doc_type($doc_type)
    {        
        return empty($this -> _addon) ? $this -> writers_managed -> is_doc_type_allowed($doc_type) : $this -> writers_managed -> is_addons_doc_type_allowed($doc_type);
    }

	// --------------------------------------------------------------------

    /**
     * retourne tous les noms des documents du rédacteur à gérer
     *
     * @param integer Identifiant du rédacteur à gérer
     * @return boolean
     */
    protected function _get_writer_docnames()
    {
        $this -> load_helper('array_helper');
        $docs = Model :: get_doc_infos_by_type();
        
        $docnames = Array_helper :: array_column($docs, 'name');
        
        if (!in_array($this -> _doc_infos['name'], $docnames)) {
            $docnames[] = $this -> _doc_infos['name'];
        }
        
        return $docnames;          
    }

	// --------------------------------------------------------------------

} //End of Class