<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_doc_helper.php';

class Add_photoramas_helper extends Add_doc_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  

    protected $_writer_rights = array(); // Droits du rédacteur
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct($writer_rights = array())
    {
        parent :: __construct(TYP_PHOTO, $writer_rights);
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
    public function set_infos_page_content()
    {		
        return parent :: set_infos_page_content();
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        return parent :: set_menu_plugin_items();         
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
//        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/public_add_record.js"></script>'."\n";
        
        $css = '';
//        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/public_add_record.css" />'."\n";

        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
	 * Crée un nouvel enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return integer Identifiant de l'enregistrement créé
	 */
    protected function _insert_record($record)
    {
        $record['id'] = parent :: _insert_record($record);
        
        if ($this -> _create_photorama_dirs($record['id'])) {
            $this -> _create_photorama_params_file($record['id']);
            $this -> _create_photorama_diapos_index_file($record['id']);    
        }                        
    
        return $record['id'];    
    }

	// --------------------------------------------------------------------

    /**
	 * Crée les répertoires (gal_XX et vgnt) du photorama dans la répertoire photo
     * 
	 * @access protected
     * @param integer Id du photorama
     * @return boolean Réussite ou échec de la création 
	 */
    private function _create_photorama_dirs($record_id)
    {
        $this -> CI -> load_helper('dir_helper');
        
        $dir_path = PHOTOREP.'gal_'.$record_id;
        
        if (Dir_helper :: create_dir($dir_path)) {
            $dir_thumbs_path = $dir_path.'/vgnt';
            Dir_helper :: create_dir($dir_thumbs_path);
            
            return TRUE;
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
	 * Crée le fichier contenant les paramètres du photorama
     * 
	 * @access protected
     * @param integer Id du photorama
     * @return boolean Réussite ou échec de la création 
	 */
    private function _create_photorama_params_file($record_id)
    {
        $this -> CI -> load_model('photoramas_params_model');
        
        return $this -> CI -> photoramas_params_model -> create($record_id);
    }

	// --------------------------------------------------------------------

    /**
	 * Crée le fichier contenant les données des diapos enregistrées dans le photorama
     * 
	 * @access protected
     * @param integer Id du photorama
     * @return boolean Réussite ou échec de la création 
	 */
    private function _create_photorama_diapos_index_file($record_id)
    {
        $this -> CI -> load_model('photoramas_diapos_model');
        
        return $this -> CI -> photoramas_diapos_model -> create($record_id);
    }
    
	// --------------------------------------------------------------------

    /**
	 * Met à jours les données de l'enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return void
	 */
    protected function _update_record($record)
    {
        parent :: _update_record($record);

        $this -> CI -> load_model($this -> _doc_infos['name'].'_params_model'); // Model du type de document        
        
        $this -> CI -> {$this -> _doc_infos['name'].'_params_model'} -> update($record); // Guppy
    
        return TRUE;    
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données du document
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    protected function _get_record_data($record_id)
    {
        $this -> CI -> load_model($this -> _doc_infos['name'].'_params_model'); // Model du type de document                      

        return  array_merge(parent :: _get_record_data($record_id), $this -> CI -> {$this -> _doc_infos['name'].'_params_model'} -> read($record_id));       
    }

	// --------------------------------------------------------------------

    /**
	 * définit et renvoie les règles de validation des paramètres du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifer lors de la validation
     * @return array Tableau contenant les règles de validation des paramètres ainsi que les messages d'erreur associés 
     * sous la forme suivante : array(param1 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                                param2 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                               ...
     *                          )
	 */	
    protected function _get_form_params_rules($params)
    {
        return array_merge(
            parent :: _get_form_params_rules($params),
            $this -> CI -> {$this -> _doc_infos['name'].'_params_model'} -> set_params_rules($params, $this -> _lang, $this -> _config)
        );
    }


    
} // End of class