<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

abstract class Add_record_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration  
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        $this -> CI =& Controller :: get_instance();

        $this -> CI -> load_helper('var_helper');
        $this -> CI -> load_helper('html_helper');
        $this -> CI -> load_helper('url_helper');
        $this -> CI -> load_helper('security_helper');
        $this -> CI -> load_helper('dir_helper');
        $this -> CI -> load_helper('plugin_menu_helper');
        $this -> CI -> load_helper('editor_helper');
        $this -> CI -> load_helper('params_rules_helper');
        $this -> CI -> load_helper('private_groups_helper');
        
        /**
         * Déclaration des variables
         */
        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        $this -> _record_id = $this ->_set_record_id();
   //     $this -> _record_id = Var_helper :: import('id', 'POST_GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));
        $this -> _record_data = $this -> _get_record_data($this -> _record_id);
        $this -> _form_params = $this -> _set_form_params();
        $this -> _form_errors = $this -> _set_form_errors($this -> _form_params);
        $this -> _form_validation = $this -> _is_valid_form($this -> _form_errors);
        //
       
        //var_dump($this -> _form_params); // Debug
        //var_dump($this -> _form_errors); // Debug        
    }

	// --------------------------------------------------------------------

    public function index()
    {
        $this -> _add_record();

        $data = array(
            'lang' => $this -> _lang,
            'config' => $this -> _config,
            'validation' => $this -> _form_validation,
            'message' => ($this -> _form_validation) ? $this -> _lang['msg_recording_success'] : $this -> _lang['msg_recording_fail'],
            'form_url' => $this -> _build_form_action_content(),
            'token' => Security_helper :: create_token('add_record'),
            'params' => $this -> _form_params,
            'errors' => $this -> _form_errors,
        );
        
        $data = array_merge($data, $this -> _add_more_data_for_add_record_view());
        
        $this -> CI -> render_page($this -> _get_layout_for_add_record_view(), $data);
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le contenu de l'attribut action du formulaire
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_form_action_content()
    {
        return Url_helper :: build_uri(array('id' => $this -> _record_id));
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires pour la vue sous la forme
     * array(key => value)
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_more_data_for_add_record_view()
    {
        return array();    
    }

	// --------------------------------------------------------------------

    /**
	 * Définit le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    abstract protected function _get_layout_for_add_record_view();

	// --------------------------------------------------------------------

    /**
	 * Ajoute ou modifie un enregistrement
     * 
	 * @access protected
     * @return boolean
	 */	
    protected function _add_record()
    {
        if ($this -> _form_validation) {    // Formulaire soumis et validé                   

            $this -> _add_more_action_before_adding_record(); // Autres actions à effectuer avant l'ajout ou la mise à jour (optionnel)

            /**
    		 * Ecriture dans la base de donnée
    		 */
    		if (empty($this -> _form_params['id'])) {  // Création d'un nouvel enregistrement
                $this -> _form_params['id'] = $this -> _insert_record($this -> _form_params);
            }
            else {  // Mise à jour de l'enregistrement
                $this -> _update_record($this -> _form_params);
            }
    		//            

            $this -> _add_more_action_after_adding_record(); // Autres actions à effectuer après l'ajout ou la mise à jour (optionnel)
            

            return TRUE;        
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
	 * Crée un nouvel enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return integer Identifiant de l'enregistrement créé
	 */
    abstract protected function _insert_record($record_data);
    
	// --------------------------------------------------------------------

    /**
	 * Met à jours les données de l'enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return void
	 */
    abstract protected function _update_record($record_data);
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute d'autres actions avant l'ajout ou la mise à jour d'un document
     * 
	 * @access protected
     * @return void
	 */
    protected function _add_more_action_before_adding_record()
    {
         return FALSE;        
    }
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute d'autres actions après l'ajout ou la mise à jour d'un document
     * 
	 * @access protected
     * @return void
	 */
    protected function _add_more_action_after_adding_record()
    {
         return FALSE;        
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données du document
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    abstract protected function _get_record_data($record_id);

	// --------------------------------------------------------------------
    
    /**
	 * Définit et renvoie l'identifiant de l'enregistrement
     * 
	 * @access protected
     * @return array
	 */    
    protected function _set_record_id()
    {
        $this -> _record_id = Var_helper :: import('id', 'POST_GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));

        return $this -> _record_id;
    }

	// --------------------------------------------------------------------
    
    /**
	 * Définit les valeurs des paramètres du formulaire
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array
	 */    
    protected function _set_form_params()
    {
        $params = $this -> _get_form_params_posted(); // Paramètres postés dans le formulaire
        $record_data = (array) $this -> _record_data; // Données de l'enregistrement

        return array_replace($record_data, $params);
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres postés dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
    protected function _get_form_params_posted()
    {
        $params = Var_helper :: import('params', 'POST', array(), array('trim')); // Paramètres postés dans le formulaire
        
        if (empty($params)) {
            $params = (array) $this -> _record_data;  // Init
        } else {
            $params = $params + $this -> _get_form_params_by_default();  // Modif
        }
        
        return $params;
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres postés par défaut dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
    protected function _get_form_params_by_default()
    {
        return array(); // Paramètres par défaut dans le formulaire       
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès à l'enregistrement par le rédacteur
     * 
	 * @access protected
     * @param integer Id du document
     * @return boolean
	 */
/*    protected function _is_doc_allowed($doc_id)
    {        
        return FALSE;    
    }
*/
	// --------------------------------------------------------------------

    /**
	 * Cherche et renvoie les erreurs lors de la validation du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifier lors de la validation
     * @return array
	 */
    protected function _set_form_errors($params)
    {
        // Récupération des règles de validation des paramètres ainsi que les messages d'erreur associés
        $params_rules = $this -> _get_form_params_rules($params);

        foreach ($params_rules as $field => $errors) {
            $this -> _form_errors[$field] = '';             
            $field_value = Var_helper :: get_array_value($field, $params);
          
            if (isset($field_value)) {
                foreach ($errors as $error) {
                    if (!empty($error['rules']) && empty($this -> _form_errors[$field])) {
                        $this -> _form_errors[$field] = $this -> _set_form_error_message($field_value, $error['rules'], $error['msg']);
                    }
                }
            }
        }
        
        return $this -> _form_errors;
    }

/*    protected function _set_form_errors($params)
    {
        // Récupération des règles de validation des paramètres ainsi que les messages d'erreur associés
        $params_rules = $this -> _get_form_params_rules($params);

        foreach ($params_rules as $field => $errors) {
            $this -> _form_errors[$field] = '';
           
            if (isset($params[$field])) {
                foreach ($errors as $error) {
                    if (!empty($error['rules']) && empty($this -> _form_errors[$field])) {
                        $this -> _form_errors[$field] = $this -> _set_form_error_message($params[$field], $error['rules'], $error['msg']);
                    }
                }
            }
        }
        
        return $this -> _form_errors;
    }*/

	// --------------------------------------------------------------------

    /**
	 * définit et renvoie les règles de validation des paramètres du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifer lors de la validation
     * @return array Tableau contenant les règles de validation des paramètres ainsi que les messages d'erreur associés 
     * sous la forme suivante : array(param1 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                                param2 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                               ...
     *                          )
	 */	
    protected function _get_form_params_rules($params)
    {
        return array();
        
        /*
        $this -> load_model($model_name);
       
        // Récupération des règles de validation des paramètres ainsi que les messages d'erreur associés
        $params_rules = $this -> {$model_name} -> set_params_rules($params, $this -> _lang, $this -> _config);

        return $params_rules;*/
    }

	// --------------------------------------------------------------------

    /**
	 * définit et renvoie un message d'erreur correspondant à la règle de validation non vérifiée
     * 
	 * @access protected
     * @param string Valeur de la variable
     * @param array Règles de validitité de la valeur de la variable
     * @param string Contenu du message d'erreur
     * @return string Code html du message d'erreur
	 */	
    protected function _set_form_error_message($var, $rules, $msg_error)
    {        
        if (empty($_POST)) {    // Formulaire non soumis
            return '';
        }

        $error = '';

        if (! Var_helper :: check_value($var, $rules)) {
            $error .= '&nbsp;&nbsp;'.Html_helper :: addEm($msg_error, array('class' => 'form-error'));
        }
        
        return $error;
    }
    
	// --------------------------------------------------------------------

    /**
	 * Vérifie si le formulaire est valide ou non
     * 
	 * @access protected
     * @param array Tableau contenant les messages d'erreurs du formulaire
     * @return boolean 
	 */	
    protected function _is_valid_form($form_errors = array(), $token_name = 'add_record')
    {
        if (empty($_POST)) {    // Formulaire non soumis
            return FALSE;
        }

        /**
         * Controle de la validité du token
         */
    //    $token_name = 'add_record';
        $token_time_expire = $this -> _config['token_time_expire'];
        $referer = $this -> _get_current_url();

        if (Security_helper :: check_token($token_time_expire, $referer, $token_name) === FALSE) {
            return FALSE;
        }
        //

        /**
         * Controle de la validité des valeurs des paramètres postés
         */
        foreach($form_errors as $error) {
           if (!empty($error)) {
                return FALSE;
           }
        }
        //
        
        return TRUE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * retourne l'url complète de la page
     * 
     * @access protected
	 * @return string Url complète de la page
	 */
    protected function _get_current_url()
    {
        $base_path = (ADMR_IS_ADMIN)? ADMR_SITE_URL.'admin/' : ADMR_SITE_URL.'plugins/'.ADMR_DIRNAME.'/';
        
        return $base_path.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
        
//        return ADMR_SITE_URL.'admin/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
//        return ADMR_SITE_URL.'plugins/'.ADMR_DIRNAME.'/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
/*    public function set_title_page()
    {
        return ucfirst($this -> _lang['add_quizzplus']);
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
/*    protected function _set_infos_page_content()
    {		
        return parent :: _set_infos_page_content();
    }
*/
	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
/*    public function set_menu_plugin_items()
    {
        return Plugin_menu_helper :: set_public_menu_items($this -> _lang, 'quizzplus', $this -> _writer_rights, 'addons/quizzplus/');         
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
/*    public function set_header_addons()
    {
        $js = ''; 
//        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/xxxxxx.js"></script>'."\n";
        
        $css = '';
//        $css .= '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/public_layout.css" />';

        return $css.$js;        
    }
*/

} //End of Class