<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_record_helper.php';

abstract class Add_user_helper extends Add_record_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration  
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  

    protected $_user_type = '';     // Type utilisateur (writer or group)
    protected $_writer_rights = array(); // Droits du rédacteur
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct($user_type, $writer_rights)
    {
        $this -> _user_type = $this -> _set_user_type($user_type);
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);
        
        parent :: __construct();
        
        $this -> CI -> load_model('rights_model', $user_type, 'user_rights_model');
        $this -> CI -> load_model('group_model');
        $this -> CI -> load_model('writer_model');
        $this -> CI -> load_helper('addons_helper');
      
        $this -> _load_addons_lang(); // Récupération des items de langues des addons
        $this -> _load_addons_add_user_helper();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['add_'.$this -> _user_type]);
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript">$.formUtils.loadModules("module_add_user", "'.ADMR_JS_PATH.'/form-validator/my_modules/");</script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/add_user.js"></script>'."\n";
        
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/add_user.css" />';

        return $js.$css;
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
    public function set_infos_page_content()
    {		
        return '';
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les propriétés du document (type et nom)
     * 
     * @access protected
     * @param string Type du document
	 * @return array Tableau contenant les informations (type, nom) du document
	 */	
    protected function _set_user_type($user_type = '')
    {
        if (!in_array($user_type, array('writer', 'group'))) {
            die('ERROR : le type d\'utilisateur n\'est pas correct');    
        }        
        
        return $this -> _user_type = $user_type;        
    }

	// --------------------------------------------------------------------

	/**
	 * définit les droits du rédacteur
     * 
     * @access protected
     * @param array Tabelau définissant les droits du rédacteur (vide par défaut) 
	 * @return array Tableau contenant les droits du rédacteur
	 */	
    protected function _set_writer_rights($writer_rights = array())
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;        
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le contenu de l'attribut action du formulaire
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_form_action_content()
    {
        return Url_helper :: build_uri(array(
            'id'   => $this -> _record_id,
            'idpg' => Var_helper :: import('idpg', '', 1, array('trim'), array(array('Var_helper', 'is_digit'))),
            'sort' => Var_helper :: import('sort', '', $this -> _config['sort_option_by_default'], array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))),
        ));
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires pour la vue sous la forme
     * array(key => value)
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_more_data_for_add_record_view()
    {
        $data = array(
            'groups' => $this -> _get_groups(),
            'boxmenus' => $this -> _get_menu_boxes(),
            'photoramas' => $this -> _get_photoramas(),
            'templates' => $this -> _get_page_templates(),
            'user_type' => $this -> _user_type,
            'cats' => $this -> _get_all_section_cats(),
            'dirs' => $this -> _get_file_manager_dirs(),
            'docs_to_be_managed' => $this -> _get_docs_to_be_managed(),
            'writers_to_be_managed' => $this -> _get_writers_to_be_managed(),
            'doc_types' => $this -> _get_doc_types(),
        );
        
        return $data + $this -> _add_addons_more_data_for_add_record_view(); // Prise en compte des données provenant de addons
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires provenant des addons pour la vue sous la forme
     * array(key => value)
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_addons_more_data_for_add_record_view()
    {        
        $data = array();
        $addons = $this -> CI -> addons_helper -> get_addons();
              
        foreach($addons as $addon) {            
            if (is_object($this -> CI -> {'add_'.$addon.'_params_for_user_rights_helper'}) && method_exists($this -> CI -> {'add_'.$addon.'_params_for_user_rights_helper'}, 'add_more_data_for_add_user_view')) {
                $data = $data + (array) $this -> CI -> {'add_'.$addon.'_params_for_user_rights_helper'} -> add_more_data_for_add_user_view();
            }
        }
  
        return $data;
    }

	// --------------------------------------------------------------------

    /**
	 * Définit le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_add_record_view()
    {
        return 'add_user_layout';    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute un enregistrement
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_record()
    {
        parent :: _add_record();
    }

	// --------------------------------------------------------------------

    /**
	 * Crée un nouvel enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return integer Identifiant de l'enregistrement créé
	 */
    protected function _insert_record($record)
    {
        $record['id'] = $this -> CI -> {$this -> _user_type.'_model'} -> insert($record);
    
        return $record['id'];    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Met à jours les données de l'enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return void
	 */
    protected function _update_record($record)
    {
        $this -> CI -> {$this -> _user_type.'_model'} -> update($record); // Mise à jour des données
    
        return TRUE;    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute d'autres actions après l'ajout ou la mise à jour d'un document
     * 
	 * @access protected
     * @return void
	 */
    protected function _add_more_action_after_adding_record()
    {
        $params =& $this -> _form_params;
//print_r($params);             
        // On charge la table des documents du rédacteur
        $this -> CI -> load_model('writer_docs_model', array('id' => $params['id']));
        $doc_infos = Model :: get_doc_infos_by_name(); // Tableau contenant les infos (name, type, path) des documents avec comme clés le nom des documents

        foreach($params as $key => $value) {
            if (preg_match('`^([a-z]+)_manage$`', $key, $matches) && ($section = $matches[1])) {
                
                // Ajout des catégories autorisées dans les droits des rédacteurs
                if (isset($params[$section.'_cats_list_allowed']) && isset($params[$section.'_cats_extra'])) {
                    $params[$section.'_cats_list_allowed'] = $this -> _get_cats_allowed_by_section($section, $params);
                    $params[$section.'_cats_extra'] = array('', '');   // Réinitialisation des catégories extra                       
                }
                
                // Ajout de documents à gérer
                if (!empty($params[$section.'_to_be_added'])) {
                    $this -> CI -> writer_docs_model -> insert_many($params[$section.'_to_be_added'], $doc_infos[$section]['type']);
                    $params[$section.'_to_be_added'] = array('');   // Réinitialisation                      
                }

                // Suppression de documents à gérer
                if (!empty($params[$section.'_to_be_removed'])) {
                    $this -> CI -> writer_docs_model -> delete_many_by_id($params[$section.'_to_be_removed'], $doc_infos[$section]['type']);
                    $params[$section.'_to_be_removed'] = array('');   // Réinitialisation                       
                }                    
            }               
        }
        
        // Password
        if (isset($params['pass'])) {
            $params['pass'] = empty($params['pass']) ? $this -> _record_data['pass'] : Security_helper :: encrypt_password($params['name'].$params['pass']);    
        }
//print_r($params);
        $this -> CI -> user_rights_model -> write($params['id'], $params);
        //        
    }

	// --------------------------------------------------------------------
    
    /**
	 * Définit les valeurs des paramètres du formulaire
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array
	 */    
    protected function _set_form_params()
    {
        return parent :: _set_form_params();
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres postés dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
    protected function _get_form_params_posted()
    {
        return parent :: _get_form_params_posted();
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres avec leur valeur par défaut dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
    protected function _get_form_params_by_default()
    {
        $this -> CI -> load_model('rights_model', $this -> _user_type, 'user_rights_model');

        return $this -> CI -> user_rights_model -> read(); // Paramètres avec leur valeur par défaut dans le formulaire       
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données du document
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    protected function _get_record_data($record_id)
    {
        $this -> CI -> load_model('rights_model', $this -> _user_type, 'user_rights_model');
        $this -> CI -> load_model($this -> _user_type.'_model');                              
        
        return array_merge(
            $this -> CI -> user_rights_model -> read($record_id),
            $this -> CI -> {$this -> _user_type.'_model'} -> get_by_id($record_id)
        );
    }

	// --------------------------------------------------------------------

    /**
	 * définit et renvoie les règles de validation des paramètres du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifer lors de la validation
     * @return array Tableau contenant les règles de validation des paramètres ainsi que les messages d'erreur associés 
     * sous la forme suivante : array(param1 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                                param2 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                               ...
     *                          )
	 */	
    protected function _get_form_params_rules($params)
    {
        return $this -> CI -> {$this -> _user_type.'_model'} -> set_params_rules($params, $this -> _lang, $this -> _config);
    }
    
	// --------------------------------------------------------------------

	/**
	 * retourne l'url complète de la page
     * 
     * @access protected
	 * @return string Url complète de la page
	 */
    protected function _get_current_url()
    {
        return parent :: _get_current_url();
    }

	// --------------------------------------------------------------------

    /**
	 * Charge les fichiers de langue des addons
     * 
	 * @access private
     * @return void
	 */
/*    private function _load_addons_lang()
    {       
        $addons_dirs = $this -> _get_addons();    

        foreach($addons_dirs as $dir) {
            $this -> CI -> load_lang($dir, ADMR_ADDONS_PATH.'/'.$dir.'/languages');
        }
        
        $this -> _lang = $this -> CI -> get_lang();      
    }
*/
	// --------------------------------------------------------------------

	/**
	 * retourne la liste des catégories autorisées pour le rédacteur
	 *
	 * @access	private
	 * @return	array sous la forme array(name => id)
	 */	
    private function _get_cats_allowed_by_section($section, $params)
    {
        $cats = array();
        
        $cats = $params[$section.'_cats_list_allowed'];
        $cat_extra = $params[$section.'_cats_extra'];        

        foreach($this -> _config['lang'] as $key => $lng) {
            if (!empty($lng) && !empty($cat_extra[$key])) {
                $new_cats_name = explode(CONNECTOR, $cat_extra[$key]);
                foreach($new_cats_name as $cat_name) {
                    if (!empty($cat_name) && !in_array($cat_name, $cats[$key])) {
                        $cats[$key][] = $cat_name;    
                    }      
                }
            }
        }       
        
        return $cats;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des groupes rédacteurs
	 *
	 * @access	private
	 * @return	array sous la forme array(id => name)
	 */
    private function _get_groups()
    {
        return $this -> CI -> group_model -> get(array(), 'ch_asc');
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des boites de menu pour les articles de guppy
     * et du plugin ajoutemenu si présent
	 *
	 * @access	private
	 * @return	array sous la forme array($id => array('id' => $id, 'title' => $title))
	 */
    private function _get_menu_boxes()
    {
        $boxmenus = array();
        
        /**
         * Récupération des boites menus enregistrées dans guppy
         */ 
        $this -> CI -> load_helper('boxmenus_helper');
        $boxmenus = $this -> CI -> boxmenus_helper -> get_all(); // Toutes les boites menus enregistrées dans guppy (par défaut) 
        //
                
        return $boxmenus;      
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des galeries photos
	 *
	 * @access	private
	 * @return	array sous la forme array($id => array('id' => $id, 'cat' => $cat, 'title' => $title))
	 */
    private function _get_photoramas()
    {
        $photoramas = array();
        
        /**
         * Récupération des galeries photos enregistrées dans guppy
         */ 
        $this -> CI -> load_helper('photoramas_helper');
        $photoramas = $this -> CI -> photoramas_helper -> get_all(); // Toutes les galeries photos enregistrées dans guppy (par défaut) 
        //
                
        return $photoramas;      
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des configurations de page (gabarits) définies dana la skin choisie
	 *
	 * @access	private
	 * @return	array sous la forme array(id => name)
	 */
    function _get_page_templates()
    {
/*        global $templates;
        
        $layouts = array();
        
        foreach($templates as $id => $name) {
            $layouts[$id]= array('id' => $id, 'name' => $name);
        }
         
        return $layouts;*/
        $this -> CI -> load_helper('templates_helper');
        
        return $this -> CI -> templates_helper -> get_all_layouts(); // Tous les gabarits enregistrés dana la skin choisie
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des catégories de toutes les sections
	 *
	 * @access	private
	 * @return	array sous la forme array(section => array(cat1, cat2))
	 */
    private function _get_all_section_cats()
    {
        $cats = array();
        $params = $this -> _form_params;

        foreach($params as $key => $value) {
            if (preg_match('`^([a-z]+)_cats_manage$`', $key, $matches) && ($section = $matches[1])) {
               $cats[$section] = $this -> _get_cats_by_section($section);    
            }
        }
       
        return $cats;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des catégories de la section
	 *
	 * @access	private
	 * @return	array Tableau contenant les catégories de la section sous la forme array(name => id)
	 */
    private function _get_cats_by_section($section)
    {
        $cats = array();
        
        $this -> CI -> load_addon_model($section, $section.'_model');  // On charge le modèle si la section est un addon pour pouvoir enregistrer les infos (type, name) du document     
        $doc_infos = Model :: get_doc_infos_by_name($section); // On récupère les infos (type, name) enregistres du document
        
        if (empty($doc_infos)) { // Si pas d'infos du document
            return array();    
        }

        $this -> CI -> load_helper('categories_helper', $doc_infos, $section.'_cats_helper');
        $cats = $this -> CI -> {$section.'_cats_helper'} -> get_all();         

        /**
         * Récupération des catégories enregistrées pour le rédacteur
         */ 
        $writer_cats = $this -> _form_params[$section.'_cats_list_allowed']; // Catégories autorisées pour le rédacteur
        
        foreach($this -> _config['lang'] as $key => $lng) {
            if (!empty($lng) && !empty($writer_cats[$key])) {
                foreach($writer_cats[$key] as $writer_cat) {
                    if (!empty($writer_cat)) {
                        $cats[$key][$writer_cat] = $writer_cat;
                    }              
                }                 
            }
        }
       //

        return $cats;     
    }

	// --------------------------------------------------------------------

    /**
     * retourne un tableau contenant la liste des répertoires accessibles dans le gestionnaire de fichiers
     * 
	 * @access	private
     * @return array sous la forme array(dir_path => dir_path)
     */
    private function _get_file_manager_dirs()
    {
        $dirs = array();
        $upload_dirs = $this -> _config['file_manager']['dirs'];
        settype($upload_dirs, 'array');
        
        foreach($upload_dirs as $dir) {
            $dirs = $dirs + array($dir => Dir_helper :: get_dirs_path_name(CHEMIN.$dir)); 
        }

        return $dirs;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Retourne la liste des rédacteurs à gérer par un "super" rédacteur
     * 
	 * @access private
	 * @return mixed Code html
	 */
    private function _get_writers_to_be_managed()
    {
        $writers = $this -> CI -> writer_model -> get();     
       
        // Suppression du "super" rédacteur qui gère les autres
        if (!empty($this -> _form_params['id'])) {
            unset($writers[$this -> _form_params['id']]);    
        }
        //

        $writers = $this -> CI -> writer_model -> sort_by_key($writers, 'ch_asc'); // Tri par rapport aux noms
        
        return $writers;    
    }
 
	// --------------------------------------------------------------------
 
	/**
	 * Retourne la liste des documents à ajouter ou à supprimer pour être gérés par le rédacteur
     * 
	 * @access private
	 * @return array Tableau contenant la liste des documents à ajouter ou à supprimer pour être gérés par le rédacteur 
     */    
    private function _get_docs_to_be_managed()
    {
        $params = $this -> _form_params;
        $docs_to_be_added = array();
        $docs_to_be_removed = array();
        $writer_docs = array();
        $guppy_docs = array();
        
        $this -> CI -> load_model('writer_docs_model', array('id' => $params['id']));     
        $doc_infos = Model :: get_doc_infos_by_name(); // Tableau contenant les infos (name, type, path) des documents avec comme clés le nom des documents
        
        /**
         * Récupération des documents enregistrés et indexés (actif) dans guppy
         */
        foreach($params as $key => $value) {
            if (preg_match('`^([a-z]+)_manage$`', $key, $matches) && ($section = $matches[1])) {
                                                                      
                if (isset($params[$section.'_to_be_added']) || isset($params[$section.'_to_be_removed'])) {
                    $guppy_docs = $this -> _get_guppy_docs($doc_infos[$section]); // Récupération des documents enregistrés dans guppy
                    $writer_docs = $this -> CI -> writer_docs_model -> get_many_by_type($doc_infos[$section]['type']); // Récupération des documents du rédacteur
                
                    $docs_to_be_added[$section] = array_diff_key($guppy_docs, $writer_docs); // Ajout de documents à gérer
                    $docs_to_be_removed[$section] = array_intersect_key($guppy_docs, $writer_docs); // Suppression de documents à gérer
                }             
            }               
        }
        //
                
        return array('docs_to_be_added' => $docs_to_be_added, 'docs_to_be_removed' => $docs_to_be_removed);    
    }

	// --------------------------------------------------------------------

    /**
     * Récupération des documents enregistrés dans guppy
     * 
     * @param array Tableau contenant les infos générale (name, type, path) du type de document
     * @return array Tableau contenant les infos des documents enregistrés dans guppy
     */
    private function _get_guppy_docs($doc_infos)
    {
        $docs = array();
        $docs += $this -> _get_guppy_docs_indexed($doc_infos);
        $docs += $this -> _get_guppy_docs_not_indexed($doc_infos);
        
        krsort($docs);

        return $docs;
    }

	// --------------------------------------------------------------------

    /**
     * Récupération des documents enregistrés et indexés (actif) dans guppy
     * 
     * @param array Tableau contenant les infos générale (name, type, path) du type de document
     * @return array Tableau contenant les infos des documents enregistrés dans guppy
     */
    private function _get_guppy_docs_indexed($doc_infos)
    {
        $this -> CI -> load_model($doc_infos['name'].'_index_model'); 
        
        return $this -> CI -> {$doc_infos['name'].'_index_model'} -> read();
    }    

	// --------------------------------------------------------------------

    /**
     * Récupération des documents enregistrés et non indexés (inactif) dans guppy
     * 
     * @param array Tableau contenant les infos générale (name, type, path) du type de document
     * @return array Tableau contenant les infos des documents enregistrés dans guppy
     */
    private function _get_guppy_docs_not_indexed($doc_infos)
    {
        $docs = array();
        $this -> CI -> load_model('guppy_docid_model'); 
        $this -> CI -> load_model($doc_infos['name'].'_model'); 

        $guppy_docs_inactivated = $this -> CI -> guppy_docid_model -> get(array('type' => $doc_infos['type'], 'status' => 'i')); // Tous les documents inactifs enregistrés dans guppy
        
        foreach($guppy_docs_inactivated as $id => $doc) {
            $docs[$id] = $this -> CI -> {$doc_infos['name'].'_model'} -> read($id);    
        }

        return $docs;     
    }
    
	// --------------------------------------------------------------------

    /**
	 * Renvoie les infos des différents documents pris en charge
     * 
	 * @access private
     * @return array Tableau contenant les infos des différents types de documents
	 */
    private function _get_doc_types()
    {
        $doc_infos = Model :: get_doc_infos_by_type();
        
        // Ajout des addons
        foreach($this -> _get_addons() as $addons) {
            $doc_infos[$addons] = array('type' => $addons, 'name' => $addons);            
        }
        
        return $doc_infos;    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Renvoie les noms des addons
     * 
	 * @access private
     * @return void
	 */
    private function _get_addons()
    {
        return $this -> CI -> addons_helper -> get_addons($except = array('messages'));
    }
    
	// --------------------------------------------------------------------

    /**
	 * Charge les items de langue des addons
     * 
	 * @access private
     * @return void
	 */
    private function _load_addons_lang()
    {
        $this -> CI -> addons_helper -> load_addons_lang();
              
        $this -> _lang = $this -> CI -> get_lang(); // Nécessaire pour récupérer les items de langue des addons chargés
    }
    
	// --------------------------------------------------------------------

    /**
	 * Vérifie si la section correspond à un addon ou non
     * 
	 * @access private
     * @return void
	 */
    private function _is_addon($section_name)
    {
        return $this -> CI -> addons_helper -> addon_exists($section_name);
    }
    
	// --------------------------------------------------------------------

    /**
	 * Charge les fichiers add_user_helper.php des addons
     * 
	 * @access private
     * @return void
	 */
    private function _load_addons_add_user_helper()
    {
        $addons = $this -> CI -> addons_helper -> get_addons();
              
        foreach($addons as $addon) {
            $this -> CI -> load_addon_helper($addon, 'add_'.$addon.'_params_for_user_rights_helper');
        }
    }

 } // End of class