<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_user_helper.php';

class Add_writer_helper extends Add_user_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  

    protected $_writer_rights = array(); // Droits du rédacteur
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {
        parent :: __construct('writer', $writer_rights);    
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();
    }

	// --------------------------------------------------------------------

    /*
     * Crée des répertoires pour le gestionnaire de fichiers
     *
     * @return void
     */        
    public function add_directories_for_filemanager()
    {	
        $writer = $this -> CI -> writer_model -> get_by_id($this -> _record_id);
      
        // Création des répertoires si rédacteur existant
		if (!empty($writer['name'])) {
	        $this -> CI -> load_helper('dir_helper');
            
            $parent_dirs = $this -> _config['file_manager']['dirs'];
           
            foreach($parent_dirs as $parent_dir) {
                Dir_helper :: create_dir(CHEMIN.$parent_dir.'/'.$writer['name']);    
            }
		}
        
        // Redirection
        $uri = Url_helper :: build_uri(
            $params = array(
                'id'   => $this -> _record_id,
                'idpg' => Var_helper :: import('idpg', '', 1, array('trim'), array(array('Var_helper', 'is_digit'))),
                'sort' => Var_helper :: import('sort', '', $this -> _config['sort_option_by_default'], array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))),
            ),
            $basehref = str_replace('/add_directories_for_filemanager', '', ADMR_CONTROLLER)
        );
                        		
		Url_helper :: redirect($uri.'#params_files');
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        return parent :: set_header_addons();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
    public function set_infos_page_content()
    {		
        return parent :: set_infos_page_content();
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        return parent :: set_menu_plugin_items();         
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données du document
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    protected function _get_record_data($record_id)
    {
        $record_data = parent :: _get_record_data($record_id);
        
        if (empty($record_data['status'])) {
            $record_data['status'] = $this -> _config['writer_status_by_default'];  // Nécessaire pour l'initialisation du status
        }
     
        return $record_data;
    }

	// --------------------------------------------------------------------

} // End of class