<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Addons_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();     // Données de langue
    protected $_config = array();   // Données de configuration
    protected $_addons = array(); // Addons
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct()
    {
        $this -> CI =& Controller :: get_instance();
        
        $this -> _addons = $this -> _scan_dir_addons();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Renvoie les noms des addons
     * 
	 * @access public
     * @return array Tableau contenant les noms des répertoires des addons
	 */
    public function get_addons($except = array())
    {
        $addons = $this -> _addons;
        settype($except, 'array');

        if (!empty($except)) {       
            $addons = array_diff($addons, $except);
        }
               
        return $addons;
    }
    
	// --------------------------------------------------------------------

    /**
	 * Charge les fichiers de langue des addons
     * 
	 * @access private
     * @param array Tableau contenant les chemins des répertoires des addons sélectionnés (tous par défaut)
     * @return void
	 */
    public function load_addons_lang($addons = array())
    {       
        if (empty($addons)) {
            $addons = $this -> _addons;    
        }          

        foreach($addons as $addon_name) {
            $this -> CI -> load_addon_lang($addon_name);
        }
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie si l'addon est installé ou non
     * 
	 * @access public
     * @param Strin Nom de l'addon
     * @return boolean
	 */    
    public function addon_exists($addon_name)
    {
        return (is_dir(ADMR_ADDONS_PATH.'/'.$addon_name) && is_dir(CHEMIN.'admin/plugins/'.$addon_name)) ? TRUE : FALSE;         
    }

	// --------------------------------------------------------------------

    /**
	 * Renvoie les noms des répertoires présents dans le répertoire addons
     * 
	 * @access public
     * @return array Tableau contenant les noms des répertoires des addons
	 */
    private function _scan_dir_addons()
    {
        $addons = array();
        $dir  = opendir(ADMR_ADDONS_PATH);
     
        while (FALSE !== ($filename = readdir($dir))) {
            if (strpos($filename, '.') === FALSE && is_dir(ADMR_ADDONS_PATH.'/'.$filename)) {
                $addons[] = $filename;    
            } 
        }
        
        closedir($dir);

        sort($addons);
               
        return $addons;
    }

}