<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Array_helper
{	
	/**
	 * extrait des valeurs correspondant à une clé dans un tableau multidimensionnel par récursivité
     * 
	 * @access public
	 * @param string Valeur de la clé recherché dans le tableau
	 * @param array  Tableau associatif multidimensionnel contenant les données
	 * @return array
	 */
    public static function extract_array_values_by_key($needle, $haystack)
    {
        if (is_array($haystack))
        {
            $tmp = array();
            
            foreach ($haystack as $key => $value)
            {
                if (is_string($value))
                {
                    if ($key == $needle) {
                        $tmp[] = $value;    
                    }
                }
                else
                {
                    if (isset($value[$needle]))
                    {
                        $tmp[$key] = $value[$needle];
                    }
                    else {
                        $tmp[$key] = self :: extract_array_values_by_key($needle, $value);
                    }
                }
            }   
        }
        else
        {
            $tmp = $haystack;
        }
        
        return $tmp;
    }

	// --------------------------------------------------------------------

    /**
     * Filtre les éléments d'un tableau multidimensionnel (récursivité) grâce à une fonction utilisateur
     * 
     * @param array Tableau à évaluer 
     * @param string Fonction utilisateur qui permet de filtrer les éléments
     * @return array Tableau avec seulement les éléments validés par le filtre
     */
    public static function array_filter_recursive($source, $fn)
     {
         $result = array();
         foreach ($source as $key => $value)
         {
             if (is_array($value))
             {
                 $result[$key] = self::array_filter_recursive($value, $fn);
                 continue;
             }
             if ($fn($key, $value))
             {
                 $result[$key] = $value; // KEEP
                 continue;
             }
         }
         return $result;
     }

	// --------------------------------------------------------------------

    /**
      * calculates intersection of two arrays like array_intersect_key but recursive
      *
      * @param  array/mixed  master array
      * @param  array        array that has the keys which should be kept in the master array
      * @return array/mixed  cleand master array
      */
     public static function array_intersect_key_recursive($master, $mask)
     {
         if (is_array($master))
         {
             foreach ($master as $key => $value)
             {                
                 if (!is_string($key)) { // keep value with numeric key
                    continue;
                 }
                 
                 if (!isset($mask[$key])) {
                    unset ($master[$key]);    // remove value from $master if the key is not present in $mask
                    continue;
                 }
                  
                 if (is_array($mask[$key])) {
                    $master[$key] = self :: array_intersect_key_recursive($master[$key], $mask[$key]); // recurse when mask is an array
                 } 
                 // else simply keep value
             }
         }
         
         return $master;
     }

	// --------------------------------------------------------------------

    /**
     * Merge two or more arrays like array_merge but recursive (by walf)
     *
     * @param  array  master array
     * @param  array  array that has the keys which should be merged in the master array
     * @return array  merged master array with others array
     */
    public static function array_merge_recursive(/* $array1, $array2 [, array $... ] */) {
    
         if (func_num_args() < 2) {
             trigger_error(__FUNCTION__ .' needs two or more array arguments', E_USER_WARNING);
             return;
         }
         $arrays = func_get_args();
         $merged = array();
         while ($arrays) {
             $array = array_shift($arrays);
             if (!is_array($array)) {
                 trigger_error(__FUNCTION__ .' encountered a non array argument', E_USER_WARNING);
                 return;
             }
             if (!$array)
                 continue;
             foreach ($array as $key => $value)
                 if (is_string($key))
                     if (is_array($value) && array_key_exists($key, $merged) && is_array($merged[$key]))
                         $merged[$key] = call_user_func(array('self', 'array_merge_recursive') , $merged[$key], $value);
                     else
                         $merged[$key] = $value;
                 else
                     $merged[] = $value;
         }
         return $merged;
    }

	// --------------------------------------------------------------------

    /**
     * Retourne les valeurs d'une colonne d'un tableau d'entrée
     *
     * @param  array  master array
     * @param  string  clé de la colonne que vous souhaitez récupérer
     * @return string  La colonne à utiliser comme index/clé pour le tableau retourné
     */    
    public static function array_column(array $input, $columnKey, $indexKey = null) {
        $result = array();
        
        if (null === $indexKey) {
            if (null === $columnKey) {
                $result = array_values($input);
            }
            else {
                foreach ($input as $row) {
                    $result[] = $row[$columnKey];
                }
            }
        }
        else {
            if (null === $columnKey) {
                foreach ($input as $row) {
                    $result[$row[$indexKey]] = $row;
                }
            }
            else {
                foreach ($input as $row) {
                    $result[$row[$indexKey]] = $row[$columnKey];
                }
            }
        }
        
        return $result;
    }

	// --------------------------------------------------------------------

}