<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

/**
 * Classe qui permet de récupérer les boites de menus enregistrées dans guppy
 */
class Boxmenus_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();     // Données de langue
    protected $_config = array();   // Données de configuration
    protected $_doc_infos = array('type' => '', 'name' => ''); // Infos concernant le document (type, name)
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct()
    {
        $this -> CI =& Controller :: get_instance();
        
        $this -> _doc_infos = Model :: get_doc_infos_by_type(TYP_MENUBOX);

        $this -> CI -> load_model('guppy_docid_model');
        $this -> CI -> load_model($this -> _doc_infos['name'].'_model');
        $this -> CI -> load_model($this -> _doc_infos['name'].'_index_model');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    /**
	 * retourne toutes les boites de menus (indexed et non indexed)
     * 
	 * @access public
     * @return array Tableau contenant les données des boites de menus
	 */	
    public function get_all()
    {
        $boxmenus = array()
                  + $this -> _get_boxmenus_indexed()
                  + $this -> _get_boxmenus_not_indexed();
        
        ksort($boxmenus);
        
        return $boxmenus;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne toutes les boites de menus (indexed et non indexed) identifiées par leur id)
     * 
	 * @access public
     * @param array Tableau contenant les identifiants des boites de menus
     * @return array Tableau contenant les données des boites de menus
	 */	
    public function get_by_id($ids)
    {
        settype($ids, 'array');
        $boxmenus = $this -> get_all();
        $boxmenus_selected = array();
        
        foreach($boxmenus as $key => $value) {
            if (in_array($value['id'], $ids)) {
                $boxmenus_selected[$key] = $boxmenus[$key];   
            }    
        }
        
        return $boxmenus_selected;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne seulement les boites de menus indexées
     * 
	 * @access public
     * @return void
	 */	
    public function get_only_indexed()
    {
        return $this -> _get_boxmenus_indexed();
    }

	// --------------------------------------------------------------------

    /**
	 * retourne seulement les boites de menus non indexées
     * 
	 * @access public
     * @return void
	 */	
    public function get_only_not_indexed()
    {
        return $this -> _get_boxmenus_not_indexed();
    }

	// --------------------------------------------------------------------

    /**
	 * retourne toutes les boites de menus indexées dans guppy (boites de menus activées)
     * 
	 * @access public
     * @return void
	 */	
    protected function _get_boxmenus_indexed()
    {
        global $lng, $lang;
        
        $boxmenus = array();
        $doc_infos = $this -> _doc_infos;
        
        $data_docs_indexed = $this -> CI -> {$doc_infos['name'].'_index_model'} -> read(); // Tous les documents enregistrées dans le fichier index de guppy                     
        
        foreach($data_docs_indexed as $data) {
            
            $data['title'] = ($lng == $lang[1]) ? $data['title2'] : $data['title1'];  
            
            $boxmenus[strtolower($data['title'])] = array(
                'id' => $data['id'],
                'title' => $data['title']
            );
            
/*            $boxmenus[$data['id']] = array(
                'id' => $data['id'],
                'name' => ($lng == $lang[1]) ? $data['title2'] : $data['title1']
            );*/
        } 
            
        return $boxmenus;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne toutes les boites de menus non indexées dans guppy (boites de menus inactivées)
     * 
	 * @access public
     * @return void
	 */	
    protected function _get_boxmenus_not_indexed()
    {
        global $lng, $lang;

        $boxmenus = array();
        $doc_infos = $this -> _doc_infos;
        
        $docs_inactivated = $this -> CI -> guppy_docid_model -> get(array('type' => $doc_infos['type'], 'status' => 'i')); // Tous les documents inactifs enregistrés dans guppy                     
        
        foreach($docs_inactivated as $doc) {
            $data = $this -> CI -> {$doc_infos['name'].'_model'} -> read($doc['id']); // Données du document de guppy                     

            $data['title'] = ($lng == $lang[1]) ? $data['title2'] : $data['title1'];  
            
            $boxmenus[strtolower($data['title'])] = array(
                'id' => $data['id'],
                'title' => $data['title']
            );
/*      
            $boxmenus[$data['id']] = array(
                'id' => $data['id'],
                'name' => ($lng == $lang[1]) ? $data['title2'] : $data['title1']
            );*/
        } 
            
        return $boxmenus;
    }

	// --------------------------------------------------------------------
    
} // End of class