<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

/**
 * Classe qui permet de récupérer les catégories des documents selon leur type
 */
class Categories_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();     // Données de langue
    protected $_config = array();   // Données de configuration
    protected $_doc_infos = array('type' => '', 'name' => ''); // Infos concernant le document (type, name)
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct($doc_infos)
    {
        $this -> CI =& Controller :: get_instance();

        $this -> _doc_infos = $this -> _set_doc_infos($doc_infos);
       
        $this -> CI -> load_model('guppy_docid_model');
        $this -> CI -> load_model($this -> _doc_infos['name'].'_model');
        $this -> CI -> load_model($this -> _doc_infos['name'].'_index_model');
        //addon
        $this -> CI -> load_addon_model($this -> _doc_infos['name'], $this -> _doc_infos['name'].'_model');
        $this -> CI -> load_addon_model($this -> _doc_infos['name'], $this -> _doc_infos['name'].'_index_model');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * retourne toutes les catégories (indexed et non indexed)
     * 
	 * @access public
     * @return void
	 */	
    public function get_all()
    {
        $cats = array(array(), array());
        
        $cats_indexed = $this -> _get_cats_indexed();
        $cats_not_indexed = $this -> _get_cats_not_indexed();

        $cats = array(
            array_merge($cats_indexed[0], $cats_not_indexed[0]),
            array_merge($cats_indexed[1], $cats_not_indexed[1]),            
        );
        
        return $cats;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne seulement les catégories indexées
     * 
	 * @access public
     * @return void
	 */	
    public function get_only_indexed()
    {
        return $this -> _get_cats_indexed();
    }

	// --------------------------------------------------------------------

    /**
	 * retourne seulement les catégories non indexées
     * 
	 * @access public
     * @return void
	 */	
    public function get_only_not_indexed()
    {
        return $this -> _get_cats_not_indexed();
    }

	// --------------------------------------------------------------------

    /**
	 * retourne toutes les catégories indexées dans guppy (catégories des documents activés)
     * 
	 * @access public
     * @return void
	 */	
    protected function _get_cats_indexed()
    {
        $cats = array(array(), array());
        $doc_infos = $this -> _doc_infos;
        
        $data_docs_indexed = $this -> CI -> {$doc_infos['name'].'_index_model'} -> read(); // Tous les documents enregistrées dans le fichier index de guppy                     
        
        foreach($data_docs_indexed as $data) {
            if (!empty($data['cat1'])) {
                $cats[0][$data['cat1']] = $data['cat1'];            
            }  
            if (!empty($data['cat2'])) {
                $cats[1][$data['cat2']] = $data['cat2'];            
            }  
        } 
            
        return $cats;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne toutes les catégories non indexées dans guppy (catégories des documents inactivés)
     * 
	 * @access public
     * @return void
	 */	
    protected function _get_cats_not_indexed()
    {
        $cats = array(array(), array());
        $doc_infos = $this -> _doc_infos;
        
        $docs_inactivated = $this -> CI -> guppy_docid_model -> get(array('type' => $doc_infos['type'], 'status' => 'i')); // Tous les documents inactifs enregistrés dans guppy                     
        
        foreach($docs_inactivated as $doc) {
            $data = $this -> CI -> {$doc_infos['name'].'_model'} -> read($doc['id']); // Données du document de guppy                     
      
            if (!empty($data['cat1'])) {
                $cats[0][$data['cat1']] = $data['cat1'];            
            }
 
            if (!empty($data['cat2'])) {
                $cats[1][$data['cat2']] = $data['cat2'];            
            }  
        } 
            
        return $cats;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les propriétés du document (type et nom)
     * 
     * @access protected
     * @param string Type du document
	 * @return array Tableau contenant les informations (type, nom) du document
	 */	
    protected function _set_doc_infos($doc_infos = '')
    {
        if (empty($doc_infos['type']) || empty($doc_infos['name'])) {
            die('ERROR : vous devez définir le type et le nom du document');    
        }        
        
        return $this -> _doc_infos = $doc_infos;        
    }

	// --------------------------------------------------------------------
    
} // End of class