<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Display_error_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
    protected $_writer_rights = array(); // Droits du rédacteur
    //
    private $_error_type = '';           // Type d'erreur
    private $_addon = '';                // Nom de l'addon (nécessaire pour récupérer sa config)   
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights = array())
    {        
        $this -> CI =& Controller :: get_instance();
        
        $this -> CI -> load_helper('var_helper');
        $this -> CI -> load_helper('url_helper');
    
        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);
        
        $this -> _addon = Var_helper :: import('addon', 'POST_GET', null, array('trim'), array(array('Var_helper', 'is_alpha_num_dash')));
        $this -> _error_type = Var_helper :: import('type', 'POST_GET', '', array('trim'), array(array('Var_helper', 'is_alpha_num_dash')));
    }

	// --------------------------------------------------------------------

    public function index()
    {        
        $data = array(
            'lang' => &$this -> _lang,
            'error_message' => $this -> _get_error_message($this -> _error_type),
        );
       
        $this -> CI -> render_page('display_error', $data);
    }

     
	// --------------------------------------------------------------------

	/**
	 * Renvoie le message d'erreur correspondant au type d'erreur
     * 
	 * @access protected
     * @param string Type d'erreur
	 * @return string Message d'erreur
	 */    
    protected function _get_error_message($error_type)
    {
        $errors_messages = $this -> _set_errors_messages();
            
        return !empty($errors_messages[$error_type]) ? $errors_messages[$error_type] : 'Une erreur non répertoriée est survenue. Veuillez contacter l\auteur du plugin.';
    }
        
	// --------------------------------------------------------------------

	/**
	 * Définit les messages d'erreur associé à leur type
     * 
	 * @access protected
	 * @return array Tableau contenant les messages d'erreur sous la forme array('type' => 'message')
	 */
    protected function _set_errors_messages()
    {
        $errors_messages = array(
            'compatibility' => $this -> _lang['errors_msg']['version_of_plugin_adm_redacteurs_is_not_compatible_with_addon'],
            'disallowed' => $this -> _lang['errors_msg']['no_rights_for_doc_access'],
            'page_not_found' => $this -> _lang['errors_msg']['this_page_doesnt_exists'],
            'page_not_allowed' => $this -> _lang['errors_msg']['access_is_not_allowed'],
            'error_404' => $this -> _lang['errors_msg']['version_of_plugin_adm_redacteurs_is_not_compatible_with_addon']
        );
        
        return $errors_messages;
    } 
       
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['errors_msg']['error_occured']);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_display_error'];
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     *
	 * @access public
	 */	
    public function set_header_addons()
    {
        $js = '';
//        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/display_error.js"></script>'."\n";
             
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/display_error.css" />';

        return $css.$js;

    }
        
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {           
        return array();
    }
   
	// --------------------------------------------------------------------

	/**
	 * définit les droits du rédacteur
     * 
     * @access private
     * @param mixed Options de tri
	 * @return void
	 */	
    private function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }
   
	// --------------------------------------------------------------------
    
} // End Class