<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Editor_helper
{
    
    /**
     * Affiche l'éditeur WYSIWYG ou non
     * 
     * @param string  Nom de l'éditeur
     * @param string  Contenu de l'éditeur
     * @param array   Paramètres de configuration (optionnels)
     * @param boolean Editeur wysiwyg (true) ou non (false)
     * @return string
     */
    public static function display_editor($name, $contents, $config_params = array(), $wysiwyg = TRUE)
    {
        if ($wysiwyg) {
            return self :: WYSIWYG_editor($name, $contents, $config_params);                
        } else {
   //       return self :: TEXTAREA_editor($name, $width, $height, $content, $params, $config_editors_path);   
        }
    }
    
    // --------------------------------------------------------------------
    
    /**
     * Affiche un éditeur WYSIWYG 
     * 
     * @param string Nom de l'éditeur
     * @param string Contenu de l'éditeur
     * @param array Paramètres de configuration (optionnels)
     * @return string
     */
    public static function WYSIWYG_editor($name, $contents, $config_params = array())
    {
        settype($params, 'array');
        
        /**
         * Editeur CKEditor
         */
        if (is_file(CHEMIN.'inc/ckeditor/ckeditor.php'))
        {
            require_once CHEMIN.'inc/ckeditor/ckeditor.php';
                    
            return self :: CKEditor($name, $config_params);
        }
        //
        
        return FALSE;   
    }
    
    // --------------------------------------------------------------------
    
    /**
     * Affiche une instance de l'éditeur WYSIWYG CKEditor
     * 
     * @param string Nom de l'éditeur
     * @param array Paramètres de configuration (optionnels)
     * @return string
     */
    public static function CKEditor($name, $config_settings = array())
    {    
        settype($config_settings, 'array');
        
        /**
         * Définition des paramètres de configuration de l'éditeur
         */
        $config_settings = array_merge(self :: _set_CKEditor_config_settings_by_default(), $config_settings);
        
        if (isset($config_settings['writer_rights']['files_manage']) && empty($config_settings['writer_rights']['files_manage'])) { // Suppression de l'accès au filemanager en fonction des droits du rédacteur
            unset(
                $config_settings['filebrowserBrowseUrl'],
                $config_settings['filebrowserImageBrowseUrl'],
                $config_settings['filebrowserImageBrowseLinkUrl'],
                $config_settings['filebrowserVideoBrowseUrl']
            );            
        }
        //

        /**
         * Création de l'éditeur
         */
        $editor = new CKEditor() ;
        $editor -> basePath = ADMR_SITE_URL.'inc/ckeditor/';               
        $editor -> replace($name, $config_settings);
        //
    }
        
    // --------------------------------------------------------------------

    /**
     * Récupère et renvoie les paramètres de configuration par défaut de l'éditeur
     * 
     * @return array Tableau contenant les paramètres de configuration de l'éditeur
     */ 
    protected static function _set_CKEditor_config_settings_by_default()
    {
   	    global $lng;

        // Paramètres communs par défaut
        $config_settings = array(
            'baseHref' => ADMR_SITE_URL,
            'language' => $lng,
            'smiley_path' => self:: get_smileys_infos('path'),
            'smiley_images' => self:: get_smileys_infos('images'),
            'smiley_descriptions' => self:: get_smileys_infos('descriptions'), 
        );
          
        if (ADMR_IS_ADMIN) {
            $config_settings = array_merge($config_settings, self :: _set_CKEditor_config_settings_for_admin());
        } else {
            $config_settings = array_merge($config_settings, self :: _set_CKEditor_config_settings_for_writer());
        }
        
        return $config_settings;       
    }
        
    // --------------------------------------------------------------------

    /**
     * Récupère et renvoie les paramètres de configuration de l'éditeur pour l'administrateur
     * 
     * @return array Tableau contenant les paramètres de configuration de l'éditeur
     */ 
    protected static function _set_CKEditor_config_settings_for_admin()
    {
   	    global $lng;

        $config_editor_basepath = ADMR_SITE_URL.'admin/editors/ckeditor_config/';
//        $filebrowser_url_basepath = ADMR_SITE_URL.'admin/editors/upload/upload.php?lng='.$lng.'&namerepconfig=ckeditor_config&pathconfig=admin/editors/'; // Filemanager de guppy 
        $filebrowser_url_basepath = str_replace(CHEMIN, ADMR_SITE_URL, ADMR_ADMIN_ROOT_PATH).'/filemanager.php?lng='.$lng.'&ctrl=file_manage'; // Filemanager du plugin Adm_redacteurs
        
        return array(
            'customConfig' => $config_editor_basepath.'guppy_ckconfig.js',
        	'contentsCss' =>  $config_editor_basepath.'custom/guppy_contents.css',
            'templates_files' => array($config_editor_basepath.'custom/templates/templates/default.js'),
            'stylesSet' => 'styles:'.$config_editor_basepath.'custom/styles/styles.js',
/*          
            // Filemanager de guppy  
        	'filebrowserBrowseUrl' =>          $filebrowser_url_basepath.'&uptype=Link', //récupération du file, img, photo, pages et flash de guppy
        	'filebrowserImageBrowseUrl' =>     $filebrowser_url_basepath.'&uptype=Image', //récupération du répertoire img et photo de guppy
        	'filebrowserImageBrowseLinkUrl' => $filebrowser_url_basepath.'&uptype=Link',  //récupération du répertoire file, img, photo, pages et flash de guppy
        	'filebrowserFlashBrowseUrl' =>     $filebrowser_url_basepath.'&uptype=Flash', //récupération du répertoire flash de guppy
*/

        	// Filemanager du plugin Adm_redacteurs
            'filebrowserBrowseUrl' =>          $filebrowser_url_basepath.'&type=link' , //récupération du file, img, photo, pages et flash de guppy
        	'filebrowserImageBrowseUrl' =>     $filebrowser_url_basepath.'&type=image', //récupération du répertoire img et photo de guppy
        	'filebrowserImageBrowseLinkUrl' => $filebrowser_url_basepath.'&type=link',  //récupération du répertoire file, img, photo, pages et flash de guppy
        	'filebrowserVideoBrowseUrl' =>     $filebrowser_url_basepath.'&type=video', //récupération du répertoire file de guppy
            'filebrowserWindowWidth' => '850',
            'filebrowserWindowHeight' => '575',           
        );
    }
        
    // --------------------------------------------------------------------

    /**
     * Récupère et renvoie les paramètres de configuration de l'éditeur pour le rédacteur
     * 
     * @return array Tableau contenant les paramètres de configuration de l'éditeur
     */ 
    protected static function _set_CKEditor_config_settings_for_writer()
    {
   	    global $lng;


        $config_editor_basepath = str_replace(CHEMIN, ADMR_SITE_URL, ADMR_EDITORS_CONFIG_PATH).'/ckeditor_config/';
        $filebrowser_url_basepath = str_replace(CHEMIN, ADMR_SITE_URL, ADMR_PUBLIC_ROOT_PATH).'/filemanager.php?lng='.$lng.'&ctrl=file_manage';

        return array(
            'customConfig' => $config_editor_basepath.'config.js',
        	'contentsCss' =>  $config_editor_basepath.'custom/contents.css',
            'templates_files' => array($config_editor_basepath.'custom/templates/templates/default.js'),
            'stylesSet' => 'styles:'.$config_editor_basepath.'custom/styles/styles.js',
            
            'filebrowserBrowseUrl' =>    $filebrowser_url_basepath.'&type=link' , //récupération du file, img, photo, pages de guppy
        	'filebrowserImageBrowseUrl' =>  $filebrowser_url_basepath.'&type=image', //récupération du répertoire img et photo de guppy
        	'filebrowserImageBrowseLinkUrl' => $filebrowser_url_basepath.'&type=link',  //récupération du répertoire file, img, photo, pages de guppy
        	'filebrowserVideoBrowseUrl' =>     $filebrowser_url_basepath.'&type=video', //récupération du répertoire file de guppy
            'filebrowserWindowWidth' => '850',
            'filebrowserWindowHeight' => '575',              
        );
    }
        
    // --------------------------------------------------------------------

    /**
     * Récupère et renvoie les infos concernants les smileys
     * 
     * @param string Type d'infos renvoyées ('path', 'images', 'descriptions')
     * @return mixed Informations sous la forme d'une chaine ('path') ou d'un tableau ('images', 'descriptions')
     */ 
    public static function get_smileys_infos($return = 'images')
    {
        $smileys_path = is_dir(ADMR_SMILEYS_PATH) ? ADMR_SMILEYS_PATH.'/' : CHEMIN.'inc/ckeditor/plugins/smiley/images/';
                
		if ($return == 'path') {
            return ADMR_SITE_URL.str_replace('../', '', $smileys_path);
        } 
        elseif ($return == 'images' || $return == 'descriptions') {
            $files = is_dir($smileys_path) ? scandir($smileys_path) : array();
            $images = array();
            $descriptions = array();
            
            foreach($files as $file) {
                if (is_file($smileys_path.$file) && $file != 'index.php') {
                    $images[] = $file;
                    $descriptions[] = basename($file, strrchr($file, '.'));
                }
            } 
            
            return $$return;
        }
    }
    
    // --------------------------------------------------------------------
    
    /**
     * Affiche l'éditeur WYSIWYG tinyMCE
     * 
     * @param string Nom de l'éditeur
     * @param string Contenu de l'éditeur
     * @param array Paramètres de configuration (optionnels)
     * @return string
     */
/*    public static function tinyMCE($name, $contents, $config_settings = array())
    {
    	global $lng;
    
        settype($config_settings, 'array');
 */       
        /**
         * Définition des paramètres de configuration de l'éditeur
         */
/*        $config_settings = array_merge(
            array(
                'baseHref' => ADMR_SITE_URL,
                'language' => $lng,
            	
                'customConfig' => ADMR_EDITORS_CONFIG_PATH.'/ckeditor_config/config.js',
            	'contentsCss' => ADMR_EDITORS_CONFIG_PATH.'/ckeditor_config/custom/contents.css',
                'templates_files' => array(ADMR_EDITORS_CONFIG_PATH.'/ckeditor_config/custom/templates/templates/default.js'),
                'stylesSet' => 'styles:'.ADMR_EDITORS_CONFIG_PATH.'/ckeditor_config/custom/styles/styles.js',
                
            	'filebrowserBrowseUrl' => ADMR_PUBLIC_ROOT_PATH.'/filemanager.php?lng='.$lng.'&ctrl=file_manager&type=link' , //récupération du file, img, photo, pages et flash de guppy
            	'filebrowserImageBrowseUrl' => ADMR_PUBLIC_ROOT_PATH.'/filemanager.php?lng='.$lng.'&ctrl=file_manager&type=image', //récupération du répertoire img et photo de guppy
            	'filebrowserImageBrowseLinkUrl' => ADMR_PUBLIC_ROOT_PATH.'/filemanager.php?lng='.$lng.'&ctrl=file_manager&type=link', //récupération du répertoire file, img, photo, pages et flash de guppy
            	'filebrowserFlashBrowseUrl' => ADMR_PUBLIC_ROOT_PATH.'/filemanager.php?lng='.$lng.'&ctrl=file_manager&type=flash', //récupération du répertoire flash de guppy
                
                'smiley_path' => self:: get_smileys_infos('path'),
                'smiley_images' => self:: get_smileys_infos('images'),
                'smiley_descriptions' => self:: get_smileys_infos('descriptions'),   
            ),
            $config_settings
        );
 */       //

        /**
         * Création de l'éditeur
         */
/*        require_once ADMR_LIBRARIES_PATH.'/tinymce.php';
    	
        $editor = new TinyMCE() ;
        $editor -> basePath = ADMR_SITE_URL.'inc/tinymce/';
        $editor -> replace($name, $config_settings);
        // 
    }
*/    
    // --------------------------------------------------------------------
    
    /**
     * Affiche un éditeur NON WYSIWYG 
     * 
     * @param string $name Nom de l'éditeur
     * @param string $width Largeur de l'éditeur (voir fichier de condif)
     * @param string $height Hauteur de l'éditeur
     * @param string $value Contenu de l'éditeur
     * @return string
     */
    public static function TEXTAREA_editor($name, $width, $height, $value, $params = array(), $path_editors = '')
    {    
        // TODO
    }    
    
    // --------------------------------------------------------------------

}