<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class File_helper
{
	/**
	 * Ecrit des données dans un document .inc de la base de données
     *
     * @access public 
	 * @param string Nom du fichier(sans extension) contenant le document de la base de donnée
     * @param $data mixed Donnée à écrire 
	 * @param string Extension du fichier contenant le document de la base de donnée	 
	 * @return boolean
	 */
	public static function write($basename, $data, $ext = '.inc')
	{
		$filename = $basename.$ext;
		
		return file_put_contents($filename, $data, LOCK_EX);
	}

	// --------------------------------------------------------------------

	/**
	 * Récupère dans un tableau les données enregistrées dans un document .inc de la base de données
     * 
     * @access public 
	 * @param string Nom du fichier (sans extension) contenant le document de la base de donnée
	 * @param string Extension du fichier contenant le document de la base de donnée	 
	 * @return array Tableau contenant les données enregistrées dans le document .inc de la base de donnée
	 */
	public static function read($basename, $ext = '.inc')
	{
		$data = array();
		$filename = $basename.$ext;
		
		if (is_file($filename)) {
			$data = file_get_contents($filename);
		}
		return $data;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute du contenu à la fin dans un fichier
     * 
     * @access public 
	 * @param string Le chemin du fichier où l'on doit écrire les données
	 * @param string|array Contenu à ajouter
	 * @param integer Flags peut prendre FILE_USE_INCLUDE_PATH, FILE_APPEND et/ou LOCK_EX (acquière un verrou exclusif),
	 *                      cependant, l'option FILE_USE_INCLUDE_PATH doit être utilisée avec précaution
	 * @return array or string
	 */
	public static function append($filename, $content, $flags = null)
	{
		$data = @file_get_contents($filename);

        // If $content is an array, convert it to a string
        if (is_array($content)) {
            $content = implode('', $content);
        }
		
        // If we don't have a string, throw an error
        if (!is_scalar($content)) {
            user_error('append() The 2nd parameter should be either a string or an array', E_USER_WARNING);
            return false;
        }
		
		return file_put_contents($filename, "$data$content", $flags);
	}

}  // End Class