<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_docs_helper.php';

class Manage_articles_helper extends Manage_docs_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri    
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct($writer_rights = array())
    {
        parent :: __construct(TYP_ART, $writer_rights);    
        
        $this -> CI -> load_library('writer_acl', $writer_rights);
        $this -> CI -> load_model('articles_menuitems_index_model');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }
    
	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        parent :: search();       
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return parent :: set_infos_page_content();
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        return parent :: set_menu_plugin_items();
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
        $headers = parent :: _set_data_table_headers();
        
        if ($this -> CI -> writer_acl -> is_allowed('menuitems_manage')) {
            $headers[] = parent :: _set_data_table_header_for_commands();
        }

        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {    	
        $cells = parent :: _set_data_table_cells($record);
        
        if ($this -> CI -> writer_acl -> is_allowed('menuitems_manage')) {
            $cells[] = parent :: _set_data_table_cell_for_commands($record);
        }
        
        return $cells;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{
        $id = $record['id'];
        $boxmenu = $record['boxmenu'];
       
        $view = '';

        if ($this -> CI -> writer_acl -> is_allowed('menuitems_manage')) {

            // Ajout d'une nouvel item de menu 
            if ($this -> CI -> writer_acl -> is_allowed('menuitems_add')) {
                $view .= Html_helper :: addA(
        			$href = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=add_articles_menuitems&amp;itemdocid='.$id,
        			$contents = Html_helper :: addImg(
        				$path = ADMR_IMG_ADD_FILE,
        				$alt = ucfirst($this -> _lang['add_menu_item_for_article']),
        				$attr = array(
        					'title' => $alt,
        					'border' => '0'
        				)
        			)
                    .'&nbsp;&nbsp;',
        			$attr = array()
        		);
            }
        	
            // Accès à la gestion des items de menu            
            $view .= Html_helper :: addA(
    			$href = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=manage_articles_menuitems&amp;sort='.$this -> _config['sort_option_by_default'].'&amp;itemdocid='.$id,
    			$contents = Html_helper :: addImg(
    				$path = ADMR_IMG_EXPLORER,
    				$alt = ucfirst($this -> _lang['show_all_menu_items_for_article']),
    				$attr = array(
    					'title' => $alt,
    					'border' => '0'
    				)
    			).'&nbsp;('.$this -> _get_nb_menuitems_for_article($id).')',
    			$attr = array()
    		);
        }		  
        
        return $view;
	}
    
	// --------------------------------------------------------------------
 
 	/**
	 * Renvoie le nombre d''items de menus associés à l'article
     *
     * @access private 
	 * @param integer Identifiant de l'article
	 * @return integer nombre d'items de menus associés à l'article
	 */
    private function _get_nb_menuitems_for_article($art_id)
    {
        $menuitems = $this -> CI -> articles_menuitems_index_model -> get_menuitems_by_art_id($art_id);
       
        if(! ADMR_IS_ADMIN) {
            $menuitems = $this -> CI -> writer_docs_model -> get_many_by_id(array_keys($menuitems));
        }
        
        return count($menuitems);
    }
    
} //End of Class