<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

abstract class Manage_docs_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri
    protected $_doc_infos = array('type' => '', 'name' => ''); // Infos concernant le document (type, name)   
    protected $_writer_rights = array(); // Droits du rédacteur    
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
	/**
	 * constructeur
     * 
     * @access public
     * @param string Type du document de guppy (TYP_ART, TYP_NEWS, ...)
     * @param array Tableau contenant les droits du rédacteur
	 * @return void
	 */	
    public function __construct($doc_type = '', $writer_rights = array())
    {
        parent :: __construct();
     
        $this -> _doc_infos = $this -> _set_doc_infos($doc_type);
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        $this -> CI -> load_library('writer_acl', $this -> _writer_rights);
        $this -> CI -> load_model('guppy_doc_model'); // Model des documents de guppy
        $this -> CI -> load_model($this -> _doc_infos['name'].'_model'); // Model du type de document                      
        
        if (ADMR_IS_ADMIN) {
            $this -> CI -> load_model('guppy_docid_model'); // Model du fichier docid de guppy
        } else {
            $this -> CI -> load_model('writer_docs_model', array('id' => !empty($this -> _writer_rights['id']) ? $this -> _writer_rights['id'] : NULL)); // Model des documents du rédacteur           
        }
       
        /**
         * Controle de sécurité
         */
        if (! ADMR_IS_ADMIN && ! $this -> _is_doc_allowed()) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
        //             
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * renvoie les paramètres utilisés dans la page
     * 
     * @access public
	 * @return void
	 */	
/*    public function get_params()
    {
        return $this -> _params;	// Paramètres         
    }
*/
	// --------------------------------------------------------------------

	/**
	 * renvoie les options de tri des données
     * 
     * @access public
	 * @return void
	 */	
/*    public function get_sort_options()
    {
        return $this -> _sort_options;	// Options de tri         
    }
*/
	// --------------------------------------------------------------------

	/**
	 * définit les propriétés du document (type et nom)
     * 
     * @access protected
     * @param string Type du document
	 * @return array Tableau contenant les informations (type, nom) du document
	 */	
    protected function _set_doc_infos($doc_type = '')
    {
        $this -> _doc_infos = Model :: get_doc_infos_by_type($doc_type);

        if (empty($this -> _doc_infos['type']) || empty($this -> _doc_infos['name'])) {
            die('ERROR : vous devez définir le type et le nom du document');    
        }        
        
        return $this -> _doc_infos;        
    }

	// --------------------------------------------------------------------

	/**
	 * définit les droits du rédacteur
     * 
     * @access protected
     * @param array Tabelau définissant les droits du rédacteur (vide par défaut) 
	 * @return array Tableau contenant les droits du rédacteur
	 */	
    protected function _set_writer_rights($writer_rights = array())
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;        
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'status_asc', 'status_desc');	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = parent :: _set_params();       
        $this -> _params['docid'] = trim(Var_helper :: import('docid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-');
        
        return $this -> _params;
    }
    
	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }
    
	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $data = array(
            'lang' => $this -> _lang,
            'content' => $this -> _build_form_data_filtering(),
        );        
        
        $this -> render_page('public_search_records_layout', $data);       
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_'.$this -> _doc_infos['name']]);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     *
	 * @access public
	 */	
    public function set_header_addons()
    {
        return parent :: set_header_addons(); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_'.$this -> _doc_infos['name']];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_'.$this -> _doc_infos['name'].'_helper');

        if (ADMR_IS_ADMIN) {
            $menu_plugin_items = $this -> CI -> {'plugin_menu_for_'.$this -> _doc_infos['name'].'_helper'} -> set_admin_items($this -> _doc_infos['name'], $this -> _lang, $this -> _config, $this -> _writer_rights);        

//            $menu_plugin_items = Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
//            $this -> CI -> load_helper('plugin_menu_for_'.$this -> _doc_infos['name'].'_helper');
            
            $menu_plugin_items = $this -> CI -> {'plugin_menu_for_'.$this -> _doc_infos['name'].'_helper'} -> set_public_items($this -> _doc_infos['name'], $this -> _lang, $this -> _config, $this -> _writer_rights);        
        }
        
        return $menu_plugin_items;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements du rédacteur
     * 
     * @access public
	 * @return string code html
	 */
    protected function _get_records()
    {
        $records = array();
        $doc_ids = empty($this -> _params['docid']) ? array() : explode('-', $this -> _params['docid']);
        
        if (ADMR_IS_ADMIN) {
            $records = $this -> CI -> guppy_docid_model -> get(array('type' => $this -> _doc_infos['type'], 'status' => array('a','i'), 'id' => $doc_ids), $this -> _params['sort']);            
        } else {
            $records = $this -> CI -> writer_docs_model -> get(array('type' => $this -> _doc_infos['type'], 'id' => $doc_ids), $this -> _params['sort']);
        }        

        return $records;       
    }

	// --------------------------------------------------------------------

	/**
	 * Filtre les enregistrements et renvoie le résultat
     * 
     * @access protected
     * @param array Enregistrements à filtrer
	 * @return array Tableau contenant les enregistrements qui ont passés le(s) filtre(s)
	 */
    protected function _filter_records($records)
    {
        return $records;       
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_select_actions_for_update_records()
    {
        $actions = array();
    
        // (Dés)activation
        if ($this -> CI -> writer_acl -> is_allowed($this -> _doc_infos['name'].'_act')) {
            $actions[] = array('label' => ucfirst($this -> _lang['activate_docs_selected']),   'value' => 'a');
            $actions[] = array('label' => ucfirst($this -> _lang['inactivate_docs_selected']), 'value' => 'i');
        }
        
        // Suppression
        if ($this -> CI -> writer_acl -> is_allowed($this -> _doc_infos['name'].'_del')) {
            $actions[] = array('label' => ucfirst($this -> _lang['delete_docs_selected']), 'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_docs_definitively'])));
        }

        return $actions;
    }
   
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected

     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return void
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
        // (Dés)Activation des enregistrements
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression des enregistrements
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return string code html
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        if ($this -> CI -> writer_acl -> is_allowed($this -> _doc_infos['name'].'_act')) {
            if (!ADMR_IS_ADMIN) {
                $this -> CI -> writer_docs_model -> update_status_by_id($records_ids, $action); // Documents du rédacteur   
            }
                        
            $this -> CI -> guppy_doc_model -> update_status_by_id($records_ids, $action); // Documents de guppy
            
            return TRUE;
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return string code html
	 */
    protected function _delete_records($records_ids)
    {
        if ($this -> CI -> writer_acl -> is_allowed($this -> _doc_infos['name'].'_del')) {
            if (!ADMR_IS_ADMIN) {
                $this -> CI -> writer_docs_model -> delete_by_id($records_ids); // Documents du rédacteur
            }
            
            $this -> CI -> guppy_doc_model -> update_status_by_id($records_ids, 'd'); // Documents de guppy
            
            return TRUE;
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();    
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string
	 */	
    protected function _build_form_data_filtering()
    {
        return '';
    }

	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }

	// --------------------------------------------------------------------
  
	/**
	 * ajoute des données supplémentaires à l'enregistrement
     * 
	 * @access protected
     * @param array Tableau de données initiales de l'enregistrement
	 * @return array Tableau contenant les nouvelles données de l'enregistrement
	 */    
    protected function _add_more_data_for_record($record)
    {
        return $this -> CI -> {$this -> _doc_infos['name'].'_model'} -> read($record['id']);
    }
  
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
            parent :: _set_data_table_header_for_description($this -> _lang['title']),
            parent :: _set_data_table_header_for_status(),            
		);

        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            parent :: _set_data_table_cell_for_id($record),
			parent :: _set_data_table_cell_for_description($record),
            parent :: _set_data_table_cell_for_status($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        if (!empty($this -> _writer_rights[$this -> _doc_infos['name'].'_edit'])) {
            return parent :: _add_contents_for_td_description($record);
        } else {
            return $this -> _get_text_for_td_description($record);
        }
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;

        return Url_helper :: build_uri(
            $params = array_merge($this -> _params, array('id' => $record['id'])),
            $basehref = $base_href.'&ctrl=add_'.$this -> _doc_infos['name'],
            $anchor = 'z2'
        );
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le texte de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_text_for_td_description($record)
    {
        return $this -> CI -> {$this -> _doc_infos['name'].'_model'} -> set_doc_heading($record);        
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access protected
     * @return boolean
	 */
    protected function _is_doc_allowed()
    {   
        if (!empty($this -> _writer_rights[$this -> _doc_infos['name'].'_manage'])) // Autorisation d'accès à la section du document
        { 
            return TRUE;
        }
        
        return FALSE;    
    }

	// --------------------------------------------------------------------

} //End of Class