<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Manage_files_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
    protected $_writer_rights = array(); // Droits du rédacteur
    //
    private $_dir_path = '';             // Chemin du répertoire
    private $_errors = array();          // Mise en cache des erreurs
    private $_type = '';                 // Type de fichier
    private $_target = '';               // Cible du lien
    private $_CKEditorFuncNum = 0;       // Identifiant de l'éditeur CKEditor
    private $_addon = '';                // Nom de l'addon (nécessaire pour récupérer sa config)   
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {        
        $this -> CI =& Controller :: get_instance();
        
        $this -> CI -> load_helper('var_helper');
        $this -> CI -> load_helper('dir_helper');
        $this -> CI -> load_helper('url_helper');
    
        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);
        
        $this -> _addon = Var_helper :: import('addon', 'POST_GET', null, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))); //
        $this -> _dir_path = Var_helper :: import('dir_path', 'POST_GET', null, array('trim'), array(array($this, '_is_valid_dir_path')));
        $this -> _type = Var_helper :: import('type', 'POST_GET', '', array('trim'), array(array('Var_helper', 'is_alpha_num_dash')));
        $this -> _target = Var_helper :: import('target', 'POST_GET', '', array('trim'), array(array('Var_helper', 'is_alpha_num_dash')));
        $this -> _CKEditorFuncNum = Var_helper :: import('CKEditorFuncNum', 'POST_GET', '', array('trim'), array(array('Var_helper', 'is_digit'))); // Nécessaire pour CKEditor
        
        if (! ADMR_IS_ADMIN && empty($this -> _writer_rights['files_manage'])) {
            Url_helper :: redirect('display_error&type=disallowed');
        }

        if (!empty($this -> _addon)) {
            $this -> CI -> load_addon_config($this -> _addon);
            $this -> _config = $this -> CI -> get_config();
        }

        if (!empty($this -> _type) && $this -> _is_valid_type($this -> _type)) {
            $this -> _writer_rights['files_dirs_list_allowed'] = $this -> _filter_directories_by_type($this -> _writer_rights['files_dirs_list_allowed'], $this -> _type);           
        }

        if (!$this -> _is_allowed_access_dir($this -> _dir_path)) {
            $this -> _dir_path = $this -> _get_dir_by_default($this -> _type);
            
            if (empty($this -> _dir_path)) {
                Url_helper :: redirect('display_error&type=disallowed');
            }           
        }        
    }

	// --------------------------------------------------------------------

    public function index()
    {        
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => $this -> _build_form_uri(),
            'base_href_uri' => $this -> _build_base_href_uri(),
            'optional_href_uri' => $this -> _build_optional_href_uri(),
            'is_allowed_create_dir'  => $this -> _is_allowed_create_dir(),
            'is_allowed_upload_file' => $this -> _is_allowed_upload_file(),
            'is_allowed_rename_dir'  => $this -> _is_allowed_rename_dir(),
            'is_allowed_rename_file' => $this -> _is_allowed_rename_file(),
            'is_allowed_delete_dir'  => $this -> _is_allowed_delete_dir(),
            'is_allowed_delete_file' => $this -> _is_allowed_delete_file(),
            'dir_listing' => $this -> _list_dir($this -> _dir_path),
            'dir_path' => $this -> _dir_path,
            'type' => $this -> _type,
            'target' => $this -> _target,
            'CKEditorFuncNum' => $this -> _CKEditorFuncNum,  // Nécessaire pour CKEditor
            'addon' => $this -> _addon, // Nécessaire pour addon           
            'allowed_ext' => $this -> _get_file_ext_allowed_by_type($this -> _type),
            'denied_ext' => $this -> _get_file_ext_denied_by_type($this -> _type),
            'dirs' => $this -> _get_dirs($this -> _type),
//            'dirs_tree' => $this -> _get_dirs_tree($this -> _type),
            'parent_dir' => $this -> _get_parent_dir($this -> _dir_path),
            'errors' => $this -> _errors,
            'max_file_size' => $this -> _get_max_file_size_allowed(),
        );
     
        $this -> CI -> render_page('file_manager', $data);
    }
     
	// --------------------------------------------------------------------

	/**
	 * Uploader des fichiers
     * 
	 * @access public
	 * @return string Vue html
	 */
    public function upload()
    {
        if (!empty($_FILES)) {
            if ($this -> _add_file()) {                
                Url_helper :: redirect($this -> _build_redirection_uri());
            };
        }
        
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => $this -> _build_form_uri(),
            'is_allowed_upload_file' => $this -> _is_allowed_upload_file(),
            'dir_path' => $this -> _dir_path,
            'type' => $this -> _type,
            'target' => $this -> _target,
            'CKEditorFuncNum' => $this -> _CKEditorFuncNum, // Nécessaire pour CKEditor
            'addon' => $this -> _addon, // Nécessaire pour addon
            'errors' => $this -> _errors,
            'max_file_size' => $this -> _get_max_file_size_allowed(),
            'uri_redirect' => $this -> _build_redirection_uri(),
        );
        
        $this -> CI -> render_page('file_manager_upload', $data);
    }
    
	// --------------------------------------------------------------------

	/**
	 * Crée un répertoire
     * 
	 * @access public
	 * @return string Vue html
	 */
    public function create_dir()
    {
        if (isset($_POST['new_dir'])) {
            if ($this -> _add_dir($_POST['new_dir'])) {                
                Url_helper :: redirect($this -> _build_redirection_uri());
            };
        }
      
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => $this -> _build_form_uri(),
            'is_allowed_create_dir'  => $this -> _is_allowed_create_dir(),
            'dir_path' => $this -> _dir_path,
            'type' => $this -> _type,
            'target' => $this -> _target,
            'CKEditorFuncNum' => $this -> _CKEditorFuncNum, // Nécessaire pour CKEditor
            'addon' => $this -> _addon, // Nécessaire pour addon
            'errors' => $this -> _errors,
            'uri_redirect' => $this -> _build_redirection_uri(),
        );
        
        $this -> CI -> render_page('file_manager_create_dir', $data);
    }

	// --------------------------------------------------------------------

	/**
	 * Récupère les extensions de fichier uniquement autorisées (si vide alors aucune extension est autorisée)
     * Si la valeur est égale à array() alors toutes les extensions sont non autorisées
     * 
	 * @access private
     * @param string Type de fichier
	 * @return null or array Tableau contenant les extensions uniquement autorisées
	 */
    private function _get_file_ext_allowed_by_type($type)
    {
        $file_ext = NULL;
        $config = $this -> _config;

        if (!empty($type) && isset($config['file_manager']['access'][$type]['allowed_ext'])) {
            $file_ext = $config['file_manager']['access'][$type]['allowed_ext'];    
        }
            
        return $file_ext;
    }

	// --------------------------------------------------------------------

	/**
	 * Récupère les extensions de fichier non autorisées 
     * Si la valeur est égale à array() alors toutes les extensions sont autorisées
     * 
	 * @access private
     * @param string Type de fichier
	 * @return null or array Tableau contenant les extensions non autorisées 
	 */
    private function _get_file_ext_denied_by_type($type)
    {
        $file_ext = NULL;
        $config = $this -> _config;

        if (!empty($type) && isset($config['file_manager']['access'][$type]['denied_ext'])) {
            $file_ext = $config['file_manager']['access'][$type]['denied_ext'];    
        }
            
        return $file_ext;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Prévisualise un fichier
     * 
	 * @access public
	 * @return string Vue html
	 */
    public function preview()
    {
        $file_name = Var_helper :: import('file_name', 'POST_GET', '', array('trim'), array(array($this, '_is_valid_file_name')));

        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => $this -> _build_form_uri('manage_files/preview', array(), 'dir_contents'),
            'dir_path' => $this -> _dir_path,
            'file_name' => $file_name,
            'image_size' => $this -> _get_image_size($file_name),
            'uri_redirect' => $this -> _build_redirection_uri(),
        );
        
        $this -> CI -> render_page('file_manager_preview', $data);
    }
   
	// --------------------------------------------------------------------

	/**
	 * Renvoie les dimensions d'une image si elle est valide
     * 
	 * @access public
	 * @param string Nom du fichier
	 * @return array
	 */    
    private function _get_image_size($file_name)
    {
        if (empty($file_name) || @getimagesize(CHEMIN.$this -> _dir_path.'/'.$file_name) == FALSE) {
            return FALSE;
        }
        
        list($width, $height, $type, $attr) = getimagesize(CHEMIN.$this -> _dir_path.'/'.$file_name);

        return array('width' => $width, 'height' => $height, 'attr' => $attr, 'type' => $type);   
    }
   
	// --------------------------------------------------------------------

	/**
	 * Renomme un fichier ou un répertoire s'il est valide
     * 
	 * @access public
	 * @return string Vue html
	 */
    public function rename()
    {
        $old_name = Var_helper :: import('old_name', 'POST_GET', '', array('trim'), array(array($this, '_is_valid_file_or_dir_name')));
        $new_name = Var_helper :: import('new_name', 'POST', '', array('trim'), array());

        $is_dir = (!empty($old_name) && strpos($old_name, '.') === FALSE) ? TRUE : FALSE;        
        
        /** 
         * Renommage
         */
        if (!empty($old_name) && isset($_POST['new_name'])) {
            $is_renamed = ($is_dir) ? $this -> _rename_dir($old_name, $new_name) : $this -> _rename_file($old_name, $new_name);            

            if ($is_renamed) {
                Url_helper :: redirect($this -> _build_redirection_uri());
            }
        }
        //
              
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => $this -> _build_form_uri('manage_files/rename', array(), 'dir_contents'),
            'is_dir' => $is_dir,
            'is_allowed_rename'  => ($is_dir) ? $this -> _is_allowed_rename_dir() : $this -> _is_allowed_rename_file(),
            'dir_path' => $this -> _dir_path,
            'type' => $this -> _type,
            'target' => $this -> _target,
            'CKEditorFuncNum' => $this -> _CKEditorFuncNum, // Nécessaire pour CKEditor
            'addon' => $this -> _addon, // Nécessaire pour addon
            'old_name' => $old_name,
            'new_name' => $new_name,
            'file_ext' => strrchr($old_name, '.'),
            'errors' => $this -> _errors,
            'uri_redirect' => $this -> _build_redirection_uri(),
        );
        
        $this -> CI -> render_page('file_manager_rename', $data);
    }

	// --------------------------------------------------------------------

	/**
	 * Supprime un fichier ou un répertoire s'il est valide
     * 
	 * @access public
	 * @return string Vue html
	 */
    public function delete()
    {
        $file_name = Var_helper :: import('file_name', 'POST_GET', '', array('trim'), array(array($this, '_is_valid_file_or_dir_name')));

        $is_dir = (!empty($file_name) && strpos($file_name, '.') === FALSE) ? TRUE : FALSE;        
        
        /** 
         * Suppression
         */
        if (!empty($file_name) && (!empty($_POST['confirm']) || $this -> _config['file_manager']['confirm_delete'])) {
            $is_deleted = ($is_dir) ? $this -> _delete_dir($file_name) : $this -> _delete_file($file_name);            

            if ($is_deleted) {
                Url_helper :: redirect($this -> _build_redirection_uri());
            }
        }
        //
        
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => $this -> _build_form_uri('manage_files/delete', array(), 'dir_contents'),
            'is_dir' => $is_dir,
            'is_allowed_delete'  => ($is_dir) ? $this -> _is_allowed_delete_dir() : $this -> _is_allowed_delete_file(),
            'dir_path' => $this -> _dir_path,
            'type' => $this -> _type,
            'target' => $this -> _target,
            'CKEditorFuncNum' => $this -> _CKEditorFuncNum, // Nécessaire pour CKEditor
            'addon' => $this -> _addon, // Nécessaire pour addon
            'file_name' => $file_name,
            'errors' => $this -> _errors,
            'uri_redirect' => $this -> _build_redirection_uri(),
        );
        
        $this -> CI -> render_page('file_manager_delete', $data);
    }
    
	// --------------------------------------------------------------------

	/**
	 * Charge un ou plusieurs fichiers s'ils sont valides
     * 
	 * @access private
     * @param  string Chemin du répertoire à créer
	 * @return boolean Résultat de la validation
	 */
    private function _add_file()
    {        
        if ($this -> _is_allowed_upload_file() && !empty($_FILES['userfiles'])) { //AUTORISATION CONFIG
        
            $dir = CHEMIN.$this -> _dir_path;
            $max_file_size = $this -> _get_max_file_size_allowed();

            foreach ($_FILES['userfiles']['error'] as $key => $file_error) {
                
                $error_msg = '';
                $tmp_name = $_FILES['userfiles']['tmp_name'][$key];
                $name = $_FILES['userfiles']['name'][$key];
                $size = $_FILES['userfiles']['size'][$key];
                
                if ($file_error == UPLOAD_ERR_OK) {
                    // Controle si le fichier n'est pas vide
        			if (empty($size)) {
        	     		$error_msg = $this -> _get_upload_error_message('upload_err_empty'); 
        			}
        			//
                    
                    // Controle de la validité du nom du fichier
        			else if ( ! $this -> _is_valid_file_name($name)) {
        	     		$error_msg = $this -> _get_upload_error_message('upload_err_name');
        			}
        			//
        			
        			// Controle si le nom du fichier existe déjà ou non
        			else if (file_exists($dir.'/'.$name)) {
        		 		$error_msg = $this -> _get_upload_error_message('upload_err_exists');
        			}
        			//
        		
        			// Controle de la taille des fichiers
        			else if (!empty($max_file_size) && $size > $max_file_size) {
      					$error_msg = $this -> _get_upload_error_message(UPLOAD_ERR_FORM_SIZE);
        			}
        			//
        
        			// Controle de l'autorisation de l'extension du fichier
        			else if(! $this -> _is_allowed_file_ext($name))
                    { 
        		 		$error_msg = $this -> _get_upload_error_message(UPLOAD_ERR_EXTENSION);	
        			}
        			//

        			// Upload et indexation
        			if (empty($error_msg) && move_uploaded_file($tmp_name, $dir.'/'.$name)) {
    	   				@chmod(CHEMIN.$this -> _dir_path.'/'.$name, 0644);
        			}
        			//
                } else {
                    $error_msg = $this -> _get_upload_error_message($file_error);
                }
                
                if (!empty($error_msg)) {
                    $this -> _errors['upload'][$name] = $error_msg;
                } 
            }
            
            if (empty($this -> _errors['upload'])) {
                return TRUE;
            }
        }
        
        return FALSE;
    }
        
	// --------------------------------------------------------------------

    /**
     * Renvoie la taille maximale (en octet) autorisée pour le fichier uploadé
     * 
     * @access private
     * @return integer Taille (en octet) maximale autorisée pour uploader un fichier
     */
    private function _get_max_file_size_allowed()
    {
        $config_upload = $this -> _config['file_manager']['upload'];
        $config_type = $this -> _config['file_manager']['access'][$this -> _type];
       
        $max_file_size = isset($config_type['max_size']) ? $config_type['max_size'] : $config_upload['max_size'];

        return $max_file_size;
    }
        
	// --------------------------------------------------------------------

    /**
     * Controle si l'extension du fichier est autorisé ou non
     * 
     * @access private
     * @param string Nom du fichier
     * @return boolean
     */
    private function _is_allowed_file_ext($filename)
    {
        $config_upload = $this -> _config['file_manager']['upload'];
        $config_type = $this -> _config['file_manager']['access'][$this -> _type];
       
        $allowed_ext = isset($config_type['allowed_ext']) ? $config_type['allowed_ext'] : $config_upload['allowed_ext'];
        $denied_ext = isset($config_type['denied_ext']) ? $config_type['denied_ext'] : $config_upload['denied_ext'];

        if( ( count($allowed_ext) > 0 && !in_array( strrchr($filename, '.'), $allowed_ext) )
    		     || ( count($denied_ext) > 0 && in_array( strrchr($filename, '.'), $denied_ext) ) )
        { 
     		return FALSE;	
    	}
        
        return TRUE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Renvoie le message d'erreur du chargement d'un fichier
     * 
	 * @access private
     * @param  string Code d'erreur
	 * @return string Message d'erreur correspondant au code d'erreur
	 */
    private function _get_upload_error_message($error_code)
    {
        $error_msg = array(
            UPLOAD_ERR_INI_SIZE   => $this -> _lang['form_errors_msg']['upload_error_ini_size'],
            UPLOAD_ERR_FORM_SIZE  => sprintf($this -> _lang['form_errors_msg']['upload_error_form_size'], round($this -> _get_max_file_size_allowed() / 1024)),
            UPLOAD_ERR_PARTIAL    => $this -> _lang['form_errors_msg']['upload_error_partial'],
            UPLOAD_ERR_NO_FILE    => $this -> _lang['form_errors_msg']['upload_error_no_file'],
            UPLOAD_ERR_NO_TMP_DIR => $this -> _lang['form_errors_msg']['upload_error_no_tmp_dir'],
            UPLOAD_ERR_CANT_WRITE => $this -> _lang['form_errors_msg']['upload_error_file_cant_write'],
            UPLOAD_ERR_EXTENSION  => $this -> _lang['form_errors_msg']['upload_error_file_extension'],
            'upload_err_empty'    => $this -> _lang['form_errors_msg']['upload_error_file_is_required'],
            'upload_err_exists'   => $this -> _lang['form_errors_msg']['upload_error_file_already_exists'],
            'upload_err_name'     => $this -> _lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes'],
        );
        
        if (empty($error_code)) {
            return $error_msg;    
        }
        
        if (is_array($error_code)) {
            return array_intersect_key($error_msg, array_flip($error_code));
        }
        
        return !empty($error_msg[$error_code]) ? $error_msg[$error_code] : $this -> _lang['form_errors_msg']['upload_error_unknown'];
     } 
   
	// --------------------------------------------------------------------

	/**
	 * Ajoute un répertoire s'il est valide
     * 
	 * @access private
     * @param  string Chemin du répertoire à créer
	 * @return boolean Résultat de la création
	 */
    private function _add_dir($dir)
    {
        if ($this -> _is_allowed_create_dir()) { //AUTORISATION CONFIG
            $parent_dir = CHEMIN.$this -> _dir_path;

            // Controle si le nom n'est pas vide
			if (empty($dir) || trim($dir) == '') {
	     		$this -> _errors['new_dir'] = $this -> _lang['form_errors_msg']['name_required']; 
			}
			//
            
            // Controle de la validité du nom du répertoire
			elseif ( ! $this -> _is_valid_dir_name($dir) ) {
	     		$this -> _errors['new_dir'] = $this -> _lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes']; 
			}
			//
			
			// Controle si le nom du fichier existe déjà ou non
			elseif (is_dir($parent_dir.'/'.$dir)) {
		 		$this -> _errors['new_dir'] = $this -> _lang['form_errors_msg']['name_exists'];
			}
			//

			// Création du répertoire et du fichier index.php
			if (empty($this -> _errors['new_dir'])) {
		        return Dir_helper :: create_dir($parent_dir.'/'.$dir);
			}
        }
        
        return FALSE;
    }
       
	// --------------------------------------------------------------------

	/**
	 * Renomme un fichier s'il est valide
     * 
	 * @access private
     * @param  string Nom du fichier à renommer avec l'extension
     * @param  string Nouveau nom du fichier SANS l'extension
	 * @return boolean Résultat de l'opération
	 */
    private function _rename_file($old_name, $new_name)
    {
        $dir = CHEMIN.$this -> _dir_path;
        
        if ($this -> _is_allowed_rename_file()) { //AUTORISATION CONFIG
			if (is_file($dir.'/'.$old_name)) {
                $ext = strrchr($old_name, '.');

                if (empty($new_name)) {
                    $this -> _errors['rename'] = $this -> _get_rename_error_message('err_empty');
	    		}
	    		
                elseif ( ! Var_helper :: is_alpha_num_dash($new_name)) {
                    $this -> _errors['rename'] = $this -> _get_rename_error_message('err_chars');
	    		}

                elseif (file_exists($dir.'/'.$new_name.$ext)) {
                    $this -> _errors['rename'] = $this -> _get_rename_error_message('err_exist');
	    		}
                 
    			// Renommage du fichier
    			if (empty($this -> _errors['rename'])) {
              		@rename($dir.'/'.$old_name , $dir.'/'.$new_name.$ext);
			  		@chmod($dir.'/'.$new_name.$ext, 0644);
                    
                    return TRUE;
    			}
			}
        }
        
        return FALSE;       
    }
       
	// --------------------------------------------------------------------

	/**
	 * Renomme un répertoire s'il est valide
     * 
	 * @access private
     * @param  string Nom du fichier à renommer avec l'extension
     * @param  string Nouveau nom du fichier SANS l'extension
	 * @return boolean Résultat de l'opération
	 */
    private function _rename_dir($old_name, $new_name)
    {
        $dir = CHEMIN.$this -> _dir_path;
        
        if ($this -> _is_allowed_rename_dir()) { //AUTORISATION CONFIG
            if (is_dir($dir.'/'.$old_name)) {	    

                if (empty($new_name)) {
                    $this -> _errors['rename'] = $this -> _get_rename_error_message('err_empty', TRUE);
	    		}

                elseif ( ! Var_helper :: is_alpha_num_dash($new_name)) {
                    $this -> _errors['rename'] = $this -> _get_rename_error_message('err_chars', TRUE);
	    		}

                elseif (is_dir($dir.'/'.$new_name)) {
	  	   			$this -> _errors['rename'] = $this -> _get_rename_error_message('err_exist', TRUE);
	    		}

    			// Renommage du répertoire
    			if (empty($this -> _errors['rename'])) {
	          		@rename($dir.'/'.$old_name, $dir.'/'.$new_name);
			  		@chmod($dir.'/'.$new_name, 0755);
                     
                    return TRUE;
    			}                
      		}
        }
        
        return FALSE;       
    }
   
	// --------------------------------------------------------------------

	/**
	 * Renvoie le(s) message(s) d'erreur du renommage d'un fichier ou d'un répertoire
     * 
	 * @access private
     * @param  string|array Code(s) d'erreur (si vide alors on renvoie tous les messages d'erreur)
	 * @return string|array Message d'erreur correspondant aux codes d'erreur
	 */
    private function _get_rename_error_message($error_code, $is_dir = FALSE)
    {
        $error_msg = array(
            'err_empty' => $this -> _lang['form_errors_msg']['name_required'],
            'err_exist' => $this -> _lang['form_errors_msg']['name_exists'],
            'err_chars' => $this -> _lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes'],
        );
        
        if (empty($error_code)) {
            return $error_msg;    
        }
        
        if (is_array($error_code)) {
            return array_intersect_key($error_msg, array_flip($error_code));
        }
        
        return !empty($error_msg[$error_code]) ? $error_msg[$error_code] : $this -> _lang['form_errors_msg']['error_unknown'];
    }
       
	// --------------------------------------------------------------------

	/**
	 * Supprime un fichier s'il est valide
     * 
	 * @access private
     * @param  string Nom du fichier à supprimer
	 * @return boolean Résultat de l'opération
	 */
    private function _delete_file($file_name)
    {
        $dir = CHEMIN.$this -> _dir_path;
        
        if ($this -> _is_allowed_delete_file()) { //AUTORISATION CONFIG
			if (is_file($dir.'/'.$file_name)) {
          		return @unlink($dir.'/'.$file_name);
            }
        }
        
        return FALSE;       
    }
       
	// --------------------------------------------------------------------

	/**
	 * Supprime un répertoire s'il est valide
     * 
	 * @access private
     * @param  string Nom du répertoire à supprimer
	 * @return boolean Résultat de l'opération
	 */
    private function _delete_dir($dir_name)
    {
        $dir = CHEMIN.$this -> _dir_path;
        
        if ($this -> _is_allowed_delete_dir()) { //AUTORISATION CONFIG
			if (is_dir($dir.'/'.$dir_name)) {
          		return Dir_helper :: delete_dir($dir.'/'.$dir_name);
            }
        }
        
        return FALSE;       
    }
       
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_files']);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_files'];
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     *
	 * @access public
	 */	
    public function set_header_addons()
    {
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript">$.formUtils.loadModules("module_file_manager", "'.ADMR_JS_PATH.'/form-validator/my_modules/");</script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/file_manager.js"></script>'."\n";
        
        
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/file_manager.css" />';

        return $css.$js;

    }
        
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {           
        $this -> CI -> load_helper('plugin_menu_for_files_helper'); 

        if (ADMR_IS_ADMIN) {
            return Plugin_menu_for_files_helper :: set_admin_items('files', $this -> _lang, $this -> _config, $this -> _writer_rights);
        } else {
            return Plugin_menu_for_files_helper :: set_public_items('files', $this -> _lang, $this -> _config, $this -> _writer_rights);
        }
    }
        
	// --------------------------------------------------------------------

	/**
	 * vérifie si le chemin du répertoire est valide ou non
     * 
	 * @access public
     * @param  string Chemin du répertoire à valider
	 * @return boolean Résultat de la validation
	 */
    public function _is_valid_dir_path($dir_path)
    {
        return (!empty($dir_path) && !preg_match('`[^a-z0-9\-_/]`i', $dir_path) && is_dir(CHEMIN.$dir_path)) ? TRUE : FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * vérifie si le chemin du répertoire est valide ou non
     * 
	 * @access public
     * @param  string Chemin du répertoire à valider
	 * @return boolean Résultat de la validation
	 */
    public function _is_valid_type($type)
    {
        $types = array_keys($this -> _config['file_manager']['access']);
     
        return in_array($type, $types) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------
	/**
	 * vérifie si le nom du répertoire ou du fichier est valide ou non
     * 
	 * @access public
     * @param  string Nom du répertoire à valider
	 * @return boolean Résultat de la validation
	 */
    public function _is_valid_file_or_dir_name($name)
    {
        return (strpos($name, '.') !== FALSE) ? $this -> _is_valid_file_name($name) : $this -> _is_valid_dir_name($name);
    }

	/**
	 * vérifie si le nom du répertoire est valide ou non
     * 
	 * @access public
     * @param  string Nom du répertoire à valider
	 * @return boolean Résultat de la validation
	 */
    public function _is_valid_dir_name($dir_name)
    {
        return preg_match('`[^a-z0-9\-_]`i', $dir_name) ? FALSE : TRUE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * vérifie si le nom du répertoire est valide ou non
     * 
	 * @access public
     * @param  string Nom du répertoire à valider
	 * @return boolean Résultat de la validation
	 */
    public function _is_valid_file_name($file_name)
    {
        return preg_match('`^[a-z0-9\-_]+\.[a-z0-9]{2,}$`i', $file_name) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * vérifie si l'accès au répertoire est autorisé ou non
     * 
	 * @access private
     * @param  string Chemin du répertoire
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_access_dir($dir)
    {
        $writer_rights = $this -> _writer_rights;
        $dirs_access = $writer_rights['files_dirs_manage'];
        $dirs_list_allowed = $writer_rights['files_dirs_list_allowed'];
        
        if (!empty($dir)) {
            
            if ($dirs_access == '1') {
                return TRUE;
            }
            
            if (!empty($dirs_list_allowed)) {

                if (in_array($dir, $dirs_list_allowed)) {
                    return TRUE;
                }
                
                foreach($dirs_list_allowed as $dir_allowed) {
                    if (strpos($dir, $dir_allowed) === 0) {
                        return TRUE;    
                    }                    
                }  
            }        
        }       
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * filtre et renvoie uniquement les répertoires qui sont accessibles selon le type de fichier défini
     * (voir paramètres de configuration)
     * 
	 * @access private
     * @param  array Liste des répertoires à filtrer
     * @param  string Type de fichier
	 * @return array Tableau contenant uniquement les répertoires valides
	 */
    private function _filter_directories_by_type($dirs, $type)
    {
        settype($dirs, 'array'); 

        if (!empty($dirs) && !empty($type) && !empty($this -> _config['file_manager']['access'][$type]['dirs'])) {
            foreach($dirs as $key => $dir) {
                $root_dir = (($pos = strpos($dir, '/')) !== FALSE) ? substr($dir, 0, $pos) : $dir;
                
                if (! in_array($root_dir, $this -> _config['file_manager']['access'][$type]['dirs'])) {
                    unset($dirs[$key]);    
                }                    
            } 
        }
        
        return array_values($dirs);       
    }
    
	// --------------------------------------------------------------------

	/**
	 * Renvoie le chemin du répertoire parent s'il est accessible
     * 
	 * @access private
     * @param  string Chemin du répertoire courant
	 * @return string or FALSE Chemin du répertoire parent
	 */
    private function _get_parent_dir($current_dir_path)
    {
        $dirs = explode('/', $current_dir_path);
        
        array_pop($dirs);
        
        $parent_dir = implode('/', $dirs);
        
        return (!empty($parent_dir) && $this -> _is_allowed_access_dir($parent_dir)) ? $parent_dir : FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Renvoie le chemin du répertoire par défaut
     * 
	 * @access private
     * @param string Type de fichier
	 * @return string or FALSE Chemin du répertoire par default
	 */
    private function _get_dir_by_default($type)
    {
        $upload_dirs = empty($this -> _config['file_manager']['access'][$type]['dirs']) ? $this -> _config['file_manager']['dirs'] : $this -> _config['file_manager']['access'][$type]['dirs'];
        $dirs_access = $this -> _writer_rights['files_dirs_manage'];
        $dirs_list_allowed = $this -> _writer_rights['files_dirs_list_allowed'];   
       
        $upload_dirs = ($dirs_access == '1') ? $upload_dirs : $dirs_list_allowed;
         
        return empty($upload_dirs) ? FALSE : $upload_dirs[0];
    }

 	// --------------------------------------------------------------------

	/**
	 * vérifie si la création de répertoire est autorisée ou non
     * 
	 * @access private
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_create_dir()
    {
        $writer_rights = $this -> _writer_rights;
 //       return true; // debug
        return (!empty($writer_rights['files_dirs_manage']) && !empty($writer_rights['files_dirs_add'])) ? TRUE : FALSE;
    }

 	// --------------------------------------------------------------------

	/**
	 * vérifie si le changement de nom du répertoire est autorisée ou non
     * 
	 * @access private
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_rename_dir()
    {
        $writer_rights = $this -> _writer_rights;
 //       return true; // debug
        return (!empty($writer_rights['files_dirs_manage']) && !empty($writer_rights['files_dirs_edit'])) ? TRUE : FALSE;
    }

 	// --------------------------------------------------------------------

	/**
	 * vérifie si la suppression de répertoire est autorisée ou non
     * 
	 * @access private
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_delete_dir()
    {
        $writer_rights = $this -> _writer_rights;
 //       return true; // debug
        return (!empty($writer_rights['files_dirs_manage']) && !empty($writer_rights['files_dirs_del'])) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * vérifie si le chargement de fichier est autorisé ou non
     * 
	 * @access private
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_upload_file()
    {
        $writer_rights = $this -> _writer_rights;

        return (!empty($writer_rights['files_manage']) && !empty($writer_rights['files_add'])) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * vérifie si le changement de nom du fichier est autorisé ou non
     * 
	 * @access private
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_rename_file()
    {
        $writer_rights = $this -> _writer_rights;

        return (!empty($writer_rights['files_manage']) && !empty($writer_rights['files_edit'])) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * vérifie si la suppression du fichier est autorisée ou non
     * 
	 * @access private
	 * @return boolean Résultat de la vérification
	 */
    private function _is_allowed_delete_file()
    {
        $writer_rights = $this -> _writer_rights;

        return (!empty($writer_rights['files_manage']) && !empty($writer_rights['files_del'])) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Renvoie le contenu (sous-répertoires et fichiers) du répertoire
     * 
	 * @access private
     * @param  string Chemin du répertoire
     * @param  string Permet de renvoyer uniquement les fichiers (files) ou les répertoires (dirs)
	 * @return array Tableau contenant le contenu (sous-répertoires et fichiers) du répertoire
	 */
    private function _list_dir($dir_path, $restrict_to = FALSE)
    {
        $dbdirs = array();
        $dbfiles = array();
        
        if (!empty($dir_path)) {
            
            $i = 0;            
            $dir = @opendir(CHEMIN.$dir_path);
            
            while (false !== ( $file = readdir($dir) ) ) {
                if( is_dir(CHEMIN.$dir_path.'/'.$file) && $file != '.' && $file != '..') {
                	$dbdirs[$i]['name'] = $file;              // Nom
                    $dbdirs[$i]['type'] = 'dir';              // Type
                  	$dbdirs[$i]['icon'] = ADMR_IMG_DIRECTORY; // Icon
                    $dbdirs[$i]['filesize'] = '--';           // Size                   
            	 }
                 elseif ( is_file(CHEMIN.$dir_path.'/'.$file) && $file != 'index.php') {
                    $dbfiles[$i]['name'] = $file;   // Nom
                    $dbfiles[$i]['type'] = 'file';  // Type                   
                    $dbfiles[$i]['ext'] = strrchr($file,'.'); // Extension
            		
                    // Icone du fichier
                    $path_parts = str_replace('.', '', $dbfiles[$i]['ext']);
                    
            	  	if( is_file(ADMR_IMG_FILES_PATH.'/'.$path_parts.'.gif') ) {
                  	  	$dbfiles[$i]['icon'] = ADMR_IMG_FILES_PATH.'/'.$path_parts.'.gif';
            	  	} else {
                  	  	$dbfiles[$i]['icon'] = ADMR_IMG_FILES_PATH.'/unknow.gif';	  
            	  	}
                    //
                    
                    // Taille du fichier
            	  	$filesize = filesize(CHEMIN.$dir_path.'/'.$file) / 1024;
            	  	$dbfiles[$i]['filesize'] = number_format($filesize, 0, ',', ' ');
                    //
              	}
                $i++;
            }
            
            closedir($dir);
        }
         
        if ($restrict_to == 'files') {
            sort($dbfiles);
            return $dbfiles;
        }

        if ($restrict_to == 'dirs') {
            sort($dbdirs);
            return $dbdirs;
        }
             
        return array_merge($dbdirs, $dbfiles);
    }
    
	// --------------------------------------------------------------------

	/**
	 * Renvoie la liste des répertoires accessibles
     * 
	 * @access private
	 * @return array Tableau contenant les répertoires accessibles
	 */
    private function _get_dirs($type)
    {
        $upload_dirs = empty($this -> _config['file_manager']['access'][$type]['dirs']) ? $this -> _config['file_manager']['dirs'] : $this -> _config['file_manager']['access'][$type]['dirs'];
        $dirs_access = $this -> _writer_rights['files_dirs_manage'];
        $dirs_list_allowed = $this -> _writer_rights['files_dirs_list_allowed'];
        $dirs = array();
   
        $upload_dirs = ($dirs_access == '1') ? $upload_dirs : $dirs_list_allowed;
        
        foreach($upload_dirs as $dir) {
            $dirs = $dirs + array($dir => Dir_helper :: get_dirs_path_name(CHEMIN.$dir)); 
        }
     
        return $dirs;
    }
   
	// --------------------------------------------------------------------

	/**
	 * Renvoie l'arborescence des répertoires accessibles
     * 
	 * @access private
     * @access string Type de donnée
	 * @return array Tableau contenant les répertoires accessibles
	 */
    private function _get_dirs_tree($type)
    {
        $upload_dirs = empty($this -> _config['file_manager']['access'][$type]['dirs']) ? $this -> _config['file_manager']['dirs'] : $this -> _config['file_manager']['access'][$type]['dirs'];
        $dirs_access = $this -> _writer_rights['files_dirs_manage'];
        $dirs_list_allowed = $this -> _writer_rights['files_dirs_list_allowed'];
        $dirs = array();
   
        $upload_dirs = ($dirs_access == '1') ? $upload_dirs : $dirs_list_allowed;

        foreach($upload_dirs as $dir) {
            $subdirs = Dir_helper :: tree2array(CHEMIN.$dir, false, true);

            $dirs = $dirs + array($dir => $this -> _array2tree($subdirs, $dir, $type)); 
        }
        
        return $dirs;
    }
   
	// --------------------------------------------------------------------

	/**
	 * Crée et renvoie une liste représentant l'arborescence du contenu d'un répertoire
     *
     * @access private 
     * @param array Tableau contenant la structure de l'arborescence du contenu d'un répertoire
     * @param string Chemin du répertoire parent
     * @param string Type
     * @return string Arborescence sous forme de la liste html (<ul>)
	 */
    private function _array2tree($dirs, $parent_dir, $type = '')
    {
        $tree = '';
        
        settype($dirs, 'array');

        foreach($dirs as $dir)
        {
          //  $href = htmlentities($_SERVER['PHP_SELF']).'?lng='.ADMR_LNG.'&amp;ctrl=manage_files&amp;dir_path='.$parent_dir.'/'.$dir['path'].'&amp;type='.$type;
            $href = Url_helper :: build_uri(array('dir_path' => $parent_dir.'/'.$dir['path']), $this -> _build_base_href_uri(), 'dir_contents');
            
            $class = ($this -> _dir_path == $parent_dir.'/'.$dir['path']) ? ' class="selected"' : '';
            
            $tree .= '<li'.$class.'><a href="'.$href.'">'.$dir['name'].'</a>';
            
            if (!empty($dir['children'])) {
                $tree .= "<ul>";
                
                $tree .= $this -> _array2tree($dir['children'], $parent_dir, $type);
                
                $tree .= "</ul>";
            }
            
            $tree .= '</li>';            
        }
        
        return $tree;       
    }
    
	// --------------------------------------------------------------------

    /**
     * construit l'url de redirection après la validation
     * 
     * @param string Nom du controller (optionnel)
     * @param array Tableau contenant les champs à placer dans la requête avec leur valeur (optionnel)
     * @param string Nom de l'ancre (optionnel)
     * @return string Uri de redirection
     */
    private function _build_redirection_uri()
    {        
        $query_params = array(
            'dir_path' => $this -> _dir_path,
            'CKEditorFuncNum' => $this -> _CKEditorFuncNum, // Nécessaire pour CKEditor
        );
        
        $uri = $this -> _build_base_href_uri().$this -> _build_optional_href_uri($query_params).$this -> _build_anchor_href_uri('dir_contents');
        
              
        return $uri;       
    }
    
	// --------------------------------------------------------------------

    /**
     * construit l'uri du formulaire
     * 
     * @param string Nom du controller (optionnel)
     * @param array Tableau contenant les champs à placer dans la requête avec leur valeur (optionnel)
     * @param string Nom de l'ancre (optionnel)
     * @return string Uri du formulaire
     */
    private function _build_form_uri($controller = 'manage_files', $query_params = array(), $anchor = '')
    {        
        return Url_helper :: build_uri($query_params, $this -> _build_base_href_uri($controller), $anchor);        
    }
    
	// --------------------------------------------------------------------

    /**
     * construit la base de l'uri des liens
     * 
     * @param string Nom du controller (optionnel)
     * @return string Uri du formulaire
     */
    private function _build_base_href_uri($controller = 'manage_files')
    {
        // Déclaration des champs par défaut
        $query_fields = array(
            'lng' => ADMR_LNG,
            'pg' => (ADMR_IS_ADMIN && !strrpos($_SERVER['PHP_SELF'], 'filemanager.php')) ? 'plugin' : '',
            'plug' => (ADMR_IS_ADMIN && !strrpos($_SERVER['PHP_SELF'], 'filemanager.php')) ? ADMR_DIRNAME.'/admin' : '',
            'ctrl' => !empty($controller) ? $controller : 'manage_files',
        );
       
        $uri =  htmlentities($_SERVER['PHP_SELF']).'?'.http_build_query($query_fields);          

        return $uri;        
    }
    
	// --------------------------------------------------------------------

    /**
     * construit la requête de l'uri des liens contenant les paramètres optionnels
     * 
     * @param array Paramètres optionnels à faire passer dans l'url (optionnel)
     * @param string Ancre (optionnel)
     * @return string Uri du formulaire
     */
    private function _build_optional_href_uri($query_params = array(), $anchor = '')
    {
        // Déclaration des champs par défaut
        $query_params = array_merge(array(
                'type' => $this -> _type,
                'target' => $this -> _target,
                'addon' => $this -> _addon, // Nécessaire pour addon
            ),
            $query_params
        );

        $query_uri = '';
        
        foreach($query_params as $param => $value) {
            if ($value != '') {
                $query_uri .= '&'.$param.'='.$value;
            }
        }
        
        return $query_uri;        
    }
    
	// --------------------------------------------------------------------

    /**
     * construit l'ancre dans la requête de l'uri des liens
     * 
     * @param string Ancre (optionnel)
     * @return string Ancre
     */
    private function _build_anchor_href_uri($anchor)
    {
        if (!empty($anchor)) {
            $anchor = '#'.$anchor;    
        }
        
        return $anchor;        
    }
   
	// --------------------------------------------------------------------

	/**
	 * définit les droits du rédacteur
     * 
     * @access private
     * @param mixed Options de tri
	 * @return void
	 */	
    private function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }
   
	// --------------------------------------------------------------------
    
} // End Class