<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.10 (2016/10/21)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

class Manage_groups_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
    protected $_params = array();       // Données récupérés par post ou get
    protected $_sort_options = array();	// Options de tri
    //
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        parent :: __construct();
        
        $this -> CI -> load_model('writer_model');
        $this -> CI -> load_model('group_model');

        if (! ADMR_IS_ADMIN && empty($this -> _writer_rights['groups_manage'])) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'ch_asc', 'ch_desc');	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = array_merge(
            parent :: _set_params(),
            array(
                'groupid'  => trim(Var_helper :: import('groupid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'writerid' => trim(Var_helper :: import('writerid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'doctype'  => trim(Var_helper :: import('doctype', '', NULL, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))), '-'),
            )
        );
       
        return $this -> _params;
    }

	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $filter = Var_helper :: import('filter', 'post', 0);
        $writerids = Var_helper :: import('writerids', 'post', array());
        $groupids = Var_helper :: import('groupids', 'post', array());
        $uri = 'manage_groups';

		/**
		 * Sélection des utilisateurs par les identifiants de leur groupe
		 */
        if ($filter == '1' && !empty($groupids)) {
            $uri .= is_array($groupids) ? '&groupid='.implode('-', $groupids) : '';         
        }
        		
		Url_helper :: redirect($uri);
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_groups']);
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent = parent :: set_header_addons();

        $js = '<script type="text/javascript" src="'.ADMR_JS_PATH.'/toggle_records_selection_display_for_management.js"></script>'."\n";
        
        $css = '';
                
        return $parent.$css.$js;
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_groups'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_groups_helper');
        
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            return $this -> CI -> plugin_menu_for_groups_helper -> set_public_items('groups', $this -> _lang, $this -> _config, $this -> _writer_rights);         
        }  
    }

	// --------------------------------------------------------------------

	/**
	 * Affecter des rédacteurs à un groupe
     * 
     * @access public
	 * @return string
	 */	
    public function assign_writers_to_group()
    {
        $group_id = Var_helper :: import('groupid', '', 0, array(), array(array('Var_helper', 'is_digit')));
        $writer_ids = Var_helper :: import('writerids', 'post', array());
        $action = Var_helper :: import('action', 'post', '', array(), array(array('Var_helper', 'is_in_array[add]')));
        $validation = FALSE;
        
        if (!empty($group_id) && !empty($writer_ids)) {
            if ($action == 'add') {
                $this -> CI -> writer_model -> update_groupid_by_id($writer_ids, $group_id);
                $validation = TRUE;               
            }
        }
        
        $data = array(
            'message'  => ($validation) ? $this -> _lang['assignement_writers_to_group_succeed'] : $this -> _lang['assignement_writers_to_group_failed'],
            'validation' => $validation,
            'lang' => $this -> _lang,
            'form_data_filtering' => $this -> _build_form_data_filtering(),
            'form_uri' => ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.ADMR_CONTROLLER,
            'groupid'  => $group_id,
            'group'    => $this -> CI -> group_model -> get_by_id($group_id),
            'writers'  => $this -> CI -> writer_model -> get(array(), 'ch_asc'),
        );

        $this -> CI -> render_page('assign_writers_to_group', $data);            
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        $groupid  = empty($this -> _params['groupid']) ? NULL : explode('-', $this -> _params['groupid']); 
        
        $records = $this -> CI -> group_model -> get(array('id' => $groupid), $this -> _params['sort']); // Récupération des enregistrements

        return $records;       
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _filter_records($records)
    {
        return $records;       
    }
    
	// --------------------------------------------------------------------

	/**
	 * Met à jour des données des enregistrements postés
     * 
     * @access public
	 * @return string code html
	 */	
    protected function _update_records()
    {
        return parent :: _update_records();
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_select_actions_for_update_records()
    {
        return array(
            array('label' => ucfirst($this -> _lang['activate_writers_in_groups_selected']), 'value' => 'a'),
            array('label' => ucfirst($this -> _lang['inactivate_writers_in_groups_selected']), 'value' => 'i'),
            array('label' => ucfirst($this -> _lang['reset_groups_selected']), 'value' => 'r', 'attrs' => array('title' => ucfirst($this -> _lang['action_delete_writers_without_removing_them_definitively']))),
            array('label' => ucfirst($this -> _lang['delete_groups_selected_with_writers']), 'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_groups_and_writers_definitively']))),
        );
    }
    
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected
     * @param array Identifiants des enregistrements à mettre à jour
     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return void
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
        // (Dés)Activation des enregistrements
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression des enregistrements
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }
        // Retirer les rédacteurs du groupe (remise à zéro)
        elseif ($action == 'r') {
            return $this -> _reset_group_for_records($records_ids);
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return void
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        return $this -> CI -> writer_model -> update_status_by_groupid($records_ids, $action);
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return void
	 */
    protected function _delete_records($records_ids)
    {
        $this -> _delete_writers_by_groupids($records_ids);         // Suppression des rédacteurs appartenant aux groupes
        $this -> CI -> group_model -> delete_by_id($records_ids);   // Suppression des groupes

        return TRUE;        
    }

	/**
	 * supprime les rédacteurs appartenant aux groupes sélectionnés par leur identifiant
     * 
     * @access public
     * @param array Tableau contenant les identifiants des groupes
	 * @return void
	 */
    protected function _delete_writers_by_groupids($groups_ids)
    {
        $this -> CI -> load_helper('manage_writers_helper', $this -> _writer_rights);
        
        $writers_ids = array_keys($this -> CI -> writer_model -> get_many_by_groupid($groups_ids));        
       
        $this -> CI -> manage_writers_helper -> delete($writers_ids);

        return TRUE;        
    }
    
	// --------------------------------------------------------------------

	/**
	 * retire les rédacteurs sélectionnés de leur groupe
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return void
	 */
    protected function _reset_group_for_records($records_ids)
    {
        return $this -> CI -> writer_model -> reset_group_by_groupid($records_ids);            
    }
    
	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
	 * @access protected
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();    
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string Formulaire html
	 */	
    protected function _build_form_data_filtering()
    {
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => Url_helper :: build_uri().'/search',
            'groups' => $this -> CI -> group_model -> get(array(), 'ch_asc'),
            'groupid' => !empty($this -> _params['groupid']) ? explode('-', $this -> _params['groupid']) : array(),
            'sort' => $this -> _params['sort'],
        );
        
        return $this -> CI -> render('fragments/form_groups_filtering', $data, TRUE);               
    }

	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }
  
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            'id' => parent :: _set_data_table_header_for_id(),
			'desc' => parent :: _set_data_table_header_for_description($this -> _lang['group_name']),
            'commands' => parent :: _set_data_table_header_for_commands(),
		);

        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            'id' => parent :: _set_data_table_cell_for_id($record),
            'desc' => parent :: _set_data_table_cell_for_description($record),
            'commands' => parent :: _set_data_table_cell_for_commands($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_id($record)
	{        
		return parent :: _add_contents_for_td_id($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
		$view = Html_helper :: addA(
				$href = $this -> _build_href_for_td_description($record),
				$contents = Html_helper :: addImg(
					$path = ADMR_IMG_EDIT,
					$alt = ucfirst($this -> _lang['edit_group_config']).'&nbsp;&quot;'.$record['name'].'&quot;',
					$attr = array('title' => $alt, 'border' => '0')
				)
				.'&nbsp;'.$this -> _get_text_for_td_description($record),
				$attr = array('title' => $alt)
		);	

		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;

        return $base_href.'&ctrl=add_group&id='.$record['id'].'&name='.$record['name'];       
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le texte de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_text_for_td_description($record)
    {
        return $record['name'];        
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
/*	protected function _add_contents_for_td_status($record)
	{
		return parent :: _add_contents_for_td_status($record);
	}
*/
	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{
        $id = $record['id'];
        $name = $record['name'];
        $nb_writers = $this -> CI -> writer_model -> count_by_groupid($id);
        $view = '';
        
        // Lister les rédacteurs du groupe rédacteur
        if (!empty($nb_writers)) {
    		$view .= Html_helper :: addA(
    			$href = CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=manage_writers&amp;sort='.$this -> _config['sort_option_by_default'].'&amp;groupid='.$id,
    			$contents = Html_helper :: addImg(
    				$path = ADMR_IMG_GROUP,
    				$alt = ucfirst($this -> _lang['display_all_writers_in_group']).'&nbsp;&quot;'.$name.'&quot;',
    				$attr = array(
    					'title' => $alt,
    					'border' => '0'
    				)
    			)
                .'&nbsp;&nbsp;('.$nb_writers.')',
    			$attr = array()
    		);	
        } else {
    		$view .= Html_helper :: addImg(
				$path = ADMR_IMG_GROUP_EMPTY,
				$alt = ucfirst($this -> _lang['no_writer_in_group']).'&nbsp;&quot;'.$name.'&quot;',
				$attr = array(
					'title' => $alt,
					'border' => '0'
				)
            )
            .'&nbsp;&nbsp;('.$nb_writers.')';
        }
        //
        
        // Affectation de rédacteurs dans un groupe             
		$view .=  '&nbsp;&nbsp;&nbsp;';
        
		$view .= Html_helper :: addA(
			$href = CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=manage_groups/assign_writers_to_group&amp;groupid='.$id,
			$contents = Html_helper :: addImg(
				$path = ADMR_IMG_ADD_WRITERS,
				$alt = ucfirst($this -> _lang['assign_writers_to_group']).'&nbsp;&quot;'.$name.'&quot;',
				$attr = array(
					'title' => $alt,
					'border' => '0'
				)
			),
			$attr = array()
		);
        //
        
        return $view;
	}

	// ---------------------------------------------------------------------------- //
    
} // End of Class