<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.10 (2016/10/21)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

class Manage_writers_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
    protected $_params = array();       // Données récupérés par post ou get
    protected $_sort_options = array();	// Options de tri
    //
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        parent :: __construct();

        $this -> CI -> load_library('writers_managed', $this -> _writer_rights['id']);
        
        $this -> CI -> load_model('writer_model');
        $this -> CI -> load_model('group_model');
      
        if (! ADMR_IS_ADMIN && empty($this -> _writer_rights['writers_manage'])) {
            Url_helper :: redirect('display_error&type=disallowed');
        }        
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les droits du rédacteur
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return parent :: _set_sort_options();	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = array_merge(
            parent :: _set_params(),
            array(
                'groupid'  => trim(Var_helper :: import('groupid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'writerid' => trim(Var_helper :: import('writerid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'doctype'  => trim(Var_helper :: import('doctype', '', NULL, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))), '-'),
            )
        );
       
        return $this -> _params;
    }

	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $filter = Var_helper :: import('filter', 'post', 0);
        $writerids = Var_helper :: import('writerids', 'post', array());
        $groupids = Var_helper :: import('groupids', 'post', array());
        $uri = 'manage_writers';

		/**
		 * Sélection des rédacteurs par leurs identifiants
		 */    
        if ($filter == '1' && !empty($writerids)) {
            $uri .= is_array($writerids) ? '&writerid='.implode('-', $writerids) : '';         
        }

		/**
		 * Sélection des rédacteurs par les identifiants de leur groupe
		 */
        if ($filter == '2' && !empty($groupids)) {
            $uri .= is_array($groupids) ? '&groupid='.implode('-', $groupids) : '';         
        }
        		
		Url_helper :: redirect($uri);
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_writers']);
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent = parent :: set_header_addons();

        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/toggle_records_selection_display_for_management.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/manage_writers.js"></script>'."\n";
        
        $css = '';
                
        return $parent.$css.$js;
    }
   
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_writers'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_writers_helper');
        
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            return $this -> CI -> plugin_menu_for_writers_helper -> set_public_items('writers', $this -> _lang, $this -> _config, $this -> _writer_rights);         
        }  
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les rédacteurs sélectionnés par leur identifiants
     * 
     * @access public
     * @param array Tableau contenant les identifiants des rédacteurs
	 * @return void
	 */
    public function delete($writers_ids = array())
    {        
        settype($writers_ids, 'array');
        
        return $this -> _delete_records($writers_ids);
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        $writerid = empty($this -> _params['writerid']) ? NULL : explode('-', $this -> _params['writerid']);
        $groupid  = (empty($this -> _params['groupid']) && $this -> _params['groupid'] !== '0') ? NULL : explode('-', $this -> _params['groupid']); 

        $records = $this -> CI -> writers_managed -> get_writers_managed(array('id' => $writerid, 'groupid' => $groupid), $this -> _params['sort']); // Récupération et tri des enregistrements autorisés

        return $records;       
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _filter_records($records)
    {
        return $records;       
    }
    
	// --------------------------------------------------------------------

	/**
	 * Met à jour des données des enregistrements postés
     * 
     * @access public
	 * @return string code html
	 */	
    protected function _update_records()
    {
        return parent :: _update_records();
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_select_actions_for_update_records()
    {
        $actions = array();

        // (Dés)activation
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_act'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['activate_writers_selected']),   'value' => 'a');
            $actions[] = array('label' => ucfirst($this -> _lang['inactivate_writers_selected']), 'value' => 'i');
        }
        
        // Suppression
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_del'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['delete_writers_selected']), 'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_writers_definitively'])));
        }

        // Remise à zéro des groupes
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_reset_group'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['reset_group_for_writers_selected']), 'value' => 'r');
        }

        return $actions;
    }

	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected
     * @param array Identifiants des enregistrements à mettre à jour
     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return void
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
        // (Dés)Activation des enregistrements
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression des enregistrements
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }        
        // Retirer les rédacteurs du groupe
        elseif ($action == 'r') {
            return $this -> _reset_group_for_records($records_ids);
        }
        //           
        
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return void
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_act'])) {
            return $this -> CI -> writer_model -> update_status_by_id($records_ids, $action);           
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access protected
     * @param array Tableau contenant les identifiants des rédacteurs
	 * @return void
	 */
    protected function _delete_records($records_ids)
    {
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_del'])) {
            $this -> _delete_addons_writers_docs($records_ids);         // Suppression des documents des addons pour les rédacteurs
            $this -> _delete_writers_messages($records_ids);            // Suppression des messages des rédacteurs
            $this -> CI -> writer_model -> delete_by_id($records_ids);  // Suppression des rédacteurs
            
            return TRUE;
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les messages pour les rédacteurs sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des rédacteurs
	 * @return void
	 */
    protected function _delete_writers_messages($writers_ids)
    {
        if ($this -> CI -> load_addon_model('messages', 'writer_messages_model') && $this -> CI -> load_addon_model('messages', 'messages_model')) {
            foreach($writers_ids as $writer_id) {
                $this -> CI -> writer_messages_model -> load_data($writer_id);
                
                $writer_messages = $this -> CI -> writer_messages_model -> get(array('author_id' => $writer_id));
                
                foreach($writer_messages as $msg) {
                    $this -> CI -> writer_messages_model -> load_data($msg['recipient_id']); // On charge les données du destinataire
                    $this -> CI -> writer_messages_model -> delete_by_id($msg['id']);   // Suppression de l'enregistrement du document dans les données du destinataire
                    
                    $this -> CI -> messages_model -> delete_by_id($msg['id']);   // Suppression des fichiers de type msg_content_XX
                }
                
                $this -> CI -> writer_messages_model -> destroy_writer_DB_file($writer_id); // Détruit le fichier de la base de donnée du rédacteur                    
            }
            
            return TRUE;
        }
        
        return FALSE;        
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les documents des addons pour les rédacteurs sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des rédacteurs
	 * @return void
	 */
    protected function _delete_addons_writers_docs($writer_ids)
    {
        $this -> CI -> load_helper('addons_helper');
        
        $addons = $this -> CI -> addons_helper -> get_addons();
        
        foreach($addons as $addon) {
            $this -> CI -> load_addon_model($addon, 'writer_'.$addon.'_model');

            if (is_object($this -> CI -> {'writer_'.$addon.'_model'}) && method_exists($this -> CI -> {'writer_'.$addon.'_model'}, 'delete_writer_docs')) {
                $this -> CI -> {'writer_'.$addon.'_model'} -> delete_writer_docs($writer_ids);     
            }   
        }
        
        return TRUE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * retire les enregistrements sélectionnés de leur groupe
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return void
	 */
    protected function _reset_group_for_records($records_ids)
    {
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_reset_group'])) {
            return $this -> CI -> writer_model -> reset_group_by_id($records_ids);
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
	 * @access protected
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();    
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string Formulaire html
	 */	
    protected function _build_form_data_filtering()
    {
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => Url_helper :: build_uri().'/search',
            'writers' => $this -> CI -> writers_managed -> get_writers_managed(array(), 'ch_asc'),
            'groups' => $this -> CI -> writers_managed -> get_groups_managed('ch_asc'),
            'writerid' => !empty($this -> _params['writerid']) ? explode('-', $this -> _params['writerid']) : array(),
            'groupid' => (!empty($this -> _params['groupid']) || $this -> _params['groupid'] === '0') ? explode('-', $this -> _params['groupid']) : array(),
            'sort' => $this -> _params['sort'],
            'lang_for_js' => htmlspecialchars(json_encode(array(
                'all' => $this -> _lang['all'],
                'writers' => $this -> _lang['writers'],
                'groups' => $this -> _lang['groups'],
                'group' => $this -> _lang['group'],
            ))),
        );

        return $this -> CI -> render('fragments/form_writers_filtering', $data, TRUE);               
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le contenu de l'attribut action du formulaire
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_form_action_content()
    {
        $href = parent :: _build_form_action_content();
        
        if ($this -> _params['groupid'] === '0') { // Correction d'un problème lorsqu'on sélectionne les rédacteurs non affectés à un groupe
            $href .= '&groupid=0';    
        }
        
        return $href;
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le lien des onglets de la barre de navigation
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_navbar_href()
    {
        $href = parent :: _build_navbar_href();
        
        if ($this -> _params['groupid'] === '0') { // Correction d'un problème lorsqu'on sélectionne les rédacteurs non affectés à un groupe
            $href .= '&groupid=0';    
        }
        
        return $href;
    }

	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }

    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            'id' => parent :: _set_data_table_header_for_id(),
			'desc' => parent :: _set_data_table_header_for_description($this -> _lang['writer_name']),
            'status' => parent :: _set_data_table_header_for_status(),
            'commands' => parent :: _set_data_table_header_for_commands(),
		);

        if (!ADMR_IS_ADMIN && empty($this -> _writer_rights['writers_docs_manage']) && empty($this -> _writer_rights['writers_edit_group'])) {
            unset($headers['commands']);  // Suppression de la colonne "Commandes"
        }        
        
        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            'id' => parent :: _set_data_table_cell_for_id($record),
            'desc' => parent :: _set_data_table_cell_for_description($record),
            'status' => parent :: _set_data_table_cell_for_status($record),
            'commands' => parent :: _set_data_table_cell_for_commands($record),
    	);

        if (!ADMR_IS_ADMIN && empty($this -> _writer_rights['writers_docs_manage']) && empty($this -> _writer_rights['writers_edit_group'])) {
            unset($cells['commands']);  // Suppression de la colonne "Commandes"
        }
        
        return $cells;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_id($record)
	{        
		return parent :: _add_contents_for_td_id($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_edit'])) {
     		$view = Html_helper :: addA(
    				$href = $this -> _build_href_for_td_description($record),
    				$contents = Html_helper :: addImg(
    					$path = ADMR_IMG_EDIT,
    					$alt = ucfirst($this -> _lang['edit_writer_config']).'&nbsp;&quot;'.$record['name'].'&quot;',
    					$attr = array('title' => $alt, 'border' => '0')
    				)
    				.'&nbsp;'.$this -> _get_text_for_td_description($record),
    				$attr = array('title' => $alt)
    		);	
        } else {
            $view = $this -> _get_text_for_td_description($record);
        }

		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;

        return $base_href.'&ctrl=add_writer&id='.$record['id'].'&name='.$record['name'];       
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le texte de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_text_for_td_description($record)
    {
        return $record['name'];        
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_status($record)
	{
		return parent :: _add_contents_for_td_status($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{
        $view = '';
        
		// Accès à la gestion des documents de guppy créés par le rédacteur
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_docs_manage'])) {
            $view .= $this -> _add_access_for_manage_writer_docs($record);
        }

		// Accès à l'édition du groupe du rédacteur
        if (ADMR_IS_ADMIN || !empty($this -> _writer_rights['writers_edit_group'])) {
            $view .= $this -> _add_access_for_edit_group($record);
        }
		
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute l'accès à la gestion des documents du rédacteur dans la cellule intitulée "Commandes"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _add_access_for_manage_writer_docs($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;
        
        $view = Html_helper :: addA(
			$href = $base_href.'&ctrl=manage_writers_docs/synchronize&amp;writerid='.$record['id'],
			$contents = Html_helper :: addImg(
				$path = ADMR_IMG_FILES,
				$alt = ucfirst($this -> _lang['manage_docs_created_by_writer']).'&nbsp;&quot;'.$record['name'].'&quot;',
				$attr = array(
					'title' => $alt,
					'border' => '0'
				)
			),
			$attr = array()
		);	

        return $view;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute l'accès à la gestion des documents du rédacteur dans la cellule intitulée "Commandes"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _add_access_for_edit_group($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;        
        $groups = $this -> CI -> group_model -> get_by_id($record['groupid']);
        $view = ''; 
        
        if (!empty($record['groupid']) && !empty($groups)) {        
            $view .= '&nbsp;&nbsp;';
    		$view .= Html_helper :: addA(
    			$href = $base_href.'&ctrl=add_group&id='.$record['groupid'],
    			$contents = Html_helper :: addImg(
    				$path = ADMR_IMG_GROUP,
    				$alt = ucfirst($this -> _lang['edit_writer_group']).'&nbsp;&quot;'.$record['name'].'&quot;',
    				$attr = array(
    					'title' => $alt,
    					'border' => '0'
    				)
    			),
    			$attr = array()
    		);	
        }

        return $view;
    }

	// ---------------------------------------------------------------------------- //
    
} // End of Class