<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

/**
 * Classe qui permet de récupérer les photoramas enregistrés dans guppy
 */
class Photoramas_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();     // Données de langue
    protected $_config = array();   // Données de configuration
    protected $_doc_infos = array('type' => '', 'name' => ''); // Infos concernant le document (type, name)
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct()
    {
        $this -> CI =& Controller :: get_instance();
        
        $this -> _doc_infos = Model :: get_doc_infos_by_type(TYP_PHOTO);

        $this -> CI -> load_model('guppy_docid_model');
        $this -> CI -> load_model($this -> _doc_infos['name'].'_model');
        $this -> CI -> load_model($this -> _doc_infos['name'].'_index_model');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    /**
	 * retourne tous les photoramas (indexés et non indexés)
     * 
	 * @access public
     * @return void
	 */	
    public function get_all()
    {
        $photoramas = array()
                  + $this -> _get_photoramas_indexed()
                  + $this -> _get_photoramas_not_indexed();
        
        ksort($photoramas);
        
        return $photoramas;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne seulement les photoramas indexés
     * 
	 * @access public
     * @return void
	 */	
    public function get_only_indexed()
    {
        return $this -> _get_photoramas_indexed();
    }

	// --------------------------------------------------------------------

    /**
	 * retourne seulement les photoramas non indexés
     * 
	 * @access public
     * @return void
	 */	
    public function get_only_not_indexed()
    {
        return $this -> _get_photoramas_not_indexed();
    }

	// --------------------------------------------------------------------

    /**
	 * retourne tous les photoramas indexés dans guppy (photoramas activés)
     * 
	 * @access public
     * @return void
	 */	
    protected function _get_photoramas_indexed()
    {
        global $lng, $lang;
        
        $photoramas = array();
        $doc_infos = $this -> _doc_infos;
        
        $data_docs_indexed = $this -> CI -> {$doc_infos['name'].'_index_model'} -> read(); // Tous les documents enregistrées dans le fichier index de guppy                     

        foreach($data_docs_indexed as $data) {
            
            $data['cat'] = ($lng == $lang[1]) ? $data['cat2'] : $data['cat1'];
            $data['title'] = ($lng == $lang[1]) ? $data['title2'] : $data['title1'];  
            
            $photoramas[$data['id']] = array(
                'id' => $data['id'],
                'cat' => $data['cat'],
                'title' => $data['title']
            );
        } 
          
        return $photoramas;
    }

	// --------------------------------------------------------------------

    /**
	 * retourne tous les photoramas non indexés dans guppy (photoramas inactivés)
     * 
	 * @access public
     * @return void
	 */	
    protected function _get_photoramas_not_indexed()
    {
        global $lng, $lang;

        $photoramas = array();
        $doc_infos = $this -> _doc_infos;
        
        $docs_inactivated = $this -> CI -> guppy_docid_model -> get(array('type' => $doc_infos['type'], 'status' => 'i')); // Tous les documents inactifs enregistrés dans guppy                     
        
        foreach($docs_inactivated as $doc) {
            $data = $this -> CI -> {$doc_infos['name'].'_model'} -> read($doc['id']); // Données du document de guppy                     

            $data['cat'] = ($lng == $lang[1]) ? $data['cat2'] : $data['cat1'];
            $data['title'] = ($lng == $lang[1]) ? $data['title2'] : $data['title1'];  
            
            $photoramas[$data['id']] = array(
                'id' => $data['id'],
                'cat' => $data['cat'],
                'title' => $data['title']
            );
        } 
            
        return $photoramas;
    }

	// --------------------------------------------------------------------
    
} // End of class