<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/plugin_menu_helper.php';

class Plugin_menu_for_photos_helper extends Plugin_menu_helper
{
    /**
	 * Définit et retourne les items du menu qui est affiché dans le bandeau en haut de la page coté public
     * 
	 * @access public
	 * @param string Nom du document
	 * @param array Tableau contenant les traduction de langue
	 * @param array Tableau contenant les options de configuration
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param array Paramètres optionnels
	 * @return array
	 */
	public static function set_public_items($doc_name, $lang, $config, $writer_rights = array(), $params = array())
	{
            return array(
                parent :: add_item_for_go_dashboard($doc_name, $lang), // retour au tableau de bord
                parent :: add_item( // Icone pour la gestion des photos
                    array(
                        'is_allowed' => $writer_rights[$doc_name.'_manage'],
                        'title' => $lang['manage_'.$doc_name],
                        'class' => 'manage_docs '.$doc_name,
                        'controller' => 'manage_'.$doc_name,
                        'query' => '&galid='.$params['photorama_id'],
                    )
                ),
                parent :: add_item( // Icone pour l'ajout des photos
                    array(
                        'is_allowed' => $writer_rights[$doc_name.'_add'],
                        'title' => $lang['add_'.$doc_name],
                        'class' => 'add_doc '.$doc_name,
                        'controller' => 'add_'.$doc_name,
                        'pattern_to_search_in_uri' => array('method' => 'no_strict'),
                        'query' => '&galid='.$params['photorama_id'],
                    )
                ),
                parent :: add_item_for_disconnect($doc_name, $lang) // Déconnexion
            );           
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne les items du menu qui est affiché dans le bandeau en haut de la page coté admin
     * 
	 * @access public
	 * @param string Nom du document
	 * @param array Tableau contenant les traduction de langue
	 * @param array Tableau contenant les options de configuration
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param array Paramètres optionnels
	 * @return array
	 */
	public static function set_admin_items($doc_name, $lang, $config, $writer_rights = array(), $params = array())
    {
        return parent :: set_admin_items($doc_name, $lang, $config, $writer_rights, $params);
    }

	// --------------------------------------------------------------------

} // End of class