<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Plugin_menu_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
/*    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
*/
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
/*    function __construct()
    {
        $this -> CI =& Controller :: get_instance();

        /**
         * Déclaration des variables
         */
/*        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        //    
    }
*/
	// --------------------------------------------------------------------

    /**
	 * Définit et retourne les items du menu qui est affiché dans le bandeau en haut de la page coté public
     * 
	 * @access public
	 * @param string Nom du document
	 * @param array Tableau contenant les traduction de langue
	 * @param array Tableau contenant les options de configuration
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param array Paramètres optionnels
	 * @return array
	 */
	public static function set_public_items($doc_name, $lang, $config, $writer_rights = array(), $params = array())
	{
        return array(
            self :: add_item_for_go_dashboard($doc_name, $lang),
            self :: add_item_for_manage_docs($doc_name, $lang, $writer_rights),
            self :: add_item_for_add_doc($doc_name, $lang, $writer_rights),
            self :: add_item_for_search_docs($doc_name, $lang),
            self :: add_item_for_disconnect($doc_name, $lang)
        );
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne les items du menu qui est affiché dans le bandeau en haut de la page coté admin
     * 
	 * @access public
	 * @param string Nom du document
	 * @param array Tableau contenant les traduction de langue
	 * @param array Tableau contenant les options de configuration
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param array Paramètres optionnels
	 * @return array
	 */
	public static function set_admin_items($doc_name, $lang, $config, $writer_rights = array(), $params = array())
    {
        return array();
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter un item de menu
     * 
     * @param array Tableau contenant les paramètres de l'item
     * @return array Item du menu 
     */
    public static function add_item($params = array())
    {
        $item = '';
        $params_by_default = array(
            'is_allowed' => FALSE, // Autorisation d'accès à l'item
            'title' => '', // Titre de l'item
            'class' => '', // Class de l'item
            'controller' => '', // Nom du controller de l'item
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);
            
        if (!empty($params['is_allowed'])) {            
            
            $params['string_to_search_in_uri'] = !empty($params['pattern_to_search_in_uri']['string']) ? $params['pattern_to_search_in_uri']['string'] : $params['controller'];
            $params['method_to_search_in_uri'] = !empty($params['pattern_to_search_in_uri']['method']) ? $params['pattern_to_search_in_uri']['method'] : 'strict';
            $params['query'] = !empty($params['query']) ? '&'.$params['query'] : '';
            
            $item = array(
                'class' => $params['class'],
                'label' => ucfirst($params['title']),
                'href'  => ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.$params['addon_dir_path'].$params['controller'].$params['query'],
                'selected' => (ADMR_CONTROLLER === $params['string_to_search_in_uri'] || 
                              ($params['method_to_search_in_uri'] != 'strict' && strpos(ADMR_CONTROLLER, $params['string_to_search_in_uri']) !== FALSE)) ? TRUE : FALSE
            );
        }
        
        return $item;
    }    

	// --------------------------------------------------------------------
	
    /**
	 * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page coté public
     * 
	 * @access public
	 * @param array Tableau contenant les traduction de langue
	 * @param string Nom du document
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param string Chemin du répertoire (addon)
	 * @return array
	 */
	public static function set_public_menu_items($lang, $doc_name = '', $writer_rights = array(), $addon_dir_path = '')
	{
		$href = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=';

        $items = array();
        
        /**
         * items du menu qui permet de revenir au tableau de bord
         */
        $items['0-go_dashboard'] = self :: add_item_for_go_dashboard($doc_name, $lang); 
        //
        
        if (!empty($doc_name) && !empty($writer_rights[$doc_name.'_manage'])) {
            /**
             * item du menu qui permet de gérer les documents
             */
            $items['10-manage_docs'] = array(
                'class' => 'manage_docs '.$doc_name,
                'label' => ucfirst($lang['manage_'.$doc_name]),
                'href'  => $href.$addon_dir_path.'manage_'.$doc_name,
                'selected' => (ADMR_CONTROLLER === 'manage_'.$doc_name) ? TRUE : FALSE
            );
            // 
    
            /**
             * item du menu qui permet d'ajouter un document
             */
            if (!empty($writer_rights[$doc_name.'_add'])) {            
                $items['20-add_doc'] = array(
                    'class' => 'add_doc '.$doc_name,
                    'label' => ucfirst($lang['add_'.$doc_name]),
                    'href'  => $href.$addon_dir_path.'add_'.$doc_name,
                    'selected' => (ADMR_CONTROLLER === 'add_'.$doc_name) ? TRUE : FALSE
                ); 
            }
            //

            /**
             * item du menu qui permet d'afficher la page de gestion des documents des rédacteurs gérés par le "super" rédacteur
             */
            if ($doc_name == 'writers' && !empty($writer_rights['writers_docs_manage'])) {            
                $items['21-manage_writers_docs'] = array(
                   // 'class' => 'manage_writers_docs '.$doc_name,
                    'class' => 'manage_docs writers_docs writers',
                    'label' => ucfirst($lang['manage_writers_docs']),
                    'href'  => $href.$addon_dir_path.'manage_writers_docs',
                    'selected' => (ADMR_CONTROLLER === 'manage_writers_docs') ? TRUE : FALSE
                );
                
                $items['22-manage_addons_writers_docs'] = array(
                  //  'class' => 'manage_addons_writers_docs '.$doc_name,
                    'class' => 'manage_docs addons_writers_docs writers',
                    'label' => ucfirst($lang['manage_addons_writers_docs']),
                    'href'  => $href.$addon_dir_path.'manage_addons_writers_docs',
                    'selected' => (strpos(ADMR_CONTROLLER, 'manage_addons_writers_') !== false) ? TRUE : FALSE
                );
            }
            //

            /**
             * items du menu qui permet de faire une recherche
             */
            if ($doc_name != 'writers') {                
           //     $items['30-search_docs'] = self :: add_item_for_search_docs($doc_name, $lang, $params = array('addon_dir_path' => $addon_dir_path));
                
                $items['30-search_docs'] = array(
                    'class' => 'search_docs '.$doc_name,
                    'label' => ucfirst($lang['search_'.$doc_name]),
                    'href'  => $href.$addon_dir_path.'search_'.$doc_name,
                    'selected' => (ADMR_CONTROLLER === 'search_'.$doc_name) ? TRUE : FALSE
                );
            }
            //
            
            /**
             * item du menu qui permet de se déconnecter
             */
            $items['40-disconnect'] = self :: add_item_for_disconnect($doc_name, $lang);
            //

        }

        ksort($items); // Tri selon les clés
        
        return $items;    
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet d'accéder au tableau de bord
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @param string Chemin du répertoire (addon)
     * @return array Item du menu 
     */

    public static function add_item_for_go_dashboard($doc_name, $lang)
    {
        return self :: add_item( // Icone pour la gestion des photos
            array(
                'is_allowed' => TRUE,
                'title' => $lang['go_to_dashboard'],
                'class' => 'go_dashboard '.$doc_name,
                'controller' => 'dashboard'
            )
        );
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de se déconnecter
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @param string Chemin du répertoire (addon)
     * @return array Item du menu 
     */

    public static function add_item_for_disconnect($doc_name, $lang)
    {
        return self :: add_item( // Icone pour la gestion des photos
            array(
                'is_allowed' => TRUE,
                'title' => $lang['disconnect'],
                'class' => 'disconnect '.$doc_name,
                'controller' => 'connect/logout',
            )
        );
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de rechercher les documents
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @return array Item du menu 
     */
    public static function add_item_for_search_docs($doc_name, $lang, $params = array())
    {
        settype($params, 'array');
       
        $params_by_default = array(
            'is_allowed' => TRUE,
            'title' => $lang['search_'.$doc_name],
            'class' => 'search_docs '.$doc_name,
            'controller' => 'search_'.$doc_name,
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);

        return self :: add_item($params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de rechercher les documents pour un addon
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @return array Item du menu 
     */
    public static function add_item_for_addon_search_docs($doc_name, $lang, $params = array())
    {
        settype($params, 'array');

        $params = array_replace_recursive(
            array(
                'pattern_to_search_in_uri' => array('method' => 'no_strict'),
                'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
            ),
            $params       
        );
        
        return self :: add_item_for_search_docs($doc_name, $lang, $params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de gérer les documents
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_manage_docs($doc_name, $lang, $writer_rights, $params = array())
    {
        settype($params, 'array');
        
        $params_by_default = array(
            'is_allowed' => $writer_rights[$doc_name.'_manage'],
            'title' => $lang['manage_'.$doc_name],
            'class' => 'manage_docs '.$doc_name,
            'controller' => 'manage_'.$doc_name,
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);
       
        return self :: add_item($params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de gérer les documents de l'addon
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_addon_manage_docs($doc_name, $lang, $writer_rights = array(), $params = array())
    {
        settype($params, 'array');

        $params = array_replace_recursive(
            array(
                'pattern_to_search_in_uri' => array('method' => 'no_strict'),
                'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
            ),
            $params       
        );
        
        return self :: add_item_for_manage_docs($doc_name, $lang, $writer_rights, $params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet d'ajouter un document
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_add_doc($doc_name, $lang, $writer_rights, $params = array())
    {
        settype($params, 'array');
        
        $params_by_default = array(
            'is_allowed' => $writer_rights[$doc_name.'_add'],
            'title' => $lang['add_'.$doc_name],
            'class' => 'add_doc '.$doc_name,
            'controller' => 'add_'.$doc_name,
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);
       
        return self :: add_item($params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet d'ajouter un document pour un addon
     * 
     * @params string Nom du document de l'addon
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_addon_add_doc($doc_name, $lang, $writer_rights = array(), $params = array())
    {
        settype($params, 'array');

        $params = array_replace_recursive(
            array(
                'pattern_to_search_in_uri' => array('method' => 'no_strict'),
                'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
            ),
            $params       
        );
        
        return self :: add_item_for_add_doc($doc_name, $lang, $writer_rights, $params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de gérer les documents supprimés
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_manage_docs_deleted($doc_name, $lang, $writer_rights, $params = array())
    {
        settype($params, 'array');
        
        $params_by_default = array(
            'is_allowed' => ADMR_IS_ADMIN ? TRUE : FALSE, // Autorisation d'accès à l'item
            'title' => $lang['manage_'.$doc_name.'_deleted'],
            'class' => 'trash_docs '.$doc_name,
            'controller' => 'manage_'.$doc_name.'_deleted',
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);
       
        return self :: add_item($params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de gérer les documents supprimés de l'addon
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_addon_manage_docs_deleted($doc_name, $lang, $writer_rights = array(), $params = array())
    {
        settype($params, 'array');

        $params = array_replace_recursive(
            array(
                'pattern_to_search_in_uri' => array('method' => 'no_strict'),
                'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
            ),
            $params       
        );
        
        return self :: add_item_for_manage_docs_deleted($doc_name, $lang, $writer_rights, $params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de controler l'intégrité des données des documents
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_check_docs_integrity($doc_name, $lang, $writer_rights, $params = array())
    {
        settype($params, 'array');
        
        $params_by_default = array(
            'is_allowed' => ADMR_IS_ADMIN ? TRUE : FALSE, // Autorisation d'accès à l'item
            'title' => $lang['check_data_integrity'],
            'class' => 'check_data_integrity '.$doc_name,
            'controller' => 'check_'.$doc_name.'_data_integrity',
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);
       
        return self :: add_item($params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de controler l'intégrité des données des documents pour un addon
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_addon_check_docs_integrity($doc_name, $lang, $writer_rights = array(), $params = array())
    {
        settype($params, 'array');

        $params = array_replace_recursive(
            array(
            'pattern_to_search_in_uri' => array('method' => 'no_strict'),
            'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
            ),
            $params       
        );
        
        return self :: add_item_for_check_docs_integrity($doc_name, $lang, $writer_rights, $params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de configurer un document
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_config_doc($doc_name, $lang, $writer_rights, $params = array())
    {
        settype($params, 'array');
        
        $params_by_default = array(
            'is_allowed' => $writer_rights[$doc_name.'_config'],
            'title' => $lang['config_'.$doc_name],
            'class' => 'config_doc '.$doc_name,
            'controller' => 'config_'.$doc_name,
            'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => ''),
            'query' => '', // paramètres passés dans l'uri autre que le controller
            'addon_dir_path' => '', // Chemin du répertoire de l'addon
         );
        
        $params = array_replace_recursive($params_by_default, $params);
       
        return self :: add_item($params);
    }

	// --------------------------------------------------------------------

    /**
     * Permet d'ajouter l'item de menu qui permet de configurer un document pour un addon
     * 
     * @params string Nom du document
     * @param array Tableau contenant les items de langues
     * @param array Tableau contenant les droits du rédacteur
     * @return array Item du menu 
     */
    public static function add_item_for_addon_config_doc($doc_name, $lang, $writer_rights = array(), $params = array())
    {
        settype($params, 'array');

        $params = array_replace_recursive(
            array(
            'pattern_to_search_in_uri' => array('method' => 'no_strict'),
            'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
            ),
            $params       
        );
        
        return self :: add_item_for_config_doc($doc_name, $lang, $writer_rights, $params);
    }

	// --------------------------------------------------------------------

	/**
	 * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
	 * @access public
	 * @param string Nom du document
	 * @return array
	 */
	public static function set_admin_menu_items($lang, $config)
    {
		include_once CHEMIN.'admin/plugins/funcplug.inc';

		$items = array(
            self :: add_item_for_go_dashboard($doc_name, $lang),            
            self :: add_item( // Gestion des rédacteurs
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['manage_writers'],
                    'class' => 'manage_writers admin',
                    'controller' => 'manage_writers',
                    'query' => 'sort='.$config['sort_option_by_default'],            
                )
            ),
            self :: add_item( // Gestion des groupes rédacteurs
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['manage_groups'],
                    'class' => 'manage_groups admin',
                    'controller' => 'manage_groups',
                    'query' => 'sort='.$config['sort_option_by_default'],            
                    'pattern_to_search_in_uri' => array('string' => 'manage_groups', 'method' => 'no_strict'),
                )
            ),
            self :: add_item( // Gestion des documents des rédacteurs
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['manage_writers_docs'],
                    'class' => 'manage_writers_docs admin',
                    'controller' => 'manage_writers_docs',
                )
            ),
            self :: add_item( // Gestion des documents des plugins
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['manage_addons_writers_docs'],
                    'class' => 'manage_addons_writers_docs admin',
                    'controller' => 'manage_addons_writers_docs',
                    'pattern_to_search_in_uri' => array('string' => 'manage_addons_writers_', 'method' => 'no_strict'),
                )
            ),
            self :: add_item( // Ajout des rédacteurs
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['add_writer'],
                    'class' => 'add_writer admin',
                    'controller' => 'add_writer',
                )
            ),
            self :: add_item( // Ajout des groupes rédacteurs
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['add_group'],
                    'class' => 'add_group admin',
                    'controller' => 'add_group',
                )
            ),
            self :: add_item( // Migration des données
                array(
                    'is_allowed' => is_dir(ADMR_PUBLIC_ROOT_PATH.'/data'),
                    'title' => $lang['migration_plugin_data'],
                    'class' => 'migrate_data admin',
                    'controller' => 'migrate_plugin_data',
                )
            ),
            self :: add_item( // Contrôle d'intégrité
                array(
                    'is_allowed' => TRUE,
                    'title' => $lang['check_data_integrity'],
                    'class' => 'check_data_integrity admin',
                    'controller' => 'check_data_integrity',
                )
            ),
            self :: add_item( // Gestion de l'affichage de l'icone du plugin dans la barre de menu
                array(
                    'is_allowed' => TRUE,
                    'title' => PluginRegistered(ADMR_DIRNAME) ? $lang['delete_icon_plugin'] : $lang['add_icon_plugin'],
                    'class' => 'icon_menu admin',
                    'controller' => 'toggle_menu_icon_display',
                    'query' => 'status='.(PluginRegistered(ADMR_DIRNAME) ? 0 : 1),            
                )
            ),
        );

        return $items;    
    }

	// --------------------------------------------------------------------

} // End of class