<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/search_records_helper.php';

abstract class Search_docs_helper extends Search_records_helper 
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_writer_rights = array(); // Droits du rédacteur    
    protected $_doc_infos = array('name' => '', 'type' => ''); // Tableau contenant les informations du document (nom, type)

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */

	/**
	 * constructeur
     * 
     * @access public
     * @param string Type du document de guppy (TYP_ART, TYP_NEWS, ...)
     * @param array Tableau contenant les droits du rédacteur
	 * @return void
	 */	
    public function __construct($doc_type, $writer_rights = array())
    {
        parent :: __construct(Model :: get_doc_infos_by_type($doc_type), $writer_rights);

        $this -> CI -> load_model($this -> _doc_infos['name'].'_model'); // Model du document
        $this -> CI -> load_model($this -> _doc_infos['name'].'_index_model'); // Model du fichier index du document

        if (ADMR_IS_ADMIN) {
            $this -> CI -> load_model('guppy_docid_model'); // Model du fichier docid de guppy
        } else {
            $this -> CI -> load_model('writer_docs_model', array('id' => !empty($this -> _writer_rights['id']) ? $this -> _writer_rights['id'] : NULL)); // Model des documents du rédacteur           
        }
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        return parent :: search();   
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {        
        $parent_addons = parent :: set_header_addons();
        
        $js = '';

        $css = '';

        return $parent_addons.$css.$js;        
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['search_'.$this -> _doc_infos['name']]); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
	 * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return '';
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        return parent :: set_menu_plugin_items();         
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        return $this -> _params = parent :: _set_params();
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_search_records_view()
    {
        return parent :: _get_layout_for_search_records_view();
    }
    
	// --------------------------------------------------------------------

	/**
	 * Fait une redirection selon le résultat du filtre appliqué
	 *
	 * @access	protected
     * @param integer Identifiant du filtre appliqué
     * @param string Uri de redirection
	 * @return void
	 */
    protected function _redirect_by_filter($filter, $uri)
    {
        return parent :: _redirect_by_filter($filter, $uri);
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => name)
	 */
    protected function _get_writer_docs()
    {
        $docs = $this -> _get_writer_docs_by_type($this -> _doc_infos['type']);

        return $docs;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur sélectionnés selon leur type
	 *
	 * @access protected
     * @param string Type du document
	 * @return array sous la forme array(id => name)
	 */
    protected function _get_writer_docs_by_type($type)
    {
        $docs = array();
        $doc_infos = Model :: get_doc_infos_by_type($type);

        $docs += $this -> _get_writer_docs_indexed($doc_infos); // Documents indexés dans fichier index/TYPE_DOC.dtb       
        $docs += $this -> _get_writer_docs_not_indexed($doc_infos); // Documents avec status i
        
        ksort($docs);
       
        $docs = $this -> _add_writer_docs_heading($docs, $doc_infos); // Ajoute l'entête du document

        return $docs;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur enregistrés dans le fichier index (document activés uniquement)
	 *
	 * @access	private
     * @param array Données des documents
     * @param string Type du document
	 * @return	array sous la forme array(id => array())
	 */
    private function _add_writer_docs_heading($docs, $doc_infos)
    {        
        foreach($docs as $id => $doc) {
            $docs[$id]['heading'] = $this -> CI -> {$doc_infos['name'].'_model'} -> set_doc_heading($doc);    
        }
        
        return $docs;
    }
    
	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur enregistrés dans le fichier index (document activés uniquement)
	 *
	 * @access	private
     * @param string Type du document
	 * @return	array sous la forme array(id => array())
	 */
    private function _get_writer_docs_indexed($doc_infos)
    {        
        $docs = array();
        $autorization = $this -> _writer_rights[$doc_infos['name'].'_manage'];
        
        if (! empty($autorization)) {
            $this -> CI -> load_model($doc_infos['name'].'_index_model'); // Model du fichier index du document

            $guppy_index_docs = $this -> CI -> {$doc_infos['name'].'_index_model'} -> read(); // Tous les documents enregistrées dans le fichier index de guppy           
            $writer_docs = $this -> CI -> writer_docs_model -> get_many_by_type($doc_infos['type']); // Tous les documents du rédacteur enregistrées dans guppy
        
            $docs = array_intersect_key($guppy_index_docs, $writer_docs);
        }

        return $docs;     
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur non enregistrés dans le fichier index (document inactivés uniquement)
	 *
	 * @access	private
     * @param string Type du document
	 * @return	array sous la forme array(id => array())
	 */
    private function _get_writer_docs_not_indexed($doc_infos)
    {        
        $docs = array();
        $autorization = $this -> _writer_rights[$doc_infos['name'].'_manage'];
        
        if (! empty($autorization)) {
            $this -> CI -> load_model($doc_infos['name'].'_model'); // Model du fichier index du document
            $writer_docs_inactivated = $this -> CI -> writer_docs_model -> get(array('status' => 'i', 'type' => $doc_infos['type'])); // Tous les documents inactifs enregistrés dans guppy
        
            foreach($writer_docs_inactivated as $id => $doc) {
                $docs[$id] = $this -> CI -> {$doc_infos['name'].'_model'} -> read($id);    
            }
        }

        return $docs;     
    }

	// --------------------------------------------------------------------

} // End of Class