<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/search_docs_helper.php';

class Search_menuitems_helper extends Search_docs_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri    

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */

	/**
	 * constructeur
     * 
     * @access public
     * @param string Type du document de guppy (TYP_ART, TYP_NEWS, ...)
     * @param array Tableau contenant les droits du rédacteur
	 * @return void
	 */	
    public function __construct($writer_rights)
    {
        parent :: __construct(TYP_OPTMENU, $writer_rights);
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function search()
    {
        return parent :: search();   
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        return $this -> _params = array_merge(parent :: _set_params(),
            array(
                'menuid'    => Var_helper :: import('menuid', 'post', array()),
                'itemdocid' => Var_helper :: import('itemdocid', 'post', array()),
            )
        );
    }

	// --------------------------------------------------------------------

	/**
	 * Fait une redirection selon le résultat du filtre appliqué
	 *
	 * @access	protected
     * @param integer Identifiant du filtre appliqué
     * @param string Uri de redirection
	 * @return void
	 */
    protected function _redirect_by_filter($filter, $uri)
    {
		/**
		 * Sélection des options de menu par l'identifiant de leur boite de menu
		 */
        $menuid = $this -> _params['menuid'];
     
        if ($filter == '2' && !empty($menuid)) {
            $uri .= is_array($menuid) ? '&menuid='.implode('-', $menuid) : '';
        }
        //
        
		/**
		 * Sélection des options de menu par l'identifiant du document associé
		 */
       $itemdocid = $this -> _params['itemdocid'];
        
        if ($filter == '3' && !empty($itemdocid)) {
            $uri .= is_array($itemdocid) ? '&itemdocid='.implode('-', $itemdocid) : '';                    
        }
        //
        
		/**
		 * Sélection des options de menu par défaut ($filter = 0) et par leurs identifiants ($filter = 1)
		 */    
        parent :: _redirect_by_filter($filter, $uri); // Filter = 0 et 1
        //
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne des données supplémentaires à faire passer à la vue
     * 
	 * @access protected
     * @return array Tableau de données à faire passer à la vue
	 */
    protected function _get_more_data_for_search_form()
    {
       return array(
            'boxmenus' => $this -> _get_menus_boxes(), // Liste des boites de menus
            'docs_for_menuitems' => $this -> _get_internal_docs(), // Liste des documents internes      
       ); 
    }   

	// --------------------------------------------------------------------

	/**
	 * Récupère les données des boites de menus crées par le rédacteur
     * 
     * @access private
	 * @return array Tableau contenant les données des boites de menus sous la forme array(array('id' => , 'title' => ))
	 */	
    private function _get_menus_boxes()
    {
        $this -> CI -> load_helper('boxmenus_helper');
        $boxmenus = $this -> CI -> boxmenus_helper -> get_all(); // Toutes les boites menus enregistrées dans guppy (par défaut) 

        return $boxmenus;           
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents crées par le rédacteur rédacteur
	 *
	 * @access	private
	 * @return	array sous la forme array(id => name)
	 */
    private function _get_internal_docs()
    {
        $docs = array();
        $doc_paths = $this -> CI -> menuitems_model -> get_internal_doc_paths();
        $docs_infos = Model :: get_doc_infos_by_type();
        
        foreach($doc_paths as $doc_type => $doc_path) {
            $docs += array($docs_infos[$doc_type]['name'] => parent :: _get_writer_docs_by_type($doc_type));
        }
        
        $this -> _doc_infos['type'] = TYP_OPTMENU;
        
        return $docs;
    }

	// --------------------------------------------------------------------

} //End of Class