<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

abstract class Search_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_writer_rights = array(); // Droits du rédacteur    
    protected $_doc_infos = array('name' => '', 'type' => ''); // Tableau contenant les informations du document (nom, type)

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
	/**
	 * constructeur
     * 
     * @access public
     * @param string Type du document de guppy (TYP_ART, TYP_NEWS, ...)
     * @param array Tableau contenant les droits du rédacteur
	 * @return void
	 */	
    public function __construct($doc_infos = '', $writer_rights = array())
    {
        $this -> CI =& Controller :: get_instance();

        $this -> CI -> load_helper('var_helper');
        $this -> CI -> load_helper('url_helper');
        $this -> CI -> load_helper('plugin_menu_helper');

        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        $this -> _params = $this -> _set_params();
        $this -> _doc_infos = $this -> _set_doc_infos($doc_infos);
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        if (!empty($_POST)) {
            $filter = $this -> _params['filter'];
            $uri = 'manage_'.$this -> _doc_infos['name'];
           
            $this -> _redirect_by_filter($filter, $uri);    
        }        
        
        $data = array(
            'lang' => $this -> _lang,
            'config' => $this -> _config,
            'form_uri' => Url_helper :: site_url(ADMR_CONTROLLER),
            'params' => $this -> _params,
            'doc_infos' => $this -> _doc_infos,
            'writer_docs' => $this -> _get_writer_docs(), // Liste des documents du rédacteur
        );
        
    //    if (method_exists('Search_'.$this -> _doc_infos['name'].'_helper', '_get_more_data_for_search_form')) {
            $data = array_merge($data, $this -> _get_more_data_for_search_form());    
      //  }

        $this -> CI -> render_page($this -> _get_layout_for_search_records_view(), $data);        
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ''; 
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {        
        $js = '';
        //$js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/'.$prefixe.'manage_records.js"></script>'."\n";

        $css = '';
        //$css = '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/'.$prefixe.'manage_records.css" />';

        return $css.$js;        
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
	 * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return '';
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @access public
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        if (ADMR_IS_ADMIN) {
            $menu_plugin_items = Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            $this -> CI -> load_helper('plugin_menu_for_'.$this -> _doc_infos['name'].'_helper');
            
            $menu_plugin_items = $this -> CI -> {'plugin_menu_for_'.$this -> _doc_infos['name'].'_helper'} -> set_public_items($this -> _doc_infos['name'], $this -> _lang, $this -> _config, $this -> _writer_rights);        
        }
        
  /*      if (ADMR_IS_ADMIN) {
            $menu_plugin_items = Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            $menu_plugin_items = Plugin_menu_helper :: set_public_menu_items($this -> _lang, $this -> _doc_infos['name'], $this -> _writer_rights);    
        }*/
        
        return $menu_plugin_items;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les propriétés du document (type et nom)
     * 
     * @access protected
     * @param string Type du document
	 * @return array Tableau contenant les informations (type, nom) du document
	 */	
    protected function _set_doc_infos($doc_infos)
    {
        if (empty($doc_infos['type']) || empty($doc_infos['name'])) {
            die('ERROR : vous devez définir le type et le nom du document');    
        }        
        
        return $this -> _doc_infos = $doc_infos;        
    }

	// --------------------------------------------------------------------

	/**
	 * définit les droits du rédacteur
     * 
     * @access protected
     * @param array Tabelau définissant les droits du rédacteur (vide par défaut) 
	 * @return array Tableau contenant les droits du rédacteur
	 */	
    protected function _set_writer_rights($writer_rights = array())
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;        
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        return $this -> _params = array(
            'filter' => Var_helper :: import('filter', 'post', 0),
            'docid' => Var_helper :: import('docid', 'post', array()),
        );
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne des données supplémentaires à faire passer à la vue
     * 
	 * @access protected
     * @return array Tableau de données à faire passer à la vue
	 */	
    protected function _get_more_data_for_search_form()
    {
       return array(); 
    }   

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_search_records_view()
    {
        return 'search_records_layout';    
    }
    
	// --------------------------------------------------------------------

	/**
	 * Fait une redirection selon le résultat du filtre appliqué
	 *
	 * @access	protected
     * @param integer Identifiant du filtre appliqué
     * @param string Uri de redirection
	 * @return void
	 */
    protected function _redirect_by_filter($filter, $uri)
    {
		/**
		 * Sélection des documents par leurs identifiants ($filter = 1)
		 */    
        $docids = $this -> _params['docid'];
        
        if ($filter == '1' && !empty($docids)) {
            $uri .= is_array($docids) ? '&docid='.implode('-', $docids) : ''; 
        }
        //
        
        Url_helper :: redirect($uri);
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => name)
	 */
    protected function _get_writer_docs()
    {
        return array();
    }

	// --------------------------------------------------------------------

} // End of Class