<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Upload_files_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
    
    private $_dir_path = '';   // Chemin du répertoire ciblé
    private $_file_type = '';  // Type de fichier (voir le contenu de la variable $config['filemanager']['access'] pour connaitre les différents types de fichiers déclarés)
    private $_error = array(); // Mise en cache des erreurs
    private $_files_uploaded = array(); // Tableau contenant la liste des fichiers chargés
    //

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct()
    {        
        $this -> CI =& Controller :: get_instance();

        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */
        
	// --------------------------------------------------------------------

    /**
     * Définit le chemin du répertoire dans lequel chargé les fichiers
     * 
     * @access public
     * @param string Chemin du répertoire cible
     * @return string Chemin du répertoire cible
     */
    public function set_dir_path($dir_path)
    {
        if (is_dir($dir_path)) {
            $this -> _dir_path = rtrim($dir_path, '/');   
        }
     
        return $this -> _dir_path;
    }
        
	// --------------------------------------------------------------------

    /**
     * Définit le type de fichiers à charger 
     * (voir le contenu de la variable $config['filemanager']['access'] pour connaitre les différents types de fichiers déclarés)
     * 
     * @access public
     * @param string Type de fichiers à charger
     * @return string Type de fichiers à charger
     */
    public function set_file_type($file_type)
    {
        if (array_key_exists($file_type, $this -> _config['file_manager']['access'])) {
            $this -> _file_type = $file_type;   
        }
     
        return $this -> _file_type;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Fait le chargement d'un ou de plusieurs fichiers s'ils sont valides
     * 
	 * @access private
	 * @return boolean Echec ou réussite du chargement des fichiers
	 */
    public function do_upload()
    {
        if (!empty($_FILES['userfiles']) && !empty($this -> _dir_path)) {
        
            $dir = $this -> _dir_path;
            $max_file_size = $this -> _get_max_file_size_allowed();

            foreach ($_FILES['userfiles']['error'] as $key => $file_error) {
                
                $error_msg = '';
                $tmp_name = $_FILES['userfiles']['tmp_name'][$key];
                $name = $_FILES['userfiles']['name'][$key];
                $size = $_FILES['userfiles']['size'][$key];
                
                if ($file_error == UPLOAD_ERR_OK) {
                    // Controle si le fichier n'est pas vide
                    if (empty($size)) {
        	     		$error_msg = $this -> _get_upload_error_message('upload_err_empty'); 
        			}
        			//
                    
                    // Controle de la validité du nom du fichier
        			else if ( ! $this -> _is_valid_file_name($name)) {
        	     		$error_msg = $this -> _get_upload_error_message('upload_err_name');
        			}
        			//
        			
        			// Controle si le nom du fichier existe déjà ou non
        			else if (file_exists($dir.'/'.$name)) {
        		 		$error_msg = $this -> _get_upload_error_message('upload_err_exists');
        			}
        			//
        		
        			// Controle de la taille des fichiers
        			else if (!empty($max_file_size) && $size > $max_file_size) {
      					$error_msg = $this -> _get_upload_error_message(UPLOAD_ERR_FORM_SIZE);
        			}
        			//
        
        			// Controle de l'autorisation de l'extension du fichier
        			else if(! $this -> _is_allowed_file_ext($name))
                    { 
        		 		$error_msg = $this -> _get_upload_error_message(UPLOAD_ERR_EXTENSION);	
        			}
        			//

        			// Upload et indexation
        			if (empty($error_msg) && move_uploaded_file($tmp_name, $dir.'/'.$name)) {
    	   				@chmod($dir.'/'.$name, 0644);
                        $this -> _files_uploaded[$name] = str_replace(CHEMIN, '', $dir).'/'.$name; 
        			}
        			//
                } else {
                    $error_msg = $this -> _get_upload_error_message($file_error);
                }
                
                if (!empty($error_msg)) {
                    $this -> _errors[$name] = $error_msg;
                } 
            }
            
            if (empty($this -> _errors)) {
                return TRUE;
            }
        }
        
        return FALSE;
    }
        
	// --------------------------------------------------------------------

    /**
     * Renvoie les erreurs générées lors du chargement des fichiers
     * 
     * @access public
     * @return array Tableau contenant les erreurs
     */
    public function get_errors()
    {
        return $this -> _errors;
    }
        
	// --------------------------------------------------------------------

    /**
     * Renvoie les noms et les chemins des fichiers qui ont été chargés sans erreur
     * 
     * @access public
     * @return array Tableau contenant les noms et les chemins des fichiers qui ont été chargés sous la forme array(name => path)
     */
    public function get_files_uploaded()
    {
        return $this -> _files_uploaded;
    }
        
	// --------------------------------------------------------------------

    /**
     * Renvoie la taille maximale (en octet) autorisée pour le fichier uploadé
     * 
     * @access private
     * @return integer Taille (en octet) maximale autorisée pour uploader un fichier
     */
    private function _get_max_file_size_allowed()
    {
        $config_upload = $this -> _config['file_manager']['upload'];
        $config_type = $this -> _config['file_manager']['access'][$this -> _file_type];
       
        $max_file_size = isset($config_type['max_size']) ? $config_type['max_size'] : $config_upload['max_size'];

        return $max_file_size;
    }
        
	// --------------------------------------------------------------------

    /**
     * Controle si l'extension du fichier est autorisé ou non
     * 
     * @access private
     * @param string Nom du fichier
     * @return boolean
     */
    private function _is_allowed_file_ext($filename)
    {
        $config_upload = $this -> _config['file_manager']['upload'];
        $config_type = $this -> _config['file_manager']['access'][$this -> _file_type];
       
        $allowed_ext = isset($config_type['allowed_ext']) ? $config_type['allowed_ext'] : $config_upload['allowed_ext'];
        $denied_ext = isset($config_type['denied_ext']) ? $config_type['denied_ext'] : $config_upload['denied_ext'];

        if( ( count($allowed_ext) > 0 && !in_array( strrchr($filename, '.'), $allowed_ext) )
    		     || ( count($denied_ext) > 0 && in_array( strrchr($filename, '.'), $denied_ext) ) )
        { 
     		return FALSE;	
    	}
        
        return TRUE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * vérifie si le nom du répertoire est valide ou non
     * 
	 * @access public
     * @param  string Nom du répertoire à valider
	 * @return boolean Résultat de la validation
	 */
    private function _is_valid_file_name($file_name)
    {
        return preg_match('`^[a-z0-9\-_]+\.[a-z0-9]{2,}$`i', $file_name) ? TRUE : FALSE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Renvoie le message d'erreur du chargement d'un fichier
     * 
	 * @access private
     * @param  string Code d'erreur
	 * @return string Message d'erreur correspondant au code d'erreur
	 */
    private function _get_upload_error_message($error_code)
    {
        $error_msg = array(
            UPLOAD_ERR_INI_SIZE   => $this -> _lang['form_errors_msg']['upload_error_ini_size'],
            UPLOAD_ERR_FORM_SIZE  => sprintf($this -> _lang['form_errors_msg']['upload_error_form_size'], round($this -> _get_max_file_size_allowed() / 1024)),
            UPLOAD_ERR_PARTIAL    => $this -> _lang['form_errors_msg']['upload_error_partial'],
            UPLOAD_ERR_NO_FILE    => $this -> _lang['form_errors_msg']['upload_error_no_file'],
            UPLOAD_ERR_NO_TMP_DIR => $this -> _lang['form_errors_msg']['upload_error_no_tmp_dir'],
            UPLOAD_ERR_CANT_WRITE => $this -> _lang['form_errors_msg']['upload_error_file_cant_write'],
            UPLOAD_ERR_EXTENSION  => $this -> _lang['form_errors_msg']['upload_error_file_extension'],
            'upload_err_empty'    => $this -> _lang['form_errors_msg']['upload_error_file_is_required'],
            'upload_err_exists'   => $this -> _lang['form_errors_msg']['upload_error_file_already_exists'],
            'upload_err_name'     => $this -> _lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes'],
        );
        
        if (empty($error_code)) {
            return $error_msg;    
        }
        
        if (is_array($error_code)) {
            return array_intersect_key($error_msg, array_flip($error_code));
        }
        
        return !empty($error_msg[$error_code]) ? $error_msg[$error_code] : $this -> _lang['form_errors_msg']['upload_error_unknown'];
     } 


} // End of Class