<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Url_helper
{	
	/**
	 *  redirige vers une nouvelle adresse
     * 
     * @access public
	 * @param string Adresse de redirection
     * @param string Méthode de redirection (location ou refresh)
     * @param integer Code renvoyé par le serveur
 	 * @return void
	 */
	public static function redirect($uri = '', $method = 'location', $http_response_code = 302)
	{
		if ( ! preg_match('#^https?://#i', $uri) && strpos($uri, '?') === FALSE)
		{
            $uri = self :: site_url($uri);
		}

		switch($method)
		{
			case 'refresh'	: header("Refresh:0;url=".$uri);
				break;
			default			: header("Location: ".$uri, TRUE, $http_response_code);
				break;
		}
		exit;
	}

	// --------------------------------------------------------------------

	/**
	 *  renvoie l'adresse relative de la page
     * 
     * @access public
	 * @param string Adresse de la page (controller + params) 
 	 * @return string
	 */
    public static function site_url($uri)
    {
        if (strpos($uri, ADMR_BASE_HREF_PLUGIN.'&ctrl=') !== 0) {
            $uri = ADMR_BASE_HREF_PLUGIN.'&ctrl='.$uri;    
        }
        
        return $uri;
    }

    // ------------------------------------------------------------------------
    
    /**
     * Renvoie l'adresse complete de la page où cette fonction est appelée
     *
     * @access	public
     * @return	string
     */
   	public static function complete_url($uri)
	{
		return ADMR_SITE_URL.'plugins/'.ADMR_DIRNAME.'/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.$uri;
	}
  
	// ---------------------------------------------------------------------------- //

	/**
	 * construit et retourne une uri
     * 
     * @access protected
     * @param array paramètres de l'uri sous la forme array($key => $value)
	 * @return void
	 */	
    public static function build_uri($query_params = array(), $basehref = '', $anchor = '')
    {
        settype($query_params, 'array');
        
        $href =  empty($basehref)? ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER : $basehref;
        
        foreach($query_params as $name => $value) {
            if ($value != '') {
                $href .= '&'.$name.'='.$value;    
            } 
        }
        
        if (!empty($anchor)) {
            $href .= '#'.$anchor;  
        }
        
        return $href;        
    }

	// ---------------------------------------------------------------------------- //

	/**
	 * Construit et retourne un lien pour le tri des enregistrements
	 *
	 * @access protected
	 * @params string Option de tri
	 * @params string Texte du lien
	 * @params string Nom de base de l'item de tri (optionnel)
	 * @return string Tableau html contenant le lien de tri
	 */
/*    public static function anchor_for_sorting_records($sort_option, $text, $sort_basename = '')
    {
        $CI =& Controller :: get_instance();
        
        if (empty($sort_basename)) {
            $sort_basename = strtolower($text);
        }
        
        $sort_item = ($sort_option == $sort_basename.'_asc') ? $sort_basename.'_desc' : $sort_basename.'_asc';        
        $img_src = ($sort_option == $sort_basename.'_asc') ? ADMR_IMG_SORT_DESC : ADMR_IMG_SORT_ASC;

        $title = sprintf($CI -> get_lang('sort_records_by_%s'), $CI -> get_lang($sort_item));
        $href = self :: build_uri(array('sort' => $sort_item));
       
        return '<a href="'.$href.'" title="'.$title.'">'.$text.'&nbsp;<img src="'.$img_src.'" alt="'.$title.'" /></a>';
    }
*/
	// ---------------------------------------------------------------------------- //

}