<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Pagination
{	
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $class_name;
    protected $url;
    protected $total_items;
    protected $current_page = 1;
    protected $max_items_per_page = 10;
    protected $img_begin = '';
    protected $img_prev = '';
    protected $img_next = '';
    protected $img_end = '';
    protected $img_beginN = '';
    protected $img_prevN = '';
    protected $img_nextN = '';
    protected $img_endN = '';
    protected $img_minus = '';
    protected $img_plus = '';
    protected $decade = 10;
	protected $tri = '';
    protected $anchor = '';
    //

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
	public function __construct($params = array())
	{
		if (!empty($params)) {
			$this -> initialize($params);
		}
	}

	// --------------------------------------------------------------------

	/**
	 * Initialize properties
	 *
	 * @access	public
	 * @param	array	initialization parameters
	 * @return	void
	 */
    public function initialize($params = array())
    {
        settype($params, 'array');
        
        foreach($params as $key => $value) {
            $methode = 'set_'.$key;
            
            if (is_callable(array($this, $methode))) {
                $this -> $methode($value);    
            }     
        }
    }

	// --------------------------------------------------------------------

	/**
	 * Définit la classe CSS de la barre de navigation
	 *
	 * @access	public
	 * @param	string	classe
	 * @return	void
	 */
    public function set_class_name($class_name)
    {
        $this -> class_name = $class_name;
    }

	// --------------------------------------------------------------------

	/**
	 * Définit l'url de base
	 *
	 * @access	public
	 * @param	string	Url
	 * @return	void
	 */
    public function set_url($url)
    {
        $this -> url = $url;
    }

	// --------------------------------------------------------------------

	/**
	 * Définit le nombre total d'items à prendre en compte
	 *
	 * @access	public
	 * @param	integer le nombre maximum d'item à prendre en compte
	 * @return	void
	 */
    public function set_total_items($total_items)
    {
        $this -> total_items = $total_items;
    }

	// --------------------------------------------------------------------

	/**
	 * Définit le numéro de la page courante
	 *
	 * @access	public
	 * @param	integer le numéro de la page courante
	 * @return	void
	 */
    public function set_current_page($current_page)
    {
        $this -> current_page = $current_page;    
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit le nombre maximum d'items par page
	 *
	 * @access	public
	 * @param	integer le nombre maximum d'items par page
	 * @return	void
	 */
    public function set_max_items_per_page($max_items_per_page)
    {
        $this -> max_items_per_page = $max_items_per_page;    
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller au premier onglet dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_begin($img_begin)
    {
        $this -> img_begin = $img_begin;
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller à l'onglet précédent dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_prev($img_prev)
    {
        $this -> img_prev = $img_prev;
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller à l'onglet suivant dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_next($img_next)
    {
        $this -> img_next = $img_next;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller au dernier onglet dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_end($img_end)
    {
        $this -> img_end = $img_end;
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller au premier onglet dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_beginN($img_beginN)
    {
        $this -> img_beginN = $img_beginN;
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller à l'onglet précédent dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_prevN($img_prevN)
    {
        $this -> img_prevN = $img_prevN;
    }
 
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller à l'onglet suivant dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_nextN($img_nextN)
    {
        $this -> img_nextN = $img_nextN;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour aller au dernier onglet dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_endN($img_endN)
    {
        $this -> img_endN = $img_endN;
    }    
    
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour afficher les dix onglets précédents dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_minus($img_minus)
    {
        $this -> img_minus = $img_minus;
    }   
    
	// --------------------------------------------------------------------

	/**
	 * Définit l'image pour afficher les dix onglets suivants dans la barre de navigation
	 *
	 * @access	public
	 * @param	string source de l'image
	 * @return	void
	 */
    public function set_img_plus($img_plus)
    {
        $this -> img_plus = $img_plus;
    }   
    
	// --------------------------------------------------------------------

	/**
	 * Définit une ancre à rajouter aux liens dans la barre de navigation
	 *
	 * @access	public
	 * @param	string Ancre sans le caractère #
	 * @return	void
	 */
    public function set_anchor($anchor)
    {
        $this -> anchor = $anchor;
    }

	// --------------------------------------------------------------------

    /**
     * Construit et retourne la barre de navigation
     *
     * @access	public
     * @param	array	initialization parameters (optional)
     * @return	string Barre de navigation
     */	
    public function generate($params = array())
    {
        global  $page, $web, $site, $reptheme;

        if (!empty($params)) {
            $this -> initialize($params);    
        }
        
        $class_name = !empty($this -> class_name) ? ' '.$this -> class_name : '';
        $url = $this -> url;
        $total_items = $this -> total_items;
        $current_page = $this -> current_page;
        $max_items_per_page = $this -> max_items_per_page;
        $decade = $this -> decade;
        $tri = $this -> tri;
        $anchor = $this -> anchor;     
        $img_begin  = empty($this -> img_begin)  ? $reptheme.'/debut.png'       : $this -> img_begin;
        $img_prev   = empty($this -> img_prev)   ? $reptheme.'/precedent.png'   : $this -> img_prev;
        $img_next   = empty($this -> img_next)   ? $reptheme.'/suivant.png'     : $this -> img_next;
        $img_end    = empty($this -> img_end)    ? $reptheme.'/fin.png'         : $this -> img_end;
        $img_beginN = empty($this -> img_beginN) ? $reptheme.'/debut_n.png'     : $this -> img_beginN;
        $img_prevN  = empty($this -> img_prevN)  ? $reptheme.'/precedent_n.png' : $this -> img_prevN;
        $img_nextN  = empty($this -> img_nextN)  ? $reptheme.'/suivant_n.png'   : $this -> img_nextN;
        $img_endN   = empty($this -> img_endN)   ? $reptheme.'/fin_n.png'       : $this -> img_endN;
        $img_minus  = empty($this -> img_minus)  ? $reptheme.'/minuspg.png'     : $this -> img_minus;
        $img_plus   = empty($this -> img_plus)   ? $reptheme.'/pluspg.png'      : $this -> img_plus;
    
        $out = '';
        if ($total_items > $max_items_per_page) {
            $nbPage= $max_items_per_page > 0 ? (ceil($total_items/$max_items_per_page)) : 1;
            $out .= '<p class="navbar'.$class_name.'">';
            if ($current_page > 1) {
                $out .= '<span><a href="'.$url.'1'.(!empty($anchor) ? '#'.$anchor : '').'"><img src="'.$img_begin.'" alt="'.$web[339].'" title="'.$web[339].'" /></a></span>';
                $out .= '<span><a href="'.$url.($current_page-1).(!empty($anchor) ? '#'.$anchor : '').'"><img src="'.$img_prev.'" alt="'.$web[32].'" title="'.$web[32].'" /></a></span>';
            }
            else {
                $out .= '<span><img src="'.$img_beginN.'" alt="'.$web[339].'" title="'.$web[339].'" /></span>';
                $out .= '<span><img src="'.$img_prevN.'" alt="'.$web[32].'" title="'.$web[32].'" /></span>';
            }
            $out .= '<span>';
            $nbpg = 1;
            $pgDebut = floor($current_page / $decade) * $decade;
            $pgFin = ceil($current_page / $decade) * $decade;
            if ($pgDebut == $pgFin) {
                $pgDebut = $pgFin - $decade;
            }
            if ($current_page > $pgDebut && $current_page <= $pgFin) {
                $decadeDebut = $pgDebut;
                $decadeFin   = $pgFin;
                $paq = $nbPage >= $decadeFin ? $decade : $nbPage - $decadeDebut;
            }
            if ($current_page > $decade && $decadeDebut < $nbPage) {
                if ($nbPage - $decade + $decadeFin > $decade) {
                    $nbPrevPage = $decade;
                }
                else {
                    $nbPrevPage = $nbPage - $decade + $decadeFin;
                }
                if ($nbPrevPage > 1) {
                    $txtPrevPage = $nbPrevPage." ".$web[340];
                }
                else {
                    $txtPrevPage = $nbPrevPage." ".$web[341];
                }
                $out .= '<a href="'.$url.($current_page + $decadeDebut - $decadeFin).(!empty($anchor) ? '#'.$anchor : '').'"><img src="'.$img_minus.'" alt="'.$txtPrevPage.'" title="'.$txtPrevPage.'" /></a>';
            }
            $out .= '&nbsp;&nbsp;[&nbsp;';
            for($i = 1; $i <= $paq; $i++) {
                if ($i + $decadeDebut <> $current_page) {
                    $out .= '<a href="'.$url.($i + $decadeDebut).(!empty($anchor) ? '#'.$anchor : '').'">'.($nbpg + $decadeDebut).'</a>&nbsp;';
                } else {
                    $out .= '<strong>'.($nbpg + $decadeDebut).'</strong>&nbsp;';
                }
                $nbpg++;
            }
            $out .= ']&nbsp;&nbsp;';
            if($current_page <= $decadeFin && $decadeFin < $nbPage) {
                if($nbPage - $decade - $decadeDebut > $decade) {
                    $nbSuivPage = $decade;
                }
                else {
                    $nbSuivPage = $nbPage - $decade - $decadeDebut;
                }
                if ($nbSuivPage > 1) {
                    $txtSuivPage = $nbSuivPage." ".$web[337];
                }
                else {
                    $txtSuivPage = $nbSuivPage." ".$web[336];
                }
                $out .= '<a href="'.$url.$tri.($i + $decadeDebut).(!empty($anchor) ? '#'.$anchor : '').'"><img src="'.$img_plus.'" alt="'.$txtSuivPage.'" title="'.$txtSuivPage.'" /></a>';
            }
            $out .= '</span>';
            if ($current_page < $nbPage) {
                $out .= '<span><a href="'.$url.($current_page + 1).(!empty($anchor) ? '#'.$anchor : '').'"><img src="'.$img_next.'" alt="'.$web[34].'" title="'.$web[34].'" /></a></span>';
                $out .= '<span><a href="'.$url.$nbPage.(!empty($anchor) ? '#'.$anchor : '').'"><img src="'.$img_end.'" alt="'.$web[338].'" title="'.$web[338].'" /></a></span>';
            }
            else {
                $out .= '<span><img src="'.$img_nextN.'" alt="'.$web[34].'" title="'.$web[34].'" /></span>';
                $out .= '<span><img src="'.$img_endN.'" alt="'.$web[338].'" title="'.$web[338].'" /></span>';
            }
            $out .= '</p>';
        }
     
        return $out;
    }

	// --------------------------------------------------------------------

} // End of Class