<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('CHEMIN') OR exit('No direct script access allowed');

/**
 * Php_session Class
 *
 * Permits to use a php native session
 *
 * @package		CodeIgniter
 * @subpackage	Libraries
 * @category	Libraries
 * @author		Jerome Croux
 * @link		
 */
class php_session
{
	var $_flash = array();

    /**
	 * Constructor
	 */
    function __construct()
	{
        session_start();
        
        $this -> init_flashdata();
    }
  
	// --------------------------------------------------------------------

    /** 
	 * Save a session variable
	 *
	 * @access	public
     * @param   string  Name of variable to save
     * @param   mixed   Value to save
     * @param   string(optional) Namespace to use. Defaults to 'default'. 'flash' is reserved.
	 * @return	void
     */
    function save($var, $val, $namespace = 'default')
	{
        if ($var === NULL) {
            $_SESSION[$namespace] = $val;
        } else {
            $_SESSION[$namespace][$var] = $val;
        }
    }
   
	// --------------------------------------------------------------------

    /**
	 * Get the value of a session variable
	 *
	 * @access	public
     * @param   string  Name of variable to load. NULL loads all variables in namespace (associative array)
     * @param   string(optional) Namespace to use, defaults to 'default'
	 * @return	void
     */
    function get($var = NULL, $namespace = 'default')
	{
        if (isset($var)) {
            return isset($_SESSION[$namespace][$var]) ? $_SESSION[$namespace][$var] : NULL;
        } else {
            return isset($_SESSION[$namespace]) ? $_SESSION[$namespace] : NULL;
		}			
    }
  
	// --------------------------------------------------------------------

    /** 
	 * Clears all variables in a namespace
	 *
	 * @access	public
     * @param   string  Name of variable to load. NULL loads all variables in namespace (associative array)
     * @param   string(optional) Namespace to use, defaults to 'default'
	 * @return	void
     */
    function clear($var = NULL, $namespace = 'default')
	{
        if (isset($var) && ($var !== NULL)) {
            unset($_SESSION[$namespace][$var]);
        } else {
            unset($_SESSION[$namespace]);
		}
    }
  
	// --------------------------------------------------------------------

    /** 
	 * Initializes the flash variable routines
	 *
	 * @access	public
	 * @return	void
     */
    function init_flashdata()
	{
        $this -> _flash = $this -> get(NULL, 'flash');
        $this -> clear(NULL, 'flash');
    }
  
	// --------------------------------------------------------------------

    /**
	 * Saves a flash variable. These are only saved for one page load
	 *
	 * @access	public
     * @param   string Variable name to save
     * @param   mixed  Value to save
	 * @return	void
     */
    function save_flashdata($var, $val)
	{
        $this -> save($var, $val, 'flash');
    }
   
	// --------------------------------------------------------------------

    /**
	 * Gets the value of a flash variable. These are only saved for one page load, so the variable must
     * have either been set or had keep_flashdata() called on the previous page load
	 *
	 * @access	public
     * @param   string Variable name to get
	 * @return	string
     */
    function get_flashdata($var)
	{
        if (isset($this -> _flash[$var])) {
            return $this -> _flash[$var];
        } else {
            return NULL;
        }
    }
  
	// --------------------------------------------------------------------

    /**
	 * Keeps the value of a flash variable for another page load.
	 *
	 * @access	public
     * @param   string(optional) Variable name to keep, or NULL to keep all. Defaults to keep all (NULL)
	 * @return	void
     */
    function keep_flashdata($var = NULL)
	{
        if ($var !== NULL) {
            $this -> save_flashdata($var, $this -> get_flashdata($var));
        } else {
            $this -> save(NULL, $this -> _flash, 'flash');
        }
    }

}
// END Php_session Class

/* End of file Php_session.php */
/* Location: ./application/libraries/Php_session.php */