<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Writers_managed
{
	private $error = array();
    private $_writer_admin_rights = array(); // Droits du rédacteur admin
    
    protected $CI; // Instance du controller (super object)

	function __construct($admin_id = 0)
	{
        $this -> CI =& Controller :: get_instance();

        $this -> CI -> load_model('writer_model');
        $this -> CI -> load_model('group_model');
        $this -> CI -> load_model('rights_model', 'writer', 'rights_writer_model');
        $this -> CI -> load_model('rights_model', 'group',  'rights_group_model');
              
        $this -> _writer_admin_rights = (ADMR_IS_ADMIN) ? $this -> CI -> rights_writer_model -> get_admin_rights() : $this -> get_writer_rights($admin_id);
	}

	// --------------------------------------------------------------------

	/**
	 * Get writer rights
	 *
	 * @return	string
	 */
	public function get_writer_rights($writer_id)
	{
        $rights = array();
        
        if (!empty($writer_id)) {
            $writer = $this -> CI -> writer_model -> get_by_id($writer_id);
            
            if (!empty($writer)) {
                $rights = $this -> CI -> rights_writer_model -> read($writer['id']);
        //        unset($rights['pass']);
                
                if (!empty($writer['groupid'])) {
                    $rights_group = $this -> CI -> rights_group_model -> read($writer['groupid']);
                    $rights_group['group_name'] = $rights_group['name'];
                    unset($rights_group['id'], $rights_group['name']); // important pour éviter l'écrasement des identifiants du rédacteur
                    
                    $rights = array_merge($rights, $rights_group);
                }
            }
        }
        
        return $rights;
	}

	// --------------------------------------------------------------------

    /*
     * vérifie que l'identifiant correspond bien à un rédacteur enregistré et autorisé à être géré
     *
     * @param integer Identifiant du rédacteur géré
     * @param integer Identifiant du rédacteur admin
     * @return boolean
     */
    public function is_writer_managed($writer_managed_id)
    {
        $rights = $this -> _writer_admin_rights;
        $writers_managed = $this -> get_writers_managed();

        return (!empty($rights['writers_manage']) && array_key_exists($writer_managed_id, $writers_managed)) ? TRUE : FALSE; 
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie les droits pour gérer les documents du rédacteur pris en charge
     *
     * @param integer Identifiant du rédacteur géré
     * @param array Nom du ou des documents du rédacteur à gérer
     * @return boolean
     */
    public function set_rights_for_manage_docs($writer_managed_id, $docs_names)
    {
        settype($docs_names, 'array');
        $rights = $this -> _writer_admin_rights;
        $writer_managed_rights = $this -> get_writer_rights($writer_managed_id);
     
        /**
         * Redéfinition des droits du rédacteur administrateur pour la gestion des documents du rédacteur géré
         */
        $writer_rights_new = array(
            'id' => $writer_managed_rights['id'],
            'name' => $writer_managed_rights['name'],
        );
        
        foreach($docs_names as $doc_name) {
            $writer_rights_new[$doc_name.'_manage'] = 1;
            $writer_rights_new[$doc_name.'_add']  = (!ADMR_IS_ADMIN && empty($rights['writers_docs_add'])) ?  0 : 1;
            $writer_rights_new[$doc_name.'_edit'] = (!ADMR_IS_ADMIN && empty($rights['writers_docs_edit'])) ? 0 : 1;
            $writer_rights_new[$doc_name.'_act']  = (!ADMR_IS_ADMIN && empty($rights['writers_docs_act'])) ?  0 : 1;
            $writer_rights_new[$doc_name.'_del']  = (!ADMR_IS_ADMIN && empty($rights['writers_docs_del'])) ?  0 : 1;

/*
            $writer_rights_new[$doc_name.'_add']  = empty($rights['writers_docs_add']) ?  0 : 1;
            $writer_rights_new[$doc_name.'_edit'] = empty($rights['writers_docs_edit']) ? 0 : 1;
            $writer_rights_new[$doc_name.'_act']  = empty($rights['writers_docs_act']) ?  0 : 1;
            $writer_rights_new[$doc_name.'_del']  = empty($rights['writers_docs_del']) ?  0 : 1;
*/
            
            if (isset($writer_managed_rights[$doc_name.'_cats_manage'])) { // Gestion des catégories si définies
                $writer_rights_new[$doc_name.'_cats_manage'] = 1;        
            }
    
            if (isset($writer_managed_rights[$doc_name.'_boxes_manage'])) { // Gestion des boites de menus si définies
                $writer_rights_new[$doc_name.'_boxes_manage'] = 1;        
            }
        }        
        //

        return array_merge($rights, $writer_rights_new);           
    }

	// --------------------------------------------------------------------

	/**
	 * Récupére les rédacteurs autorisés à être gérés
     * 
     * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @param string Option de tri (optionnel)
	 * @return array Tableau contenant les rédacteurs autorisés
	 */	
    public function get_writers_managed($filters = array(), $sort_by = '')
    {
        $writers_managed = array();
        $rights = $this -> _writer_admin_rights;
                
        if (empty($rights['writers_allowed'])) { // Aucun rédacteur à gérer
            $writers_managed = array();    
        }
        elseif ($rights['writers_allowed'] == 1) { // Tous les rédacteurs à gérer
            $writers_managed = $this -> CI -> writer_model -> get();   
        }
        elseif ($rights['writers_allowed'] == 2 && !empty($rights['writers_list_allowed'])) { // Gestion des rédacteurs appartenant à une liste
            $writers_managed = $this -> CI -> writer_model -> get(array('id' => $rights['writers_list_allowed']));
        }
        elseif ($rights['writers_allowed'] == 3 && !empty($rights['writers_groups_list_allowed'])) { // Gestion des rédacteurs appartenant à un groupe
            $writers_managed = $this -> CI -> writer_model -> get(array('groupid' => $rights['writers_groups_list_allowed']));
        }
        
        if (!empty($filters)) {
            $writers_managed = array_intersect_key($writers_managed, $this -> CI -> writer_model -> get($filters)); // Filtrage des rédacteurs           
        }        
        
        unset($writers_managed[$rights['id']]); // Suppression du rédacteur admin (IMPORTANT !! : à faire avant le tri)
        
        if (!empty($sort_by)) {
            $writers_managed = $this -> CI -> writer_model -> sort_by_key($writers_managed, $sort_by); // Tri des rédacteurs           
        }
        
        return $writers_managed;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des groupes rédacteurs autorisés à être gérés
	 *
     * @access protected
     * @param string Option de tri des rédacteurs (optionnel)
	 * @return array Tableau contenant les rédacteurs autorisés
	 */	
    public function get_groups_managed($sort_option = '')
    {
        $groups = array();
        $rights = $this -> _writer_admin_rights;

        if (!empty($rights['writers_allowed']))
        {
            if ($rights['writers_allowed'] == 1) { // Tous les rédacteurs
                $groups = $this -> CI -> group_model -> get();     
            }        
            elseif ($rights['writers_allowed'] == 2 && !empty($rights['writers_list_allowed'])) { // Rédacteurs sélectionnés
                $writers = $this -> CI -> writer_model -> get(array('id' => $rights['writers_list_allowed']));
                unset($writers[$this -> _writer_rights['id']]); // Suppression du "super" rédacteur qui gère les autres
                
                foreach($writers as $writer) {
                    $group_ids[$writer['groupid']] = $writer['groupid'];
                }
                
                $groups = $this -> CI -> group_model -> get(array('id' => $group_ids));     
            }
            elseif ($rights['writers_allowed'] == 3 && !empty($rights['writers_groups_list_allowed'])) { // Groupes de rédacteurs sélectionnés
                $groups = $this -> CI -> group_model -> get(array('id' => $rights['writers_groups_list_allowed']));   
            }
    
            
            if (!empty($sort_option)) {
                $groups = $this -> CI -> group_model -> sort_by_key($groups, $sort_option); // Tri des groupes rédacteurs           
            }
        }
       
        return $groups;    
    }

	// --------------------------------------------------------------------

    /*
     * vérifie que le type du document correspond bien à un type enregistré et autorisé pour la gestion des rédacteurs
     *
     * @param string Type du document à tester
     * @return boolean
     */
    public function is_doc_type_allowed($doc_type)
    {
        $rights = $this -> _writer_admin_rights;
        $doc_types_allowed = $this -> get_doc_types_allowed();
      
        return (!empty($rights['writers_docs_manage']) && array_key_exists($doc_type, $doc_types_allowed)) ? TRUE : FALSE;
    }

	// --------------------------------------------------------------------

    /*
     * vérifie que le type du document correspond bien à un type enregistré et autorisé pour la gestion des documents des rédacteurs
     *
     * @param string Type du document à tester
     * @return boolean
     */
    public function is_addons_doc_type_allowed($addon_doc_type)
    {
        $rights = $this -> _writer_admin_rights;

        if (empty($rights['writers_docs_manage'])) { // Aucun type de documents à gérer
            return FALSE;    
        }
        elseif ($rights['writers_docs_manage'] == 1) { // Tous les types de documents à gérer
            return TRUE;   
        }
        elseif ($rights['writers_docs_manage'] == 2 && !empty($rights['writers_docs_types_allowed'])) { // Gestion des documents du rédacteur appartenant à une liste de type autorisée
            return in_array($addon_doc_type, $rights['writers_docs_types_allowed']) ? TRUE : FALSE;
        }
    }

	// --------------------------------------------------------------------

	/**
	 * Récupére les types de documents autorisées pour la gestion des rédacteurs
     * 
     * @access protected
     * @param array Droits du rédacteur admin
	 * @return array Tableau contenant les rédacteurs autorisés
	 */	
    public function get_doc_types_allowed($sort_option = '')
    {
        $doc_types = array();
        $rights = $this -> _writer_admin_rights;

        if (empty($rights['writers_docs_manage'])) { // Aucun type de documents à gérer
            $doc_types = array();    
        }
        elseif ($rights['writers_docs_manage'] == 1) { // Tous les types de documents à gérer
            $doc_types = $this -> CI -> writer_model -> get_doc_types();   
        }
        elseif ($rights['writers_docs_manage'] == 2 && !empty($rights['writers_docs_types_allowed'])) { // Gestion des documents du rédacteur appartenant à une liste de type autorisée
            $doc_types = $this -> CI -> writer_model -> get_doc_types($rights['writers_docs_types_allowed']);
        }
     
        if (!empty($sort_option)) {
            $doc_types = $this -> CI -> writer_model -> sort_doc_types_by_key($doc_types, $sort_option); // Tri des documents           
        }
       
        return $doc_types;
    }

	// --------------------------------------------------------------------

	/**
	 * Récupére les documents du rédacteur géré
     * 
     * @access protected
     * @param object Instance du model de gestion des documents du rédacteur géré
     * @param array Filtres sur les documents à gérer de la forme array($key1 => $values1, $key2 => $values2, ...) (optionnel)
     * @param string Option de tri des données
	 * @return array Tableau contenant les documents du rédacteur géré
	 */
    public function get_writer_docs(Writer_docs_model $writer_docs_model, $filters = array(), $sort_by = '')
    {
        $docs = array();
        $rights = $this -> _writer_admin_rights;       
  
        if (empty($rights['writers_docs_manage'])) { // Aucun documents à gérer
            $docs = array();    
        }
        elseif ($rights['writers_docs_manage'] == 1) { // Tous les documents à gérer
            $docs = $writer_docs_model -> get($filters, $sort_by);   
        }
        elseif ($rights['writers_docs_manage'] == 2 && !empty($rights['writers_docs_types_allowed'])) { // Gestion des documents du rédacteur appartenant à une liste de type autorisée
            $doc_types = array_intersect($rights['writers_docs_types_allowed'], (array) $filters['type']);
            
            $filters['type'] = !empty($doc_types) ? $doc_types : $rights['writers_docs_types_allowed'];

            $docs = $writer_docs_model -> get($filters, $sort_by);
        }
       
        return $docs;
   }

	// --------------------------------------------------------------------

} //End of Class