<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_index_model.php';

class Articles_index_model extends Docs_index_model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_ART;

    private $_params = array(
        'cat1'      => '', // Catégorie pour la langue 1
        'cat2'      => '', // Catégorie pour la langue 2
        'title1'    => '', // Titre pour la langue 1
        'title2'    => '', // Titre pour la langue 2
        'id'        => '', // Identifiant du document
        'boxmenu'   => '', // Choix du menu
        'group'     => '', // Groupe privé
        'type'      => '', // Type du document
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);              
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données enregistrées du rédacteur
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read()
    {
        $data = array();
        $db = parent :: read();    // Récupérer données enregistrés dans le fichier d'index.dtb        
            
        foreach($db as $row) {
            $data[$row[4]] = array(
                'cat1'      => empty($row[0])? 'Hors Catégorie' : $row[0], // Catégorie pour la langue 1
                'cat2'      => empty($row[1])? 'Hors Catégorie' : $row[1], // Catégorie pour la langue 2
                'title1'    => $row[2], // Titre pour la langue 1
                'title2'    => $row[3], // Titre pour la langue 2
                'id'        => $row[4], // Identifiant du document
                'boxmenu'   => $row[5], // Choix du menu
                'group'     => $row[6], // Groupe privé
                'type'      => $row[7], // Type du document
            );    
        }
        
        return $data;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de l'index
     * 
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return integer Identifiant du document rajouté
	 */    
    public function insert($params)
    {
        settype($params, 'array');
        $params = array_merge($this -> _params, $params);
        
        $data[0]  = $params['cat1'];
        $data[1]  = $params['cat2'];
        $data[2]  = $params['title1'];
        $data[3]  = $params['title2'];
        $data[4]  = $params['id'];
        $data[5]  = $params['boxmenu'];
        $data[6]  = $params['group'];
        $data[7]  = $this -> _doc_type;        

        // Suppression des connecteurs
        $data = parent :: clean($data);
        
        // Rajout des données du document
        parent :: append($data);        
        
        return $params['id'];            
    }    
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     *
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return integer Identifiant du document rajouté
	 */    
    public function update($params)
    {
        settype($params, 'array');
        
        $data = parent :: read();
        $id = $params['id'];

        if (!empty($data[$id])) { // Mise à jour
            $data[$id][0] = $params['cat1'];
            $data[$id][1] = $params['cat2'];
            $data[$id][2] = $params['title1'];
            $data[$id][3] = $params['title2'];
            $data[$id][4] = $params['id'];
            $data[$id][5] = $params['boxmenu'];
            $data[$id][6] = $params['group'];
            $data[$id][7] = $this -> _doc_type;
            
            $data[$id] = parent :: clean($data[$id]);
            
            parent :: write($data);            
        }
        
        return $params['id']; 
    }
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     *
     * @access public 
	 * @param array Tableau contenant les identifiants des documents à supprimer
	 * @return void
	 */    
    public function delete($ids)
    {
        settype($ids, 'array');
        
        $data = parent :: read();

        foreach($ids as $id) {
            if (!empty($data[$id])) {
                unset($data[$id]);
            }            
        }
        
        parent :: write($data);
    }

	// --------------------------------------------------------------------

} // End of Class