<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_index_model.php';

class Articles_menuitems_index_model extends Docs_index_model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type;

    private $_params = array(
        'id_art'      => '', // Id de l'article
        'id_item'     => '', // Id de l'item de menu
        'id_menu'     => '', // Id du menu
        'menu_title1' => '', // Titre du menu pour la langue 1
        'menu_title2' => '', // Titre du menu pour la langue 2
        'item_cat1'   => '', // Catégorie de l'item de menu pour la langue 1
        'item_cat2'   => '', // Catégorie de l'item de menu pour la langue 2
    );

    private $_data_DB = array(); // Mise en cache des données du fichier
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        $this -> _doc_type = TYP_ART.TYP_OPTMENU;
               
        parent :: __construct($this -> _doc_type);
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données enregistrées du rédacteur
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read()
    {
        $data = array();
//        $db = parent :: read();    // Récupérer données enregistrés dans le fichier d'index.dtb        
        $db = ReadDBFields(DBINDEX.$this -> _doc_type.DBEXT);
           
        foreach($db as $row) {
            $data[$row[1]] = array(
                'id_art'      => $row[0], // Id de l'article
                'id_item'     => $row[1], // Id de l'item de menu
                'id_menu'     => $row[2], // Id du menu
                'menu_title1' => $row[3], // Titre du menu pour la langue 1
                'menu_title2' => $row[4], // Titre du menu pour la langue 2
                'item_cat1'   => empty($row[5])? 'Hors Catégorie' : $row[5], // Catégorie de l'item de menu pour la langue 1
                'item_cat2'   => empty($row[6])? 'Hors Catégorie' : $row[6], // Catégorie de l'item de menu pour la langue 2
            );    
        }
        
        return $data;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de l'index
     * 
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return integer Identifiant du document rajouté
	 */    
    public function insert($params)
    {
        settype($params, 'array');
        $params = array_merge($this -> _params, $params);
        
        $data[0]  = $params['id_art'];
        $data[1]  = $params['id_item'];
        $data[2]  = $params['id_menu'];
        $data[3]  = $params['menu_title1'];
        $data[4]  = $params['menu_title2'];
        $data[5]  = $params['item_cat1'];
        $data[6]  = $params['item_cat2'];       

        // Suppression des connecteurs
        $data = parent :: clean($data);
        
        // Rajout des données du document
        return parent :: append($data);        
    }    
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     *
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return integer Identifiant du document rajouté
	 */    
    public function update($params)
    {
        settype($params, 'array');
        
        // $data = parent :: read(); // Fais chier ce foutu fichier index à la con qui n'a pas la même structure que les autres
        $data = array();
        $db = ReadDBFields(DBINDEX.$this -> _doc_type.DBEXT);
        
        foreach($db as $row) {
            $data[$row[1]] = $row; // Clé = id   
        }
        //
        
        $id = $params['id_item'];

        if (!empty($data[$id])) { // Mise à jour
            $data[$id][0] = $params['id_art'];
            $data[$id][1] = $params['id_item'];
            $data[$id][2] = $params['id_menu'];
            $data[$id][3] = $params['menu_title1'];
            $data[$id][4] = $params['menu_title2'];
            $data[$id][5] = $params['item_cat1'];
            $data[$id][6] = $params['item_cat2'];
            
            $data[$id] = parent :: clean($data[$id]);
            
            parent :: write($data);            
        }
        
        return $id; 
    }
    
	// --------------------------------------------------------------------
 
 	/**
	 * Supprime un ou plusieurs enregistrements dans la base de donnée de guppy
     *
     * @access public 
	 * @param array Tableau contenant les identifiants des documents à supprimer
	 * @return boolean
	 */    
    public function delete($ids)
    {
        settype($ids, 'array');
        
        $data = $this -> read();

        foreach($ids as $id) {
            if (!empty($data[$id])) {
                unset($data[$id]);
            }            
        }
        
        parent :: write($data);
        
        return TRUE;
    }
    
	// --------------------------------------------------------------------
 
 	/**
	 * Renvoie les items de menus associés à l'article
     *
     * @access public 
	 * @param integer Identifiant de l'article
	 * @return array Tableau contenant les données des items de menus associés à l'article
	 */    
    public function get_menuitems_by_art_id($art_id)
    {
        if (empty($this -> _data_DB)) {
            $this -> _data_DB = $this -> read(); // Mise en cache des données du fichier              
        }

        $menuitems = $this -> _data_DB;
       
        foreach($menuitems as $item_id => $item) {            
            if ($item['id_art'] != $art_id) {
                unset($menuitems[$item_id]);    
            }    
        }
        
        return $menuitems;
    }

	// --------------------------------------------------------------------

} // End of Class