<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_model.php';

class Articles_model extends Docs_model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_ART;

    private $_params = array(
        'type'      => '',  // Type du document
        'id'        => '',  // Identifiant du document
        'status'    => '',  // Status
        'creadate'  => '',  // Date de création
        'moddate'   => '',  // Date de modification
        'author'    => '',  // Nom de l'auteur
        'email'     => '',  // Email de l'auteur
        'cat1'      => '',  // Catégorie pour la langue 1
        'cat2'      => '',  // Catégorie pour la langue 2
        'title1'    => '',  // Titre pour la langue 1
        'title2'    => '',  // Titre pour la langue 2
        'content1'  => '',  // Contenu pour la langue 1
        'content2'  => '',  // Contenu pour la langue 2
        'boxmenu'   => '',  // Choix du menu
        'icon'      => '',  // Icône
        'sidebars'  => '',  // Mode d'affichage des boîtes latérales
        'layout'    => '',  // Configuration de page
        'group'     => '',  // Groupe privé

        'pubdate0'   => '', // Date début de publication programmée
        'pubhour0'   => '', // Heure de début de publication programmée
        'pubminute0' => '', // Minute de début de publication programmée
        'pubdate1'   => '', // Date de fin de publication programmée
        'pubhour1'   => '', // Heure de fin de publication programmée
        'pubminute1' => '', // Minute de fin de publication programmée
        
        'update_moddate' => '0', // Mise à jour de la date de modification (0 : désactivée ou 1 : activée)

        'keywords1' => '',  // Mots clé pour la langue 1
        'keywords2' => '',  // Mots clé pour la langue 2
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);             
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données enregistrées du rédacteur
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read($doc_id = '')
    {
        if (empty($doc_id)) { // Nouveau document
            $params = array_merge(
                $this -> _params,
                array(
                    'type'       => $this -> _doc_type, // Type du document
                    'status'     => 'i', // Status par defaut
                    'pubdate0'   => Date_helper :: get_current_date(),   // Date début de publication programmée
                    'pubhour0'   => Date_helper :: get_current_hour(),    // Heure de début de publication programmée
                    'pubminute0' => Date_helper :: get_current_minutes(), // Minute de début de publication programmée
                    'boxmenu'    => 'none',  // Choix du menu
                    'sidebars'   => 'S',     // Mode d'affichage des boîtes latérales
                    'layout'     => '0',     // Configuration de page
                )
            );
        }
        else {  // Document existant
            
            $data = parent :: read($doc_id);    // Récupérer données enregistrés dans docxxx.dtb

            list($data['pubdate0'], $data['pubhour0'], $data['pubminute0'], $data['pubdate1'], $data['pubhour1'], $data['pubminute1']) = Date_helper :: convert_createdate_to_pubdates($data['creadate']); // Récupérer dates et horaires de publication
            list($data['keywords1'], $data['keywords2']) = $this -> _get_keywords($doc_id); // Récupérer mots clés dans index kw
                        
            $params = array_merge(
                $this -> _params,
                array(
                    'type'      => $data['type'],      // Type du document
                    'id'        => $data['fileid'],    // Identifiant du document
                    'status'    => $data['status'],    // Status
                    'creadate'  => $data['creadate'],  // Date de création
                    'moddate'   => $data['moddate'],   // Date de modification                
                    'author'    => $data['author'],    // Nom de l'auteur
                    'email'     => $data['email'],     // Email de l'auteur
                    'cat1'      => $data['fielda1'],   // Catégorie pour la langue 1
                    'cat2'      => $data['fielda2'],   // Catégorie pour la langue 2
                    'title1'    => $data['fieldb1'],   // Titre pour la langue 1
                    'title2'    => $data['fieldb2'],   // Titre pour la langue 2
                    'content1'  => $data['fieldc1'],   // Contenu pour la langue 1
                    'content2'  => $data['fieldc2'],   // Contenu pour la langue 2
                    'boxmenu'   => $this -> _is_valid_boxmenu($data['fieldd1']) ? $data['fieldd1'] : 'none',   // Choix du menu
                    'icon'      => !empty($data['fieldd2']) ? 'img/'.$data['fieldd2'] : $data['fieldd2'],   // Icône (ajout de img/ pour la compatibilité de guppy)
                    'sidebars'  => !empty($data['fieldweb']) ? $data['fieldweb'] : 'S',  // Mode d'affichage des boîtes latérales 
                    'layout'    => !empty($data['fieldmail']) ? $data['fieldmail'] : '0', // Configuration de page
                    'group'     => $data['fieldmod'],  // Groupe privé
                    
                    'pubdate0'   => $data['pubdate0'],   // Date début de publication programmée
                    'pubhour0'   => $data['pubhour0'],   // Heure de début de publication programmée
                    'pubminute0' => $data['pubminute0'], // Minute de début de publication programmée
                    'pubdate1'   => $data['pubdate1'],   // Date de fin de publication programmée
                    'pubhour1'   => $data['pubhour1'],   // Heure de fin de publication programmée
                    'pubminute1' => $data['pubminute1'], // Minute de fin de publication programmée

                    'keywords1' => $data['keywords1'], // Mots clé pour la langue 1
                    'keywords2' => $data['keywords2'], // Mots clé pour la langue 2
                )
            );
        }          

        return $params;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Le nom du rédacteur
	 * @return array
	 */    
    public function insert($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = '';
        $data[2]  = $params['status'];
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = '';
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $params['cat1'];
        $data[8]  = $params['cat2'];
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = $params['boxmenu'];
        $data[14] = str_replace('img/', '', $params['icon']); // Compatibilité Guppy
        $data[15] = $params['sidebars'];
        $data[16] = $params['layout'];
        $data[17] = $params['group'];

        // Création du document
        $params['id'] = ActionOnFields('add', $data);
        
        // Enregistrement des mots clés du document
        $this -> _update_keywords($params);
        
        return $params['id'];            
    }    

	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Identifiant du document
     * @param array Données du document
	 * @return array
	 */    
    public function update($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = $params['id'];
        $data[2]  = '';
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']), array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = empty($params['update_moddate']) ? $params['moddate'] : GetCurrentDateTime();
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $params['cat1'];
        $data[8]  = $params['cat2'];
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = $params['boxmenu'];
        $data[14] = str_replace('img/', '', $params['icon']); // Compatibilité Guppy
        $data[15] = $params['sidebars'];
        $data[16] = $params['layout'];
        $data[17] = $params['group'];

        // Mise à jour du document
        ActionOnFields('mod', $data);
        
        // Mise à jour des mots clés du document    
        $this -> _update_keywords($params);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie l'intitulé du document
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres du document
	 * @return string Intitulé descriptif du document
	 */
    public function set_doc_heading($params)
    {        
        global $lng, $lang, $admin;
        
 //       $field0 = (strpos($params['boxmenu'], 'MNU') === FALSE) ? $admin[681].' - ' : '';
 //       $field1 = (($lng == $lang[1]) ? $params['cat2'] : $params['cat1']).' - ';
        $field2 = ($lng == $lang[1]) ? $params['title2'] : $params['title1'];

 //       $field1 = htmlspecialchars($field1, ENT_COMPAT | ENT_HTML5, 'UTF-8');
        $field2 = htmlspecialchars($field2, ENT_COMPAT | ENT_HTML5, 'UTF-8');   
        
        return '<strong>'.$field2.'</strong>'; 
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array_merge(
            Params_rules_helper :: set_params_author_rules($lang),            // Author
            Params_rules_helper :: set_params_email_rules($lang),             // Email
            Params_rules_helper :: set_params_status_rules($lang),            // Status
            Params_rules_helper :: set_params_pubdates_rules($params, $lang), // Dates de publication
            Params_rules_helper :: set_params_icon_rules($lang, $config),     // Icon
            Params_rules_helper :: set_params_group_rules($lang),             // Groupe privé
            Params_rules_helper :: set_params_title_rules($lang, $config),    // Titre de l'article
            Params_rules_helper :: set_params_sidebars_mode_display_rules($lang, $config),    // Mode d'affichage des boites latérales
            Params_rules_helper :: set_params_moddate_options_rules($lang, $config), // Mise à jour de la date de modification du document

            array(
                'boxmenu' => array( // boxmenu
                    array(
                        'rules' => array(array($this, '_is_valid_boxmenu')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['boxmenu_id_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),           
                'layout' => array( // gabarits
                    array(
                        'rules' => array(array($this, '_is_valid_layout')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['layout_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
            )
        );
    }
    
	// --------------------------------------------------------------------

    /**
     * récupére les mots clés enregistrés dans la table indexée kw
     *
     * @access private
     * @param integer Id du document
     * @return array array($keywords1, $keywords2)
     */
    private function _get_keywords($doc_id)
    {
  		$db = ReadDBFields(DBKEYWORDS);
        $keywords = array('', '');
        
		foreach ($db as $data) {
			if ($doc_id == $data[0]) {
				$keywords = array($data[3], $data[4]);
				break;
			}
		}
        
        return $keywords;
    }
    
	// --------------------------------------------------------------------

    /**
     * Met à jour les mots clés enregistrés dans la table indexée kw
     *
     * @access private
	 * @param array Tableau contenant les paramètres de l'article
     * @return void
     */
    private function _update_keywords($params)
    {
        UpdateKeywords($params['id'], $params['title1'], $params['title2'], $params['keywords1'], $params['keywords2'], $params['layout']);
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si l'option du paramètre boxmenu est valide ou non
     * 
     * @access protected
	 * @param string Option à valider
	 * @return boolean
	 */
    function _is_valid_boxmenu($str)
    {
        if ($str == 'none') {
            return TRUE;
        }
        
        return preg_match('`^MNU [0-9]+$`', $str) ? TRUE : FALSE;
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si l'option du paramètre layout est valide ou non (tconfig|heigth)
     * 
     * @access protected
	 * @param string Option à valider
	 * @return boolean
	 */
    function _is_valid_layout($str)
    {        
        $str = str_replace('on', '', $str);
        
        return ! preg_match('`[^0-9|]+`', $str) ? TRUE : FALSE;
    }

	// --------------------------------------------------------------------
 
} // End of Class