<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_model.php';

class Boxmenus_model extends Docs_model
{       
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_MENUBOX;

    private $_params = array(
        'type'      => '', // Type du document
        'id'        => '', // Identifiant du document
        'status'    => '', // Status
        'creadate'  => '', // Date de crétaion
        'moddate'   => '', // Date de modification
        'author'    => '', // Nom de l'auteur
        'email'     => '', // Email de l'auteur
        'boxpos'    => array(), // Emplacements de la boite du menu 
        'boxview'   => '', // Options d'affichage de la boite dynamique (off : affichage statique par défaut, open : affichage dynamique ouvert par défaut, close : affichage dynamique fermé par défaut)
        'boxview_for_mobile' => '', // Options d'affichage de la boite dynamique pour la version mobile (off : affichage statique par défaut, open : affichage dynamique ouvert par défaut, close : affichage dynamique fermé par défaut)
        'title1'    => '', // Titre pour la langue 1
        'title2'    => '', // Titre pour la langue 2
        'content1'  => '', // Contenu pour la langue 1
        'content2'  => '', // Contenu pour la langue 2
        'group'     => '', // Groupe privé
        'boxtype'   => '', // Type de boite de manu(0 : Menu en liste, 1 : Menu dynamique, 2 : Menu liste dynamique n°1, 3 : Menu liste dynamique n°2, 4 : Menu dynamique compact)
        'imgnewpos' => '', // position de l'image nouveauté (L : affichage à gauche, R : affichage à droite)

        'pubdate0'   => '', // Date début de publication programmée
        'pubhour0'   => '', // Heure de début de publication programmée
        'pubminute0' => '', // Minute de début de publication programmée
        'pubdate1'   => '', // Date de fin de publication programmée
        'pubhour1'   => '', // Heure de fin de publication programmée
        'pubminute1' => '', // Minute de fin de publication programmée        
    );
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données enregistrées du rédacteur
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read($doc_id = '')
    {
        if (empty($doc_id)) { // Nouveau document
            $params = array_merge(
                $this -> _params,
                array(
                    'type'       => $this -> _doc_type, // Type du document
                    'status'     => 'i', // Status par defaut
                    'pubdate0'   => Date_helper :: get_current_date(),   // Date début de publication programmée
                    'pubhour0'   => Date_helper :: get_current_hour(),    // Heure de début de publication programmée
                    'pubminute0' => Date_helper :: get_current_minutes(), // Minute de début de publication programmée

                    'boxview'   => 'off', // Options d'affichage de la boite dynamique (off : affichage statique par défaut, open : affichage dynamique ouvert par défaut, close : affichage dynamique fermé par défaut)
                    'boxview_for_mobile' => 'off', // Options d'affichage de la boite dynamique pour la version mobile (off : affichage statique par défaut, open : affichage dynamique ouvert par défaut, close : affichage dynamique fermé par défaut)
                    'boxtype'   => '2',   // Type de boite de manu(0 : Menu en liste, 1 : Menu dynamique, 2 : Menu liste dynamique n°1, 3 : Menu liste dynamique n°2, 4 : Menu dynamique compact)
                    'boxpos'    => array('L'),   // Emplacements de la boite du menu (T: entête, L : colonne latérale gauche, A : colonne centrale au dessus,  U : colonne centrale au dessous, R : colonne latérale droite, B : pied de page)
                    'imgnewpos' => 'L', // position de l'image nouveauté (L : affichage à gauche, R : affichage à droite)
                )
            );
        }
        else {  // Document existant
            
            $data = parent :: read($doc_id);    // Récupérer données enregistrés dans docxxx.dtb

            list($data['pubdate0'], $data['pubhour0'], $data['pubminute0'], $data['pubdate1'], $data['pubhour1'], $data['pubminute1']) = Date_helper :: convert_createdate_to_pubdates($data['creadate']); // Récupérer dates et horaires de publication
            list($data['boxview'], $data['boxview_for_mobile']) = $this -> _convert_string_boxviews_to_array($data['fielda2']);
       
            $params = array_merge(
                $this -> _params,
                array(
                    'type'      => $data['type'],      // Type du document
                    'id'        => $data['fileid'],    // Identifiant du document
                    'status'    => $data['status'],    // Status
                    'creadate'  => $data['creadate'],  // Date de création                 
                    'author'    => $data['author'],    // Nom de l'auteur
                    'email'     => $data['email'],     // Email de l'auteur
                    'boxpos'    => $this -> _convert_string_boxpos_to_array($data['fielda1']),   // Emplacements de la boite du menu (T: entête, L : colonne latérale gauche, A : colonne centrale au dessus,  U : colonne centrale au dessous, R : colonne latérale droite, B : pied de page)
                    'boxview'   => $data['boxview'],   // Options d'affichage de la boite dynamique (off : affichage statique par défaut, open : affichage dynamique ouvert par défaut, close : affichage dynamique fermé par défaut)
                    'boxview_for_mobile' => $data['boxview_for_mobile'], // Options d'affichage de la boite dynamique pour la version mobile (off : affichage statique par défaut, open : affichage dynamique ouvert par défaut, close : affichage dynamique fermé par défaut)
                    'title1'    => $data['fieldb1'],   // Titre pour la langue 1
                    'title2'    => $data['fieldb2'],   // Titre pour la langue 2
                    'content1'  => $data['fieldc1'],   // Contenu pour la langue 1
                    'content2'  => $data['fieldc2'],   // Contenu pour la langue 2
                    'imgnewpos' => !empty($data['fieldd1']) ? $data['fieldd1'] : 'L', // position de l'image nouveauté (L : affichage à gauche, R : affichage à droite)
                    'group'     => $data['fieldmod'],  // Groupe privé
                    'boxtype'   => $data['fieldweb'],  // Type de boite de manu(0 : Menu en liste, 1 : Menu dynamique, 2 : Menu liste dynamique n°1, 3 : Menu liste dynamique n°2, 4 : Menu dynamique compact)
                    
                    'pubdate0'   => $data['pubdate0'],   // Date début de publication programmée
                    'pubhour0'   => $data['pubhour0'],   // Heure de début de publication programmée
                    'pubminute0' => $data['pubminute0'], // Minute de début de publication programmée
                    'pubdate1'   => $data['pubdate1'],   // Date de fin de publication programmée
                    'pubhour1'   => $data['pubhour1'],   // Heure de fin de publication programmée
                    'pubminute1' => $data['pubminute1'], // Minute de fin de publication programmée
                )
            );
        }

        return $params;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Le nom du rédacteur
	 * @return array
	 */    
    public function insert($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = '';
        $data[2]  = $params['status'];
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = '';
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $this -> _convert_array_boxpos_to_string($params['boxpos']);
        $data[8]  = $this -> _convert_array_boxviews_to_string(array($params['boxview'], $params['boxview_for_mobile']));
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = $params['imgnewpos'];
        $data[14] = '';
        $data[15] = $params['boxtype'];
        $data[16] = '';
        $data[17] = $params['group'];

        // Création du document
        $id = ActionOnFields('add', $data);
        
        return $id;
    }    
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Identifiant du document
     * @param array Données du document
	 * @return array
	 */    
    public function update($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = $params['id'];
        $data[2]  = '';
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = GetCurrentDateTime();
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $this -> _convert_array_boxpos_to_string($params['boxpos']);
        $data[8]  = $this -> _convert_array_boxviews_to_string(array($params['boxview'], $params['boxview_for_mobile']));
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = $params['imgnewpos'];
        $data[14] = '';
        $data[15] = $params['boxtype'];
        $data[16] = '';
        $data[17] = $params['group'];

        // Mise à jour du document
        ActionOnFields('mod', $data);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie l'intitulé du document
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres du document
	 * @return string Intitulé descriptif du document
	 */
    public function set_doc_heading($params)
    {        
        global $lng, $lang;

        $field1 = (($lng == $lang[1]) ? $params['title2'] : $params['title1']);

        $field1 = htmlspecialchars($field1, ENT_COMPAT | ENT_HTML5, 'UTF-8');   
        
        return '<strong>'.$field1.'</strong>'; 
    }

	// --------------------------------------------------------------------
  
	/**
	 * Convertit la valeur des positions de la boite de menu en tableau de valeurs
     * 
     * @access private
	 * @param string les positions sélectionnées pour la boite de menus
	 * @return array Tableau contenant les différentes positions sélectionnées pour la boite de menus
	 */        
    private function _convert_string_boxpos_to_array($boxpos)
    {
        return str_split($boxpos);    
    } 

	// --------------------------------------------------------------------
  
	/**
	 * Convertit le tableau de valeurs des positions de la boite de menu en chaine
     * 
     * @access private 
	 * @param array Tableau contenant les différentes positions sélectionnées pour la boite de menus
	 * @return string les positions sélectionnées pour la boite de menus
	 */        
    private function _convert_array_boxpos_to_string($boxpos)
    {
        return implode('', $boxpos);    
    } 

	// --------------------------------------------------------------------
  
	/**
	 * Convertit la valeur des options d'affichage (web et mobile) de la boite de menu en tableau de valeurs
     * 
     * @access private
	 * @param string les options d'affichage (web et mobile) sélectionnées pour la boite de menus
	 * @return array Tableau contenant les différentes options d'affichage (web et mobile) sélectionnées pour la boite de menus
	 */        
    private function _convert_string_boxviews_to_array($boxviews)
    {
        $boxviews = explode('|', $boxviews);
        
        if (!isset($boxviews[1])) {
            $boxviews[1] = 'off';    
        }
        
        return $boxviews;    
    } 

	// --------------------------------------------------------------------
  
	/**
	 * Convertit le tableau de valeurs des options d'affichage (web et mobile) de la boite de menu en chaine
     * 
     * @access private 
	 * @param array Tableau contenant les options d'affichage (web et mobile) sélectionnées pour la boite de menus
	 * @return string les positions sélectionnées pour la boite de menus
	 */        
    private function _convert_array_boxviews_to_string($boxviews)
    {
        settype($boxviews, 'array');
        
        return implode('|', $boxviews);    
    } 

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array_merge(
            Params_rules_helper :: set_params_author_rules($lang),            // Author
            Params_rules_helper :: set_params_email_rules($lang),             // Email
            Params_rules_helper :: set_params_status_rules($lang),            // Status
            Params_rules_helper :: set_params_pubdates_rules($params, $lang), // Dates de publication
            Params_rules_helper :: set_params_group_rules($lang),             // Group
            Params_rules_helper :: set_params_title_rules($lang, $config),    // Titre de la boite de menu
            array(
                'boxtype' => array( // boxtype
                    array(
                        'rules' => array(array('Var_helper', 'is_in_array['.implode(',', $config['box_types']).']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['boxmenu_type_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'boxview' => array( // boxview
                    array(
                        'rules' => array(array('Var_helper', 'is_in_array['.implode(',', $config['box_views']).']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['boxmenu_view_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'boxview_for_mobile' => array( // boxview pour version mobile
                    array(
                        'rules' => array(array('Var_helper', 'is_in_array['.implode(',', $config['box_views']).']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['boxmenu_view_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'boxpos' => array( // boxpos (array)
                    array(
                        'rules' => array(array($this, '_is_valid_boxpos['.implode(',', $config['box_positions']).']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['boxmenu_positions_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'imgnewpos' => array( // boxview pour version mobile
                    array(
                        'rules' => array(array('Var_helper', 'is_in_array[R,L]')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),

            )
        );
    }

	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si les positions sélectionnées de la boite de menus sont correctes ou non
     * 
     * @access public 
	 * @param array Tableau contenant les positions sélectionnées
	 * @param string|array Tableau contenant les positions autorisées
	 * @return boolean Résultats de la validation
	 */
    function _is_valid_boxpos($boxpos, $pos_allowed)
    {
        if (!is_array($pos_allowed)) {
            $pos_allowed = explode(',', $pos_allowed);    
        }
        
        foreach($boxpos as $pos) {
            if (!in_array($pos, $pos_allowed)) { // TLAURB
                return FALSE;
            }    
        }
        
        return TRUE;
    }

	// --------------------------------------------------------------------
 
} // End of Class