<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Guppy_doc_model extends Model 
{    
    /**
     * constructeur
     * 
     * @return void
     */ 
    public function __construct()
    {
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    /**
     * Met à jour les status des documents de guppy
     * 
     * @param array Identifiants des documents de guppy
     * @param string Status à affecter
     * @return array
     */
    public function update_status_by_id($ids, $status)
    {
        settype($ids, 'array');
        $data = $this -> _read_docid();
        $doctypes = array(); // Tableau contenant les types des documents à traiter

        foreach($ids as $id){
            $type = $data[$id][AOF_TYPE]; // Type du document
            $doctypes[$type] = $type;
            ActionOnFields('act', array($type, $id, $status), FALSE);
        }
        
        // Réindexation des fichiers
        foreach($doctypes as $doctype) {
            ActionOnFields('reindex', array($doctype));
        }
        
    }

	// --------------------------------------------------------------------

    /**
     * Supprime définitivement des documents de guppy
     * 
     * @param array Identifiants des documents de guppy
     * @return array
     */
    public function delete_by_id($ids)
    {
        settype($ids, 'array');
        $data = $this -> _read_docid();
        $doctypes = array();  // Tableau contenant les types des documents à traiter

        foreach($ids as $id){
            $type = $data[$id][AOF_TYPE]; // Type du document
            $doctypes[$type] = $type;
            ActionOnFields('sup', array($type, $id), FALSE);
			
            if ($type == TYP_PHOTO) {
				RecursiveRemoteDir(PHOTOREP.'gal_'.$id);
			}
            if ($type == TYP_MENUBOX) {
                $doctypes[TYP_OPTMENU] = TYP_OPTMENU;
                $opts = SelectDBFieldsByField(ReadDBFields(DBOPTMENU), 5, $id);
                foreach ($opts as $opt) {
                    ActionOnFields('sup', array(TYP_OPTMENU, $opt[4]), FALSE);    
                }
            }
            if ($type == TYP_DDMENUBOX) {
                $doctypes[TYP_OPTDDMENU] = TYP_OPTDDMENU;
                $opts = SelectDBFieldsByField(ReadDBFields(DBOPTDDMENU), 5, $id);
                foreach ($opts as $opt) {
                    ActionOnFields('sup', array(TYP_OPTDDMENU, $opt[4]), FALSE);    
                }
            }
        }
        
        // Réindexation des fichiers
        foreach($doctypes as $doctype) {
            ActionOnFields('reindex', array($doctype, 0));
        }
        
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes du document
     *
     * @access private
     * @return array
     */
    private function _read_doc($id)
    {
       return  ReadDoc(TestFileId($id)); 
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes de la table indexée des documents selon leur type
     *
     * @access private
     * @return array
     */
    private function _read_index($section)
    {
       return ReadDBFields(DBINDEX.$section.DBEXT); 
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes de la table indexée des documents de guppy (type||id||status)
     *
     * @access private
     * @return array
     */
    private function _read_docid()
    {
       $data = array();
       $records = ReadDBFields(DOCID);
       
       foreach ($records as $record) {
            $data[$record[1]] = $record;
       }
       
       return $data;
    }

	// --------------------------------------------------------------------
    
} // End Class