<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.14 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Writer_docs_model extends Model
{
    private $_file_basepath = ADMR_WRITER_DOCS_PATH;
    private $_file_prefix = ADMR_WRITER_DOCS_FILE_PREFIX;
//    private $_file_ext = DBEXT;

    private $_DB_file_path = NULL;  // Chemin du fichier contenant la base de donnée
    private $_data_DB = array();    //Données de la base de données
    
    private $_sort_items = array('id_asc', 'id_desc', 'type_asc', 'type_desc', 'status_asc', 'status_desc', 'up_asc', 'up_desc');	// Options de tri

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */

    /**
     * constructeur
     * 
     * @param array Tableau contenant l'identifiant du rédacteur qui est associé au fichier contenant la table des documents
     * @return void
     */ 
    function __construct($params = array())
    {
        if (!empty($params['id'])) {
            $this -> load_data($params['id']);
        }
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Charge les données des diapos enregistrées dana le photorama
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant la base de données des diapos enregistrées dana le photorama (vide par défaut)
	 */    
    function load_data($writer_id)
    {
        if (!empty($writer_id) && ctype_digit($writer_id)) {
            $this -> _DB_file_path = $this -> _file_basepath.'/'.$this -> _file_prefix.$writer_id.DBEXT;
            
            $this -> _data_DB = $this -> read();   
        }
        
        return $this -> _data_DB;       
    }

	// --------------------------------------------------------------------

	/**
	 * récupére les données des rédacteurs enregistrés (tous par défaut)
     * 
	 * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @param  string Option de tri (optionnel)
	 * @return array tableau contenant les données des rédacteurs enregistrés
	 */
	function get($filters = array(), $sort_by = '')
	{
        settype($filters, 'array');
        
        $data = array();
      
        if (!empty($filters) ) {
            $data = $this -> get_many_by_keys($filters);
        }
        else {
            $data = $this -> get_all();
        }
        
        if (!empty($sort_by)) {
            $data = $this -> sort_by_key($data, $sort_by);
        }
        
        return $data;
	}

	// --------------------------------------------------------------------

    /**
     * récupérer les documents enregistrés
     * 
     * @access public
     * @return array
     */
    function get_all()
    {  
        return $this -> _data_DB;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des documents identifiés par les critères de sélection
     * 
     * @param array Tableau contenant les critères de sélection sous la forme array( key => values)
     * @return array
     */
    function get_many_by_keys($keys)
    {
        settype($keys, 'array');

        return $this -> select_many_by_many_keys($this -> _data_DB, $keys);
    }

	// --------------------------------------------------------------------
    
    /**
     * récupérer le nombre de documents enregistrés
     * 
     * @access public
     * @param  string Type du document (optionnel)
     * @return integer
     */
	function count($doc_type = NULL)
	{
        return empty($doc_type) ? $this -> count_all() : $this -> count_by_type($doc_type);
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total de documents enregistrés
     * 
     * @access public
     * @return integer
     */
    function count_all()
    {
        return count($this -> _data_DB);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total de documents enregistrés par type
     * 
     * @access public
     * @param  string Type du document
     * @return integer
     */
	function count_by_type($doc_type)
	{
        return count($this -> get_many_by_type($doc_type));
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa valeur
     * 
     * @param 
     * @return array
     */
    function select_by_key($data_DB = array(), $key = '', $value = '')
    {
        settype($data_DB, 'array');
        settype($value, 'string');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && $row[$key] == $value) {
                return $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données des documents
     * @return array
     */
    function select_many_by_key($data_DB = array(), $key = '', $value = array())
    {
        settype($data_DB, 'array');
        settype($value, 'array');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && in_array($row[$key], $value)) {
                $data[$row['id']] = $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données de la base
     * @param array Tableau contenant les critères de sélection sous la forme array($key1 => mixed $values1, $key2 => mixed $values2,...)
     * @return array
     */
    function select_many_by_many_keys($data_DB = array(), $keys = array())
    {
        settype($data_DB, 'array');
        settype($keys, 'array');

        
        $data = $data_DB;

        foreach($keys as $key => $values) {
            
            if (empty($values)) {
                continue;    
            }
            
            settype($values, 'array');
            
            foreach($data as $id => $row) {
                if (!isset($row[$key]) || !in_array($row[$key], $values)) {
                    unset($data[$id]);
                }
            }           
        }        
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par leur type
     * 
     * @param string|array Type du document
     * @return array
     */
    function get_many_by_type($type)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'type', $type);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par id
     * 
     * @param integer Id du rédacteur
     * @return array Données du rédacteur
     */
    function get_by_id($id)
    {
        return $this -> select_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par les ids
     * 
     * @param array Tableau contenant les valeurs des identifiants des documents à récupérer
     * @return array Données du rédacteur
     */
    function get_many_by_id($id)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par son status
     * 
     * @param string Status du rédacteur
     * @return array
     */
    function get_many_by_status($status)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'status', $status);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par le status différent du sien
     * 
     * @param string Status différent de celui du rédacteur
     * @return array
     */
    function get_many_by_not_status($status)
    {
        return array_diff_key($this -> _data_DB, $this -> select_many_by_key($this -> _data_DB, 'status', $status));
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par leur type
     * 
     * @param string Type du document
     * @return array
     */
    function get_many_by_mode($mode)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'mode', $mode);
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes de la table indexée des rédacteurs (pseudo||id||status)
     *
     * @return array
     */
    function read()
    {
        $data_DB = array();
        $records = array();
        
        if (!empty($this -> _DB_file_path) && is_file($this -> _DB_file_path)) {
            $data_DB = file($this -> _DB_file_path);
    		
            foreach($data_DB as $data) {
                list($type, $id, $status, $mode) = explode(CONNECTOR, trim($data)) + array(3 => 0);
    			
                $records[$id] = array(
                    'type'   => $type,
                    'id'     => $id,
                    'status' => $status,
                    'mode'   => $mode, // 1 : new, 2 : updated, 0 : approved 
                );
            }
        }
        
        return $records;
    }

	// --------------------------------------------------------------------

    /**
     * Efface le contenu de la table et le remplace avec les données passées en paramètre
     * 
     * @param array Données à écrire
     * @return array
     */
    function write()
    {
        $data = $this -> _data_DB;
        $file_path = $this -> _DB_file_path;
        $data_out = '';
        
        if (empty($file_path)) { // Si pas de fichier, on a rien à faire ici !
            return FALSE;    
        }
        
        foreach($data as $row) {     
            $data_out .= implode(CONNECTOR, array_values($row))."\n";
        }

        $fhandle = fopen($file_path, 'w');
        fputs($fhandle, $data_out);
        fclose($fhandle);
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * synchronize les données du rédacteur avec les données de guppy
     *
     * @param object Objet model contenant les méthodes de gestion des documents de guppy (fichier docid)
     * @return array
     */
    function synchronize($guppy_docid_model)
    {
        $guppy_data = $guppy_docid_model -> get(array('status' => array('a', 'i')));
        
        return $this -> synchronize_with_guppy_data($guppy_data);
    }

	// --------------------------------------------------------------------

    /**
     * synchronize les données du rédacteur avec les données de guppy
     *
     * @param array Tableau contenant les données de guppy prises comme référence
     * @return array Données du rédacteurs synchronisées sur celles de guppy
     */
    function synchronize_with_guppy_data($guppy_data)
    {
        settype($guppy_data, 'array');
        $writer_data = $this -> _data_DB;
        
        foreach($writer_data as $data) {
            if (isset($guppy_data[$data['id']])) {                
                $this -> _data_DB[$data['id']] = $guppy_data[$data['id']] + array('mode' => $data['mode']);
            } else {
                unset($this -> _data_DB[$data['id']]);
            }
        }
        
        $this -> write();

        return TRUE;        
    }
    
	// --------------------------------------------------------------------

    /**
     * Ajoute un enregistrement dans la table indexée 
     * des documents des rédacteurs (type||id||status)
     * 
     * @param array Données de l'enregistrement du document dans la table
     * @return array
     */
    function insert($data)
    {
        if (empty($data)) { // Si pas de données, on a rien à faire ici !
            return FALSE;
        }

  //      $this -> _data_DB[$data['id']] = $data;
        
        $this -> _data_DB[$data['id']] = array(
            'type'   => $data['type'],
            'id'     => $data['id'],
            'status' => $data['status'],
            'mode'   => 1, // 1 : new, 2 : updated, 0 : approved 
        );
        
        $this -> write();

        return TRUE;
    }
    
	// --------------------------------------------------------------------

    /**
     * Met à jours un enregistrement dans la table indexée 
     * des documents des rédacteurs (type||id||status)
     * 
     * @param array Données de l'enregistrement du document dans la table
     * @return array
     */
    function update($data)
    {
        if (empty($data)) { // Si pas de données, on a rien à faire ici !
            return FALSE;
        }
        
        $this -> _data_DB[$data['id']] = array(
            'type'   => $data['type'],
            'id'     => $data['id'],
            'status' => $data['status'],
            'mode'   => 2, // 1 : new, 2 : updated, 0 : approved 
        );
        
        $this -> write();

        return TRUE;
    }
    
	// --------------------------------------------------------------------

    /**
     * remise à zéro de la table indexée 
     * des documents des rédacteurs (type||id||status||mode)
     * 
     * @return void
     */
    function reset()
    {       
        $this -> _data_DB = array();
        
        $this -> write();

        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute plusieurs enregistrements en une fois dans la table indexée 
     * des documents des rédacteurs (type||id||status||mode)
     * 
     * @param array Identifiants des enregistrements dans la table
     * @param string Type des enregistrements
     * @param string Status des enregistrements (par défaut status = a)
     * @param integer Mode des enregistrements (par défaut mode = 1)
     * @return array
     */
    function insert_many($ids, $type, $status = 'a', $mode = '1')
    {
        if (empty($ids) || empty($type)) {
            return FALSE;
        }
        
        settype($ids, 'array');
        
        foreach($ids as $id) {
            $this -> _data_DB[$id] = array(
                'type'   => $type,
                'id'     => $id,
                'status' => $status,
                'mode'   => $mode, 
            );    
        }
        
        $this -> write();

        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Tri les enregistrements
     * 
     * @param string Option de tri
     * @return array Données triées
     */
    function sort_by_key($data, $sort_option)
    {       
        if(empty($data)) {
            return $data;
        }

        // Tableau en colonne
        foreach ($data as $key => $row) {
            $id[$key]     = $row['id'];
            $type[$key]   = $row['type'];
            $status[$key] = $row['status'];
            $mode[$key]   = $row['mode'];
        }
        //
        
        switch ($sort_option) {
			case 'id_desc' :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'id_asc' :
				array_multisort($id, SORT_NUMERIC, SORT_ASC, $data);
				break;
			case 'type_asc' :
				array_multisort(array_map('strtolower', $type), SORT_STRING, SORT_ASC, $mode, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'type_desc' :
				array_multisort(array_map('strtolower', $type), SORT_STRING, SORT_DESC, $mode, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'status_desc' :
				array_multisort($status, SORT_DESC, $data);
				break;
			case 'status_asc' :
				array_multisort($status, SORT_ASC, $data);
				break;
			case 'up_asc' :
				array_multisort($mode, SORT_NUMERIC, SORT_ASC, $data);
				break;
			case 'up_desc' :
				array_multisort($mode, SORT_NUMERIC, SORT_DESC, $data);
				break;
			default :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
		}	
	
		return $data;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour les status des documents dans la table 
     * 
     * @param array Identifiants des rédacteurs
     * @param string Status à affecter
     * @return array
     */
    function update_status_by_id($ids, $status)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                $db[$key]['status'] = $status;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour le mode des documents dans la table 
     * 
     * @param array Enregistrements des documents dans la table
     *              sous la forme array(id => status)
     * @param string Status à affecter
     * @return array
     */
    function update_mode_by_id($ids, $mode)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                $db[$key]['mode'] = $mode;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les documents identifiés par leur identifiants dans la table (alias)
     * 
     * @param integer|array Identifiants des documents dans la table
     * @return array
     */
    function delete_many_by_id($ids)
    {
        return $this -> delete_by_id($ids);
    }

	// --------------------------------------------------------------------

    /**
     * supprime les documents identifiés par leur identifiants dans la table
     * 
     * @param integer|array Identifiants des documents dans la table
     * @return array
     */
    function delete_by_id($ids)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
        
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                unset($db[$key]);
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------
    
} // End Class